@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-#	$Id: gmtpatch.sh,v 1.1 2009/05/21 14:55:16 remko Exp $
+#	$Id: gmtpatch.sh,v 1.2 2009/10/23 18:32:37 remko Exp $
 #
 #	gmtpatch - Manage installation of GMT patches between releases
 #
@@ -28,7 +28,7 @@ fi
 mkdir -p .gmtpatchdir
 
 # Get ftp site
-site=`grep GMT_site src/makegmt.macros | awk '{print $3}'`
+site=`grep GMT_site src/config.mk | awk '{print $3}'`
 
 # Get the list of available patches
 
