@@ -1,6 +1,6 @@
 #!/bin/sh
 #		GMT EXAMPLE 12
-#		$Id: job12.sh,v 1.12 2008/11/29 23:44:56 guru Exp $
+#		$Id: job12.sh,v 1.13 2009/04/16 19:38:18 guru Exp $
 #
 # Purpose:	Illustrates Delaunay triangulation of points, and contouring
 # GMT progs:	makecpt, minmax, pscontour, pstext, psxy, triangulate
@@ -9,14 +9,14 @@
 # First draw network and label the nodes
 #
 ps=example_12.ps
-triangulate table_5.11 -M > net.xy
-psxy -R0/6.5/-0.2/6.5 -JX3.06i/3.15i -B2f1WSNe -M net.xy -Wthinner -P -K -X0.9i -Y4.65i > $ps
+triangulate table_5.11 -m > net.xy
+psxy -R0/6.5/-0.2/6.5 -JX3.06i/3.15i -B2f1WSNe -m net.xy -Wthinner -P -K -X0.9i -Y4.65i > $ps
 psxy table_5.11 -R -J -O -K -Sc0.12i -Gwhite -Wthinnest >> $ps
 $AWK '{print $1, $2, 6, 0, 0, "CM", NR-1}' table_5.11 | pstext -R -J -O -K >> $ps
 #
 # Then draw network and print the node values
 #
-psxy -R -J -B2f1eSNw -M net.xy -Wthinner -O -K -X3.25i >> $ps
+psxy -R -J -B2f1eSNw -m net.xy -Wthinner -O -K -X3.25i >> $ps
 psxy -R -J -O -K table_5.11 -Sc0.03i -Gblack >> $ps
 $AWK '{printf "%g %s 6 0 0 LM %g\n", $1, $2, $3}' table_5.11 | pstext -R -J -O -K -Wwhite,o \
 	-C0.01i/0.01i -D0.08i/0i -N >> $ps
