@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmode.c,v 1.62 2009/09/09 23:27:01 guru Exp $
+ *    $Id: blockmode.c,v 1.65 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -66,7 +66,7 @@ int main (int argc, char **argv)
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct BLOCKMODE_CTRL *) New_Blockmode_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct BLOCKMODE_CTRL *) New_blockmode_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 
@@ -248,7 +248,7 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (buffer, BUFSIZ, fp);
-				buffer[strlen(buffer)-1] = 0;
+				GMT_chop (buffer);
 				if (first && GMT_io.io_header[GMT_OUT]) (Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? fprintf (GMT_stdout, "%s weights\n", buffer) : fprintf (GMT_stdout, "%s\n", buffer);
 			}
 			first = FALSE;
@@ -423,7 +423,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)data);
 	GMT_free ((void *)z_tmp);
 
-	Free_Blockmode_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_blockmode_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
