@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdraster.c,v 1.59 2009/05/13 21:06:43 guru Exp $
+ *	$Id: grdraster.c,v 1.62 2010/01/14 07:15:20 guru Exp $
  *
- *    Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* grdraster.c -- read a rasterfile and extract a region as a grid file.
@@ -91,7 +91,7 @@ int main (int argc, char **argv)
 
 	struct GRDRASTER_CTRL *Ctrl;
 	
-	void *New_Grdraster_Ctrl (), Free_Grdraster_Ctrl (struct GRDRASTER_CTRL *C);
+	void *New_grdraster_Ctrl (), Free_grdraster_Ctrl (struct GRDRASTER_CTRL *C);
 	void convert_u_row (struct GRDRASTER_INFO ras, float *row, unsigned char *buffer);
 	void convert_c_row (struct GRDRASTER_INFO ras, float *row, char *buffer);
 	void convert_d_row (struct GRDRASTER_INFO ras, float *row, short unsigned int *buffer);
@@ -101,7 +101,7 @@ int main (int argc, char **argv)
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDRASTER_CTRL *)New_Grdraster_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDRASTER_CTRL *)New_grdraster_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 
@@ -534,7 +534,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)grd);
 	GMT_free ((void *)rasinfo);
 
-	Free_Grdraster_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdraster_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 	
@@ -677,12 +677,10 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 	
 	while (fgets(rasinfo[nfound].h.command, GRD_COMMAND_LEN, fp) ) {
 		if (rasinfo[nfound].h.command[0] == '#') continue;
-		if (rasinfo[nfound].h.command[0] == '\n') continue;	 /* Blank line */
+		GMT_chop (rasinfo[nfound].h.command);
+		if (rasinfo[nfound].h.command[0] == '\0') continue;	 /* Blank line */
 
-		/* Strip off the trailing "\n" :  */
 		length = strlen(rasinfo[nfound].h.command);
-		length--;
-		rasinfo[nfound].h.command[length] = '\0';
 
 		/* Find the integer file name first:  */
 		i = 0;
@@ -1082,15 +1080,15 @@ GMT_LONG get_byte_size (char type) {
 	return (ksize);
 }
 
-void *New_Grdraster_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdraster_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDRASTER_CTRL *C;
 	
-	C = (struct GRDRASTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDRASTER_CTRL), "New_Grdraster_Ctrl");
+	C = (struct GRDRASTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDRASTER_CTRL), "New_grdraster_Ctrl");
 	
 	return ((void *)C);
 }
 
-void Free_Grdraster_Ctrl (struct GRDRASTER_CTRL *C) {	/* Deallocate control structure */
+void Free_grdraster_Ctrl (struct GRDRASTER_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
