@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: filter1d.c,v 1.58 2009/09/09 23:27:01 guru Exp $
+ *    $Id: filter1d.c,v 1.61 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -166,11 +166,11 @@ int main (int argc, char **argv)
 	void	free_space (struct FILTER1D_INFO *F);			/* Does just what it says  */
 	void	allocate_more_data_space (struct FILTER1D_INFO *F);	/* Does just what it says  */
 	void load_parameters (struct FILTER1D_INFO *C, struct FILTER1D_CTRL *Ctrl);
-	void *New_Filter1d_Ctrl (), Free_Filter1d_Ctrl (struct FILTER1D_CTRL *C);
+	void *New_filter1d_Ctrl (), Free_filter1d_Ctrl (struct FILTER1D_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct FILTER1D_CTRL *)New_Filter1d_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct FILTER1D_CTRL *)New_filter1d_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&F, 0, sizeof (struct FILTER1D_INFO));	/* Init control structure to NULL */
 	F.n_row_alloc = GMT_CHUNK;
@@ -549,7 +549,7 @@ int main (int argc, char **argv)
 
 	if (F.n_multiples > 0 && gmtdefs.verbose) fprintf (stderr, "%s: WARNING: %ld multiple modes found\n", GMT_program, F.n_multiples);
 
-	Free_Filter1d_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_filter1d_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -578,6 +578,7 @@ GMT_LONG set_up_filter (struct FILTER1D_INFO *F)
 		w_sum = 0.0;
 		while (GMT_fgets (buffer, BUFSIZ, F->fp_wt)) {
 			if (GMT_is_a_blank_line (buffer)) continue;	/* Skip blank lines or # comments */
+			GMT_chop (buffer);
 			if (sscanf (buffer, "%lf", &F->f_wt[F->n_f_wts]) != 1) {
 				fprintf (stderr, "%s: Error decoding filter weights from file\n", GMT_program);
 				exit (EXIT_FAILURE);
@@ -1040,10 +1041,10 @@ void load_parameters (struct FILTER1D_INFO *F, struct FILTER1D_CTRL *Ctrl)
 	F->out_at_time = Ctrl->T.active;
 }
 
-void *New_Filter1d_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_filter1d_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct FILTER1D_CTRL *C;
 
-	C = (struct FILTER1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct FILTER1D_CTRL), "New_Filter1d_Ctrl");
+	C = (struct FILTER1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct FILTER1D_CTRL), "New_filter1d_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->N.ncols = 2;						/* Expected # of columns */
@@ -1051,7 +1052,7 @@ void *New_Filter1d_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Filter1d_Ctrl (struct FILTER1D_CTRL *C) {	/* Deallocate control structure */
+void Free_filter1d_Ctrl (struct FILTER1D_CTRL *C) {	/* Deallocate control structure */
 	if (C->F.file) free ((void *)C->F.file);	
 	GMT_free ((void *)C);	
 }
