@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *    $Id: fitcircle.c,v 1.31 2007/03/12 19:52:26 remko Exp $
+ *    $Id: fitcircle.c,v 1.45 2010/01/05 01:15:44 guru Exp $
  *
- *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *	Contact info: gmt.soest.hawaii.edu
  *--------------------------------------------------------------------*/
 /*
- * fitcircle <lonlatfile> [-L1] [-L2] [-S]
+ * fitcircle <lonlatfile> [-L1] [-L2] [-S[<lat>]]
  *
  * Read lon,lat pairs from GMT_stdin[file].  Find mean position and pole
  * of best-fit circle through these points.  By default, fit great
@@ -51,6 +51,7 @@
  * To find a small circle, first find the great circle pole and the mean
  * position.  Suppose the small circle pole to lie in the plane containing
  * the mean and great circle pole, and narrow down its location by bisection.
+ * Alternatively, specify the latitude of the small circle.
  *
  * Author:	W. H. F. Smith
  * Date:	16 September 1991.
@@ -64,10 +65,12 @@ struct FITCIRCLE_CTRL {	/* All control options for this program (except common a
 	/* active is TRUE if the option has been activated */
 	struct L {	/* -L[<n>] */
 		BOOLEAN active;
-		int norm;	/* 1, 2, or 3 (both) */
+		GMT_LONG norm;	/* 1, 2, or 3 (both) */
 	} L;
 	struct S {	/* -S */
 		BOOLEAN active;
+		GMT_LONG mode;	/* 0 = find latitude, 1 = use specified latitude */
+		double lat;	/* 0 for great circle */
 	} S;
 };
 
@@ -77,16 +80,17 @@ struct	FITCIRCLE_DATA {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, greenwich = FALSE;
+	BOOLEAN	error = FALSE, greenwich = FALSE, allocate;
 
-	char	format[BUFSIZ];
+	char	format[BUFSIZ], *not_used = NULL;
 
-	int	i, j, k, imin, imax, n_alloc, n_data, n, np, nrots, n_fields, n_expected_fields;
+	GMT_LONG	imin, imax, nrots, n_fields, n_expected_fields;
+	GMT_LONG	i, j, k, n_alloc, n_data, n, np;
 
 	double	lonsum, latsum, *in;
 	double	meanv[3], cross[3], cross_sum[3], gcpole[3], scpole[3];		/* Extra vectors  */
 	double	*a, *lambda, *v, *b, *z;	/* Matrix stuff */
-	double	get_small_circle (struct FITCIRCLE_DATA *data, int ndata, double *center, double *gcpole, double *scpole, int norm, double *work);
+	double	get_small_circle (struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *center, double *gcpole, double *scpole, GMT_LONG norm, double *work, GMT_LONG mode, double slat);
 	double	rad, *work = VNULL;
 
 	FILE	*fp = NULL;
@@ -94,11 +98,11 @@ int main (int argc, char **argv)
 	struct	FITCIRCLE_DATA *data;
 	struct FITCIRCLE_CTRL *Ctrl;
 
-	void *New_Fitcircle_Ctrl (), Free_Fitcircle_Ctrl (struct FITCIRCLE_CTRL *C);
+	void *New_fitcircle_Ctrl (), Free_fitcircle_Ctrl (struct FITCIRCLE_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
- 	Ctrl = (struct FITCIRCLE_CTRL *) New_Fitcircle_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+ 	Ctrl = (struct FITCIRCLE_CTRL *) New_fitcircle_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -125,6 +129,10 @@ int main (int argc, char **argv)
 					break;
 				case 'S':
 					Ctrl->S.active = TRUE;
+					if (argv[i][2]) {
+						Ctrl->S.lat = atof (&argv[i][2]);
+						Ctrl->S.mode = 1;
+					}
                                         break;
 				default:
 					error = TRUE;
@@ -142,7 +150,7 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "fitcircle %s - find best-fitting great circle to points on sphere\n\n", GMT_VERSION);
-		fprintf(stderr,"usage:  fitcircle [<input_file>] -L[<n>] [%s] [-S] [-V] [%s]\n", GMT_H_OPT, GMT_t_OPT);
+		fprintf(stderr,"usage:  fitcircle [<input_file>] -L[<n>] [%s] [-S[<lat>]] [-V] [%s]\n", GMT_H_OPT, GMT_t_OPT);
 		fprintf(stderr,"\t[%s] [%s]\n\n", GMT_bi_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -152,6 +160,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		GMT_explain_option ('H');
 		fprintf(stderr,"\t-S will attempt to fit a small circle rather than a great circle.\n");
+		fprintf(stderr,"\t   Optionally append the latitude of the small circle you want to fit\n");
 		GMT_explain_option ('V');
 		GMT_explain_option (':');
 		GMT_explain_option ('i');
@@ -178,7 +187,7 @@ int main (int argc, char **argv)
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 
@@ -194,7 +203,7 @@ int main (int argc, char **argv)
 
 	data = (struct FITCIRCLE_DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct FITCIRCLE_DATA), GMT_program);
 
-	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (format, BUFSIZ, fp);
+	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (format, BUFSIZ, fp);
 
 	sprintf (format, "%s\t%s", gmtdefs.d_format, gmtdefs.d_format);
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 2;
@@ -202,29 +211,30 @@ int main (int argc, char **argv)
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %d\n", GMT_program, n_fields,  n_expected_fields, n_data);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_data);
 			exit (EXIT_FAILURE);
 		}
 
-		lonsum += in[0];
-		latsum += in[1];
-		GMT_geo_to_cart (&in[1], &in[0], data[n_data].x, TRUE);
+		lonsum += in[GMT_X];
+		latsum += in[GMT_Y];
+		GMT_geo_to_cart (in[GMT_Y], in[GMT_X], data[n_data].x, TRUE);
 		n_data++;
 
 		if (n_data == n_alloc) {
-			n_alloc += GMT_CHUNK;
+			n_alloc <<= 1;
       			data = (struct FITCIRCLE_DATA *) GMT_memory ((void *)data, (size_t)n_alloc, sizeof(struct FITCIRCLE_DATA), GMT_program);
 	        }
         }
         if (fp != GMT_stdin) GMT_fclose(fp);
         
       	data = (struct FITCIRCLE_DATA *) GMT_memory ((void *)data, (size_t)n_data, sizeof(struct FITCIRCLE_DATA), GMT_program);
-	if (Ctrl->S.active && (Ctrl->L.norm%2) ) work = (double *) GMT_memory (VNULL, (size_t)n_data, sizeof(double), GMT_program);
+	allocate = (Ctrl->S.active && (Ctrl->L.norm%2)) ;
+	if (allocate) work = (double *) GMT_memory (VNULL, (size_t)n_data, sizeof(double), GMT_program);
 
 	lonsum /= n_data;
 	latsum /= n_data;
 	if (gmtdefs.verbose) {
-		fprintf (stderr, "%s: %d points read, Average Position (Flat Earth): ", GMT_program, n_data);
+		fprintf (stderr, "%s: %ld points read, Average Position (Flat Earth): ", GMT_program, n_data);
 		fprintf (stderr, format, lonsum, latsum);
 		fprintf (stderr, "\n");
 	}
@@ -268,13 +278,13 @@ int main (int argc, char **argv)
 		fprintf (GMT_stdout, format, lonsum, latsum);
 		fprintf (GMT_stdout, "\tL1 N Hemisphere Great Circle Pole (Cross-Averaged)\n");
 		latsum = -latsum;
-		lonsum = d_atan2(-cross_sum[1], -cross_sum[0]) * R2D;
+		lonsum = d_atan2d(-cross_sum[1], -cross_sum[0]);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
 		fprintf (GMT_stdout, format, lonsum, latsum);
 		fprintf (GMT_stdout, "\tL1 S Hemisphere Great Circle Pole (Cross-Averaged)\n");
 		if (Ctrl->S.active) {
 			if (gmtdefs.verbose) fprintf (stderr,"Fitting small circle using L1 norm.\n");
-			rad = get_small_circle (data, n_data, meanv, gcpole, scpole, 1, work);
+			rad = get_small_circle (data, n_data, meanv, gcpole, scpole, 1, work, Ctrl->S.mode, Ctrl->S.lat);
 			if (rad >= 0.0) {
 				GMT_cart_to_geo (&latsum, &lonsum, scpole, TRUE);
 				if (greenwich && lonsum < 0.0) lonsum += 360.0;
@@ -305,7 +315,7 @@ int main (int argc, char **argv)
 			fprintf(stderr,"%s: Eigenvalue routine failed to converge in 50 sweeps.\n", GMT_program);
 			fprintf(stderr,"%s: The reported L2 positions might be garbage.\n", GMT_program);
 		}
-		if (gmtdefs.verbose) fprintf(stderr,"%s: Eigenvalue routine converged in %d rotations.\n", GMT_program, nrots);
+		if (gmtdefs.verbose) fprintf(stderr,"%s: Eigenvalue routine converged in %ld rotations.\n", GMT_program, nrots);
 		imax = 0;
 		imin = 2;
 		if (d_acos (GMT_dot3v (v, meanv)) > M_PI_2)
@@ -327,7 +337,7 @@ int main (int argc, char **argv)
 		fprintf (GMT_stdout, format, lonsum, latsum);
 		fprintf (GMT_stdout, "\tL2 N Hemisphere Great Circle Pole (Eigenval Method)\n");
 		latsum = -latsum;
-		lonsum = d_atan2(-gcpole[1], -gcpole[0]) * R2D;
+		lonsum = d_atan2d(-gcpole[1], -gcpole[0]);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
 		fprintf (GMT_stdout, format, lonsum, latsum);
 		fprintf (GMT_stdout, "\tL2 S Hemisphere Great Circle Pole (Eigenval Method)\n");
@@ -339,7 +349,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *)a);
 		if (Ctrl->S.active) {
 			if (gmtdefs.verbose) fprintf(stderr,"%s: Fitting small circle using L2 norm.\n", GMT_program);
-			rad = get_small_circle(data, n_data, meanv, gcpole, scpole, 2, work);
+			rad = get_small_circle(data, n_data, meanv, gcpole, scpole, 2, work, Ctrl->S.mode, Ctrl->S.lat);
 			if (rad >= 0.0) {
 				/* True when small circle fits better than great circle */
 				GMT_cart_to_geo (&latsum, &lonsum, scpole, TRUE);
@@ -351,17 +361,17 @@ int main (int argc, char **argv)
 			}
 		}
 	}
-	if (Ctrl->S.active && (Ctrl->L.norm%2) ) GMT_free ((void *)work);
+	if (allocate) GMT_free ((void *)work);
 	GMT_free ((void *)data);
 
-	Free_Fitcircle_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_fitcircle_Ctrl (Ctrl);	/* Deallocate control structure */
 	
 	GMT_end (argc, argv);
 	
 	exit (EXIT_SUCCESS);
 }
 
-double	get_small_circle (struct FITCIRCLE_DATA *data, int ndata, double *center, double *gcpole, double *scpole, int norm, double *work)
+double	get_small_circle (struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *center, double *gcpole, double *scpole, GMT_LONG norm, double *work, GMT_LONG mode, double slat)
 {
 
 	/* Find scpole, the pole to the best-fit small circle, 
@@ -369,10 +379,10 @@ double	get_small_circle (struct FITCIRCLE_DATA *data, int ndata, double *center,
 		center and +/- gcpole, the pole to the best fit
 		great circle.  */
 
-	int	i, j;
+	GMT_LONG	i, j;
 	double	temppole[3], a[3], b[3], oldpole[3];
 	double	trypos, tryneg, afit, bfit, afactor, bfactor, fit, oldfit;
-	double	length_ab, length_aold, length_bold, circle_misfit(struct FITCIRCLE_DATA *data, int ndata, double *pole, int norm, double *work, double *circle_distance), circle_distance;
+	double	length_ab, length_aold, length_bold, circle_misfit(struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *pole, GMT_LONG norm, double *work, double *circle_distance), circle_distance;
 
 	/* First find out if solution is between center and gcpole,
 		or center and -gcpole:  */
@@ -394,16 +404,26 @@ double	get_small_circle (struct FITCIRCLE_DATA *data, int ndata, double *center,
 		for (i = 0; i < 3; i++) b[i] = gcpole[i];
 	}
 
-	/* Now a is at center and b is at pole on correct side.
-		Try to bracket a minimum.  Move from b toward
+	/* Now a is at center and b is at pole on correct side. */
+	
+	if (mode) {	/* Want a specified latitude */
+		afactor = sind (slat);
+		bfactor = cosd (slat);
+		for (i = 0; i < 3; i++) scpole[i] = (afactor * a[i] + bfactor * b[i]);
+		GMT_normalize3v (scpole);
+		fit = circle_misfit (data, ndata, scpole, norm, work, &circle_distance);
+		return (90.0-slat);
+	}
+	
+	/* Try to bracket a minimum.  Move from b toward
 	a in 1 degree steps:  */
 
 	afit = circle_misfit(data, ndata, a, norm, work, &circle_distance);
 	bfit = circle_misfit(data, ndata, b, norm, work, &circle_distance);
 	j = 1;
 	do {
-		afactor = sin(j * D2R);
-		bfactor = cos(j * D2R);
+		afactor = sind(j);
+		bfactor = cosd(j);
 		for (i = 0; i < 3; i++) temppole[i] = (afactor * a[i] + bfactor * b[i]);
 		GMT_normalize3v (temppole);
 		fit = circle_misfit(data, ndata, temppole, norm, work, &circle_distance);
@@ -471,13 +491,13 @@ double	get_small_circle (struct FITCIRCLE_DATA *data, int ndata, double *center,
 	return (R2D * circle_distance);
 }
 
-double	circle_misfit(struct FITCIRCLE_DATA *data, int ndata, double *pole, int norm, double *work, double *circle_distance)
+double	circle_misfit(struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *pole, GMT_LONG norm, double *work, double *circle_distance)
 {
 	/* Find the L(norm) misfit between a small circle through
 		center with pole pole.  Return misfit in radians.  */
 
 	double	distance, delta_distance, misfit = 0.0;
-	int	i;
+	GMT_LONG	i;
 
 	/* At first, I thought we could use the center to define
 		circle_dist = distance between pole and center.
@@ -513,10 +533,10 @@ double	circle_misfit(struct FITCIRCLE_DATA *data, int ndata, double *pole, int n
 	return (norm == 1) ? misfit : sqrt (misfit);
 }
 
-void *New_Fitcircle_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_fitcircle_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct FITCIRCLE_CTRL *C;
 	
-	C = (struct FITCIRCLE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct FITCIRCLE_CTRL), "New_Fitcircle_Ctrl");
+	C = (struct FITCIRCLE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct FITCIRCLE_CTRL), "New_fitcircle_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -525,6 +545,6 @@ void *New_Fitcircle_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Fitcircle_Ctrl (struct FITCIRCLE_CTRL *C) {	/* Deallocate control structure */
+void Free_fitcircle_Ctrl (struct FITCIRCLE_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
