@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2rgb.c,v 1.55 2009/01/09 04:02:32 guru Exp $
+ *	$Id: gmt2rgb.c,v 1.59 2010/01/05 01:15:44 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -51,15 +51,15 @@ struct GMT2RGB_CTRL {
 	} L;
 	struct W {	/* -W<width/height>[/<n_bytes>] */
 		BOOLEAN active;
-		int nx, ny;	/* Dimension of image */
-		int size;	/* Number of bytes per pixels */
+		GMT_LONG nx, ny;	/* Dimension of image */
+		GMT_LONG size;	/* Number of bytes per pixels */
 	} W;
 };
 
 int main (int argc, char **argv)
 {
-	int i, error = 0, index, irgb[3], entry, one_or_zero, pos;
-	GMT_LONG nm, k, k3;
+	GMT_LONG i, error = 0, index, entry, one_or_zero, pos, nm, k, k3;
+	int irgb[3];
 	BOOLEAN guess = FALSE;
 	float *z;
 	double w, e, s, n;
@@ -70,13 +70,13 @@ int main (int argc, char **argv)
 	unsigned char *picture;
 	struct GMT2RGB_CTRL *Ctrl;
 	
-	void guess_width (char *file, int byte_per_pixel, int *raw_nx, int *raw_ny);
-	unsigned char *loadraw (char *file, struct imageinfo *header, int byte_per_pixel, int nx, int ny);
-	void *New_Gmt2rgb_Ctrl (), Free_Gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C);
+	void guess_width (char *file, GMT_LONG byte_per_pixel, GMT_LONG *raw_nx, GMT_LONG *raw_ny);
+	unsigned char *loadraw (char *file, struct imageinfo *header, GMT_LONG byte_per_pixel, GMT_LONG nx, GMT_LONG ny);
+	void *New_gmt2rgb_Ctrl (), Free_gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GMT2RGB_CTRL *)New_Gmt2rgb_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GMT2RGB_CTRL *)New_gmt2rgb_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -209,11 +209,11 @@ int main (int argc, char **argv)
 			guess_width (file, Ctrl->W.size, &Ctrl->W.nx, &Ctrl->W.ny);
 
 		if (Ctrl->W.active && Ctrl->W.nx <= 0) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Witdth of raw raster file must be a positive integer. Not %d\n", GMT_program, Ctrl->W.nx);
+			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Witdth of raw raster file must be a positive integer. Not %ld\n", GMT_program, Ctrl->W.nx);
 			error++;
 		}
 		if (Ctrl->W.active && Ctrl->W.ny <= 0) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Height of raw raster file must be a positive integer. Not %d\n", GMT_program, Ctrl->W.ny);
+			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Height of raw raster file must be a positive integer. Not %ld\n", GMT_program, Ctrl->W.ny);
 			error++;
 		}
 	}
@@ -344,14 +344,14 @@ int main (int argc, char **argv)
 	}
 	GMT_free ((void *)z);
 
-	Free_Gmt2rgb_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_gmt2rgb_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-unsigned char *loadraw (char *file, struct imageinfo *header, int byte_per_pixel, int nx, int ny) {
+unsigned char *loadraw (char *file, struct imageinfo *header, GMT_LONG byte_per_pixel, GMT_LONG nx, GMT_LONG ny) {
 	/* loadraw reads a raw binary grb or rgba rasterfile of depth 24, or 32 into memory */
 
 	GMT_LONG j, i, nm;
@@ -393,11 +393,11 @@ unsigned char *loadraw (char *file, struct imageinfo *header, int byte_per_pixel
 	return (buffer);
 }
 
-void guess_width (char *file, int byte_per_pixel, int *raw_nx, int *raw_ny) {
+void guess_width (char *file, GMT_LONG byte_per_pixel, GMT_LONG *raw_nx, GMT_LONG *raw_ny) {
 	unsigned char *buffer;
 	float	*work, *datac, *img_pow, pow_max = -FLT_MAX, pm;
-	int	k = 0, j, rgb[3], inc, i, l, even;
-	GMT_LONG narray, img_size, n_pix;
+	GMT_LONG k = 0, j, inc, i, l, even, narray, img_size, n_pix;
+	int rgb[3];
 	FILE *fp;
 
 	if ((fp = GMT_fopen (file, "rb")) == NULL) {
@@ -471,7 +471,7 @@ void guess_width (char *file, int byte_per_pixel, int *raw_nx, int *raw_ny) {
 			j = (*raw_nx) + (int)irint (copysign((double)l, (double)pm));
 			if (i*j == n_pix) {	/* Got a good candidate */
 				*raw_ny = i;	*raw_nx = j;
-				fprintf (stderr, "... SUCESS (W = %d, H = %d)\n", *raw_nx, *raw_ny);
+				fprintf (stderr, "... SUCESS (W = %ld, H = %ld)\n", *raw_nx, *raw_ny);
 				break;
 			}
 			even = (k%2 == 0) ? 1: 0;
@@ -480,11 +480,11 @@ void guess_width (char *file, int byte_per_pixel, int *raw_nx, int *raw_ny) {
 		}
 	}
 	else
-		if (gmtdefs.verbose) fprintf (stderr, "File %s has %d Lines and %d Cols\n", file, *raw_ny, *raw_nx);
+		if (gmtdefs.verbose) fprintf (stderr, "File %s has %ld Lines and %ld Cols\n", file, *raw_ny, *raw_nx);
 
 	/* If both attempts failed */
 	if ((*raw_nx) * (*raw_ny) != n_pix) {
-		fprintf (stderr, "FAILURE while guessing image dimensions (W = %d, H = %d)\n", *raw_nx, *raw_ny);
+		fprintf (stderr, "FAILURE while guessing image dimensions (W = %ld, H = %ld)\n", *raw_nx, *raw_ny);
 		exit (EXIT_FAILURE);
 	}
 
@@ -495,10 +495,10 @@ void guess_width (char *file, int byte_per_pixel, int *raw_nx, int *raw_ny) {
 	GMT_free ((void *)img_pow);
 }
 
-void *New_Gmt2rgb_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_gmt2rgb_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GMT2RGB_CTRL *C;
 	
-	C = (struct GMT2RGB_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMT2RGB_CTRL), "New_Gmt2rgb_Ctrl");
+	C = (struct GMT2RGB_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMT2RGB_CTRL), "New_gmt2rgb_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -508,7 +508,7 @@ void *New_Gmt2rgb_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C) {	/* Deallocate control structure */
+void Free_gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	if (C->G.name) free ((void *)C->G.name);	
 	GMT_free ((void *)C);	
