@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_customio.c,v 1.86 2009/09/14 00:16:00 jluis Exp $
+ *	$Id: gmt_customio.c,v 1.89 2010/01/05 01:15:44 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -1774,8 +1774,8 @@ GMT_LONG GMT_gdal_read_grd_info (struct GRD_HEADER *header) {
 	}
 
 	/* Allocate new control structures */
-	to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_Gdalread_Ctrl");
-	from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_Gd_Ctrl");
+	to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_gdalread_Ctrl");
+	from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_gd_Ctrl");
 
 	to_gdalread->M.active = 1;		/* Metadata only */
 	to_gdalread->C.active = 1;		/* Force info in grid registration */
@@ -1824,8 +1824,8 @@ GMT_LONG GMT_gdal_read_grd (struct GRD_HEADER *header, float *grid, double w, do
 	char	strR [128]; 
 
 	/* Allocate new control structures */
-	to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_Gdalread_Ctrl");
-	from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_Gd_Ctrl");
+	to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_gdalread_Ctrl");
+	from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_gd_Ctrl");
 
 	to_gdalread->C.active = 1;		/* Force info in grid node registration */
 	if (w != 0 || e != 0 || s != 0 || n != 0) {	/* We have a Sub-region demand */
@@ -1889,7 +1889,6 @@ GMT_LONG GMT_gdal_read_grd (struct GRD_HEADER *header, float *grid, double w, do
 
 	GMT_free((void *) to_gdalread);
 	if (from_gdalread->ColorMap == NULL) GMT_free((void *) from_gdalread->ColorMap);
-	GMT_free((void *) from_gdalread);
 
 	if (from_gdalread->UInt8.active)
 		GMT_free ((void *)from_gdalread->UInt8.data);
@@ -1902,6 +1901,8 @@ GMT_LONG GMT_gdal_read_grd (struct GRD_HEADER *header, float *grid, double w, do
 	else if (from_gdalread->Int32.active)
 		GMT_free ((void *)from_gdalread->Int32.data);
 
+	GMT_free((void *) from_gdalread);
+
 	return (GMT_NOERROR);
 }
 
