@@ -4,7 +4,7 @@ struct Z {	/* -Z[<flags>] */
 	BOOLEAN repeat[2];
 	char format[2];
 	char type;
-	int skip;
+	GMT_LONG skip;
 };
 
 GMT_LONG GMT_parse_z_io (char *txt, struct Z *z)
