@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_shore.h,v 1.21 2009/01/16 21:43:11 guru Exp $
+ *	$Id: gmt_shore.h,v 1.29 2010/01/05 01:15:45 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -24,35 +24,60 @@
  *
  * Author:	Paul Wessel
  * Date:	12-AUG-1995
- * Revised:	15-AUG-1998
- * Version:	4.1.x
+ * Revised:	6-NOV-2009
+ * Version:	4.5.2
  */
 
 #include "netcdf.h"
 
-#define GSHHS_MAX_DELTA 65535	/* Largest value to store in a unsigned short, used as largest dx or dy in bin  */
+#define GSHHS_MAX_DELTA		65535	/* Largest value to store in a unsigned short, used as largest dx or dy in bin  */
 #define GMT_MAX_GSHHS_LEVEL	4	/* Highest hierarchical level of coastlines */
 
 #define GMT_N_BLEVELS		3	/* Number of levels for borders */
-#define GMT_N_RLEVELS		10	/* Number of levels for rivers */
+#define GMT_N_RLEVELS		11	/* Number of levels for rivers */
+#define GMT_RIV_INTERMITTENT	5	/* Id for intermittent rivers */
+#define GMT_RIV_CANALS		8	/* Id for river canals */
 
-struct GMT_SHORE {
+#define GMT_NO_RIVERLAKES	1
+#define GMT_NO_LAKES		2
+
+struct GMT_SHORE_SELECT {	/* Information on levels and min area to use */
+	int low;	/* Lowest hierarchical level to use [0] */
+	int high;	/* Highest hierarchical level to use [4] */
+	int flag;	/* 1 = no riverlakes from level 2; 2 = only riverlakes from level 2 */
+	int fraction;	/* If not 0, the microfraction limit on a polygons area vs the full resolution version */
+	double area;	/* Area of smallest geographical feature to include [0] */
+};
+
+struct GMT_GSHHS_pol {	/* Information pertaining to each GSHHS polygon */
+	int *parent;		/* Array with ids of the parent polygon for each GSHHS polygon (-1 for all level 1 polygons) */
+	int *area;		/* Array with areas in 10*km^2 of the GSHHS polygons */
+	int *area_fraction;	/* Array with micro-fraction fractions of area relative to full res area  */
+};
+
+struct GMT_SHORE {	/* Struct used by pscoast and others */
 
 	/* Global variables that remain fixed for all bins */
 	
-	int nb;			/* Number of bins to use */
-	int *bins;		/* Array with the nb bin numbers to use */
+	GMT_LONG nb;		/* Number of bins to use */
+	GMT_LONG *bins;		/* Array with the nb bin numbers to use */
+	GMT_LONG min_level;	/* Lowest level to include [0] */
+	GMT_LONG max_level;	/* Highest level to include [4] */
+	GMT_LONG flag;		/* If riverlakes or lakes are to be excluded */
+	GMT_LONG fraction;	/* If not 0, the microfraction limit on a polygons area vs the full resolution version */
+	double min_area;	/* Smallest feature to include in km^2 */
 	double scale;		/* Multiplier to convert dx, dy back to dlon, dlat in degrees */
 	
 	/* Variables associated with the current bin */
 	
-	int ns;			/* Number of segments to use in current bin */
+	GMT_LONG ns;			/* Number of segments to use in current bin */
 	unsigned char node_level[4];
 	struct GMT_SHORE_SEGMENT *seg;	/* Array of these segments */
-	struct GSHHS_SIDE *side[4];		/* Has position & id for each side exit/entry */
-	int nside[4];			/* Number of entries per side, including corner */
-	int n_entries;
+	struct GSHHS_SIDE *side[4];	/* Has position & id for each side exit/entry */
+	GMT_LONG nside[4];		/* Number of entries per side, including corner */
+	GMT_LONG n_entries;
 	BOOLEAN leftmost_bin;		/* TRUE if current bin is at left edge of map */
+	BOOLEAN skip_feature;		/* TRUE if GSHHS version > 2.0 and +r or +l is in use */
 	double bsize;			/* Size of square bins in degrees */
 	double lon_sw;			/* Longitude of SW corner */
 	double lat_sw;			/* Latitude of SW corner */
@@ -61,48 +86,63 @@ struct GMT_SHORE {
 
 	/* Data variables associated with shoreline database */
 	
-	int bin_size;	/* Size of square bins in minutes */
+	int bin_size;		/* Size of square bins in minutes */
 	int bin_nx;		/* Number of bins in 360 degrees of longitude */
 	int bin_ny;		/* Number of bins in 180 degrees of latitude */
+	int n_poly;		/* Number of polygons present in the data set */
 	int n_bin;		/* Number of bins present in the data set */
 	int n_seg;		/* Number of segments present in the data set */
 	int n_pt;		/* Number of points present in the data set */
+	int n_nodes;		/* Number of grid nodes present in the data set */
 	
+	int *GSHHS_node;	/* Array with ids of the polygon that enclose each node */
 	int *bin_firstseg;	/* Array with ids of first segment per bin */
 	short int *bin_info;	/* Array with levels of all 4 nodes per bin */
 	short int *bin_nseg;	/* Array with number of segments per bin */
 	
+	int *GSHHS_parent;		/* Array with ids of the parent polygon for each GSHHS polygon (-1 for all level 1 polygons) */
+	int *GSHHS_area;		/* Array with areas in 10*km^2 of the GSHHS polygons */
+	int *GSHHS_area_fraction;	/* Array with micro-fraction fractions of area relative to full res area  */
+
 	char units[80];		/* Units of lon/lat */
 	char title[80];		/* Title of data set */
 	char source[80];	/* Source of data set */
+	char version[8];	/* Version of data set */
 
 	/* netCDF ID variables */
 	
-	int cdfid;		/* File id for coastbin file */
+	int cdfid;		/* netCDF File id for coastbin file */
 	
 	int bin_size_id;	/* Id for variable bin_size */
 	int bin_nx_id;		/* Id for variable bin_nx */
 	int bin_ny_id;		/* Id for variable bin_ny */
+	int n_poly_id;		/* Id for variable n_bin */
 	int n_bin_id;		/* Id for variable n_bin */
 	int n_seg_id;		/* Id for variable n_seg */
 	int n_pt_id;		/* Id for variable n_pt */
+	int n_node_id;		/* Id for variable n_nodes */
 	int bin_firstseg_id;	/* Id for variable bin_firstseg */
 	int bin_info_id;	/* Id for variable bin_info */
 	int bin_nseg_id;	/* Id for variable bin_nseg */
 	
 	int seg_info_id;	/* Id for variable seg_info */
-	int seg_area_id;	/* Id for variable seg_area */
 	int seg_start_id;	/* Id for variable seg_start */
+	int seg_GSHHS_ID_id;	/* Id for variable seg_GSHHS_ID */
+	
+	int GSHHS_parent_id;	/* Id for variable GSHHS_parent */
+	int GSHHS_area_id;	/* Id for variable GSHHS_area */
+	int GSHHS_areafrac_id;	/* Id for variable GSHHS_area_fraction */
+	int GSHHS_node_id;	/* Id for variable GSHHS_node_id */
 	
 	int pt_dx_id;		/* Id for variable pt_dx */
 	int pt_dy_id;		/* Id for variable pt_dy */
-	
 };
 
 struct GMT_SHORE_SEGMENT {
 	unsigned char level;	/* Level of polygon segment (1 i ocean/land, 2 = land/lake, 3 = lake/island, etc) */
 	unsigned char entry;	/* Side (0-3) the segment starts on, or 4 for closed segments */
 	unsigned char exit;	/* Side (0-3) the segment ends on, or 4 for closed segments */
+	unsigned char fid;	/* Fill id (same as level expect for riverlakes which is 5) */
 	unsigned short n;	/* Number of points in segment */
 	short int *dx;		/* Array of scaled longitudes relative to SW corner */
 	short int *dy;		/* Array of scaled latitudes relative to SW corner */
@@ -110,20 +150,20 @@ struct GMT_SHORE_SEGMENT {
 
 struct GSHHS_SIDE {
 	unsigned short pos;	/* Position along side in 0-65535 range */
-	short int id;	/* Local segment id */
+	short int id;		/* Local segment id */
 };
 
 struct GMT_BR {	/* Structure for Borders and Rivers */
 
 	/* Global variables that remain fixed for all bins */
 	
-	int nb;			/* Number of bins to use */
-	int *bins;		/* Array with the nb bin numbers to use */
+	GMT_LONG nb;		/* Number of bins to use */
+	GMT_LONG *bins;		/* Array with the nb bin numbers to use */
 	double scale;		/* Multiplier to convert dx, dy back to dlon, dlat in degrees */
 	
 	/* Variables associated with the current bin */
 	
-	int ns;			/* Number of segments to use in current bin */
+	GMT_LONG ns;		/* Number of segments to use in current bin */
 	struct GMT_BR_SEGMENT *seg;	/* Array of these segments */
 	double lon_sw;		/* Longitude of SW corner */
 	double lat_sw;		/* Latitude of SW corner */
@@ -132,8 +172,8 @@ struct GMT_BR {	/* Structure for Borders and Rivers */
 	/* Data variables associated with shoreline database */
 	
 	int bin_size;	/* Size of square bins in minutes */
-	int bin_nx;		/* Number of bins in 360 degrees of longitude */
-	int bin_ny;		/* Number of bins in 180 degrees of latitude */
+	int bin_nx;	/* Number of bins in 360 degrees of longitude */
+	int bin_ny;	/* Number of bins in 180 degrees of latitude */
 	int n_bin;		/* Number of bins present in the data set */
 	int n_seg;		/* Number of segments present in the data set */
 	int n_pt;		/* Number of points present in the data set */
@@ -144,6 +184,7 @@ struct GMT_BR {	/* Structure for Borders and Rivers */
 	char units[80];		/* Units of lon/lat */
 	char title[80];		/* Title of data set */
 	char source[80];	/* Source of data set */
+	char version[8];	/* Version of data set */
 
 	/* netCDF ID variables */
 	
@@ -164,7 +205,6 @@ struct GMT_BR {	/* Structure for Borders and Rivers */
 	
 	int pt_dx_id;		/* Id for variable pt_dx */
 	int pt_dy_id;		/* Id for variable pt_dy */
-	
 };
 
 struct GMT_BR_SEGMENT {
@@ -177,26 +217,28 @@ struct GMT_BR_SEGMENT {
 struct GMT_GSHHS_POL {
 	GMT_LONG n;
 	BOOLEAN interior;	/* TRUE if polygon is inside bin */
-	int level;
+	GMT_LONG level;
+	GMT_LONG fid;		/* Fill id; same as level but 5 if riverlake */
 	double *lon;
 	double *lat;
 };
 
 /* Public functions */
 
-EXTERN_MSC int GMT_get_shore_bin (int b, struct GMT_SHORE *c, double min_area, int min_level, int max_level);
-EXTERN_MSC int GMT_get_br_bin (int b, struct GMT_BR *c, int *level, int n_levels);
-EXTERN_MSC void GMT_free_polygons (struct GMT_GSHHS_POL *p, int n);
+EXTERN_MSC void GMT_set_levels (char *info, struct GMT_SHORE_SELECT *I);
+EXTERN_MSC GMT_LONG GMT_get_shore_bin (GMT_LONG b, struct GMT_SHORE *c);
+EXTERN_MSC GMT_LONG GMT_get_br_bin (GMT_LONG b, struct GMT_BR *c, GMT_LONG *level, GMT_LONG n_levels);
+EXTERN_MSC void GMT_free_polygons (struct GMT_GSHHS_POL *p, GMT_LONG n);
 EXTERN_MSC void GMT_free_shore (struct GMT_SHORE *c);
 EXTERN_MSC void GMT_free_br (struct GMT_BR *c);
 EXTERN_MSC void GMT_shore_cleanup (struct GMT_SHORE *c);
 EXTERN_MSC void GMT_br_cleanup (struct GMT_BR *c);
-EXTERN_MSC int GMT_init_shore (char res, struct GMT_SHORE *c, double w, double e, double s, double n);
-EXTERN_MSC int GMT_init_br (char which, char res, struct GMT_BR *c, double w, double e, double s, double n);
-EXTERN_MSC int GMT_assemble_shore (struct GMT_SHORE *c, int dir, int first_level, BOOLEAN assemble, BOOLEAN shift, double west, double east, struct GMT_GSHHS_POL **pol);
-EXTERN_MSC int GMT_assemble_br (struct GMT_BR *c, BOOLEAN shift, double edge, struct GMT_GSHHS_POL **pol);
-EXTERN_MSC int GMT_prep_polygons (struct GMT_GSHHS_POL **p, int np, BOOLEAN sample, double step, int anti_bin);
-EXTERN_MSC int GMT_set_resolution (char *res, char opt);
+EXTERN_MSC GMT_LONG GMT_init_shore (char res, struct GMT_SHORE *c, double w, double e, double s, double n, struct GMT_SHORE_SELECT *I);
+EXTERN_MSC GMT_LONG GMT_init_br (char which, char res, struct GMT_BR *c, double w, double e, double s, double n);
+EXTERN_MSC GMT_LONG GMT_assemble_shore (struct GMT_SHORE *c, GMT_LONG dir, BOOLEAN assemble, BOOLEAN shift, double west, double east, struct GMT_GSHHS_POL **pol);
+EXTERN_MSC GMT_LONG GMT_assemble_br (struct GMT_BR *c, BOOLEAN shift, double edge, struct GMT_GSHHS_POL **pol);
+EXTERN_MSC GMT_LONG GMT_prep_polygons (struct GMT_GSHHS_POL **p, GMT_LONG np, BOOLEAN sample, double step, GMT_LONG anti_bin);
+EXTERN_MSC GMT_LONG GMT_set_resolution (char *res, char opt);
 EXTERN_MSC char GMT_shore_adjust_res (char res);
 
 #endif /* _GMT_SHORE_H */
