@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtconvert.c,v 1.66 2009/09/09 23:27:02 guru Exp $
+ *	$Id: gmtconvert.c,v 1.69 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -79,11 +79,11 @@ int main (int argc, char **argv)
 
 	struct GMTCONVERT_CTRL *Ctrl;
 
-	void *New_Gmtconvert_Ctrl (), Free_Gmtconvert_Ctrl (struct GMTCONVERT_CTRL *C);
+	void *New_gmtconvert_Ctrl (), Free_gmtconvert_Ctrl (struct GMTCONVERT_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GMTCONVERT_CTRL *)New_Gmtconvert_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GMTCONVERT_CTRL *)New_gmtconvert_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -472,7 +472,7 @@ int main (int argc, char **argv)
 				while (GMT_REC_IS_NEW_SEGMENT && !GMT_REC_IS_EOF) {
 					if (Ctrl->E.active && (Ctrl->E.mode & 2) && n_in_seg > 0) fprintf (GMT_stdout, "%s", record_str);		/* Previous segments last point */
 					if (Ctrl->S.active) {	/* See if this header has text matching our search string */
-						match = !strstr (GMT_io.segment_header, Ctrl->S.pattern);
+						match = (strstr (GMT_io.segment_header, Ctrl->S.pattern) != NULL);	/* TRUE if we matched */
 						on = (Ctrl->S.inverse == !match);	/* If match then we turn output ON */
 					}
 					if (ascii_in_bin_out && n_out == 0)
@@ -565,17 +565,17 @@ int main (int argc, char **argv)
 	
 	GMT_free ((void *)out);
 
-	Free_Gmtconvert_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_gmtconvert_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Gmtconvert_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_gmtconvert_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GMTCONVERT_CTRL *C;
 	
-	C = (struct GMTCONVERT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMTCONVERT_CTRL), "New_Gmtconvert_Ctrl");
+	C = (struct GMTCONVERT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMTCONVERT_CTRL), "New_gmtconvert_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -584,7 +584,7 @@ void *New_Gmtconvert_Ctrl () {	/* Allocate and initialize a new control structur
 	return ((void *)C);
 }
 
-void Free_Gmtconvert_Ctrl (struct GMTCONVERT_CTRL *C) {	/* Deallocate control structure */
+void Free_gmtconvert_Ctrl (struct GMTCONVERT_CTRL *C) {	/* Deallocate control structure */
 	if (C->D.name) free ((void *)C->D.name);	
 	if (C->F.col) GMT_free ((void *)C->F.col);	
 	if (C->S.pattern) free ((void *)C->S.pattern);	
