@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtselect.c,v 1.106 2009/09/09 23:27:03 guru Exp $
+ *	$Id: gmtselect.c,v 1.108 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -132,11 +132,11 @@ int main (int argc, char **argv)
 	PFL near_a_line, near_a_point;
 
 	int compare_x (const void *point_1, const void *point_2);
-	void *New_Gmtselect_Ctrl (), Free_Gmtselect_Ctrl (struct GMTSELECT_CTRL *C);
+	void *New_gmtselect_Ctrl (), Free_gmtselect_Ctrl (struct GMTSELECT_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GMTSELECT_CTRL *) New_Gmtselect_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct GMTSELECT_CTRL *) New_gmtselect_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -754,7 +754,7 @@ int main (int argc, char **argv)
 		}
 	}
 	
-	Free_Gmtselect_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_gmtselect_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -776,11 +776,11 @@ int compare_x (const void *point_1, const void *point_2)
 		return (0);
 }
 
-void *New_Gmtselect_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_gmtselect_Ctrl () {	/* Allocate and initialize a new control structure */
 	GMT_LONG i;
 	struct GMTSELECT_CTRL *C;
 	
-	C = (struct GMTSELECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMTSELECT_CTRL), "New_Gmtselect_Ctrl");
+	C = (struct GMTSELECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMTSELECT_CTRL), "New_gmtselect_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -794,7 +794,7 @@ void *New_Gmtselect_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Gmtselect_Ctrl (struct GMTSELECT_CTRL *C) {	/* Deallocate control structure */
+void Free_gmtselect_Ctrl (struct GMTSELECT_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	if (C->F.file) free ((void *)C->F.file);	
 	if (C->L.file) free ((void *)C->L.file);	
