@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtset.c,v 1.28 2009/01/09 04:02:33 guru Exp $
+ *	$Id: gmtset.c,v 1.31 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 
 int main (int argc, char **argv)
 {
-	int i, j;
+	GMT_LONG i, j;
 	char *file = CNULL;
 
 	/* SPECIAL INITIALIZATION SINCE BMT_begin IS NOT USED HERE !! */
