@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grd2cpt.c,v 1.56 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grd2cpt.c,v 1.58 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -107,11 +107,11 @@ int main (int argc, char **argv)
 
 	FILE	*fpc = NULL;
 
-	void *New_Grd2cpt_Ctrl (), Free_Grd2cpt_Ctrl (struct GRD2CPT_CTRL *C);
+	void *New_grd2cpt_Ctrl (), Free_grd2cpt_Ctrl (struct GRD2CPT_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRD2CPT_CTRL *)New_Grd2cpt_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRD2CPT_CTRL *)New_grd2cpt_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	w = e = s = n = 0.0;
 
@@ -505,23 +505,23 @@ int main (int argc, char **argv)
 	GMT_free ((void *)zdata);
 	GMT_free ((void *)z);
 
-	Free_Grd2cpt_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grd2cpt_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grd2cpt_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grd2cpt_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRD2CPT_CTRL *C;
 
-	C = (struct GRD2CPT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRD2CPT_CTRL), "New_Grd2cpt_Ctrl");
+	C = (struct GRD2CPT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRD2CPT_CTRL), "New_grd2cpt_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	return ((void *)C);
 }
 
-void Free_Grd2cpt_Ctrl (struct GRD2CPT_CTRL *C) {	/* Deallocate control structure */
+void Free_grd2cpt_Ctrl (struct GRD2CPT_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);
 	GMT_free ((void *)C);
 }
