@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grd2xyz.c,v 1.60 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grd2xyz.c,v 1.63 2010/01/11 16:56:58 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,10 @@ struct GRD2XYZ_CTRL {
 		BOOLEAN active;
 		double nodata;
 	} E;
+	struct N {	/* -N<nodata> */
+		BOOLEAN active;
+		double value;
+	} N;
 	struct S {	/* -S[r] */
 		BOOLEAN active;
 		BOOLEAN reverse;
@@ -59,11 +63,11 @@ int main (int argc, char **argv)
 	struct GMT_Z_IO io;
 	struct GRD2XYZ_CTRL *Ctrl;
 
-	void *New_Grd2xyz_Ctrl (), Free_Grd2xyz_Ctrl (struct GRD2XYZ_CTRL *C);
+	void *New_grd2xyz_Ctrl (), Free_grd2xyz_Ctrl (struct GRD2XYZ_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRD2XYZ_CTRL *)New_Grd2xyz_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRD2XYZ_CTRL *)New_grd2xyz_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	w = e = s = n = 0.0;
 
@@ -93,6 +97,16 @@ int main (int argc, char **argv)
 					GMT_io.out_col_type[0] = GMT_IS_LON;
 					GMT_io.out_col_type[1] = GMT_IS_LAT;
 					break;
+				case 'N':
+					if (!argv[i][2]) {
+						fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Must specify value or NaN\n", GMT_program);
+						error++;
+					}
+					else {
+						Ctrl->N.value = (argv[i][2] == 'N' || argv[i][2] == 'n') ? GMT_d_NaN : atof (&argv[i][2]);
+						Ctrl->N.active = TRUE;
+					}
+					break;
 				case 'Z':
 					Ctrl->Z.active = TRUE;
 					error += GMT_parse_z_io (&argv[i][2], &Ctrl->Z);
@@ -118,7 +132,7 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "grd2xyz %s - Converting netCDF grdfile(s) to ASCII xyz data\n\n", GMT_VERSION);
-		fprintf( stderr, "usage: grd2xyz <grdfiles> [-E[<nodata>]] [%s] [%s] [-S[r]] [-V]\n", GMT_Ho_OPT, GMT_Rgeo_OPT);
+		fprintf( stderr, "usage: grd2xyz <grdfiles> [-E[<nodata>]] [%s] [-N<nodata>] [%s] [-S[r]] [-V]\n", GMT_Ho_OPT, GMT_Rgeo_OPT);
 		fprintf( stderr, "\t[-W[<weight>]] [-Z[<flags>]] [%s] [%s] [%s] > xyzfile\n", GMT_t_OPT, GMT_bo_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -128,6 +142,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-E Write ESRI ArcInfo ASCII interchange format.  Only one grid file can be specified\n");
 		fprintf (stderr, "\t   Optionally append nodata value to represent NaNs [-9999]\n");
 		fprintf (stderr, "\t-H Write 1 ASCII header record [Default is no header]\n");
+		fprintf (stderr, "\t-N Replace z-values that equal NaN with this value [Default writes NaN]\n");
 		GMT_explain_option ('R');
 		fprintf (stderr, "\t-S Suppress output for nodes whose z equals NaN [Default prints all nodes]\n");
 		fprintf (stderr, "\t   Append r to reverse the suppression (only output NaN nodes)\n");
@@ -230,6 +245,7 @@ int main (int argc, char **argv)
 					continue;
 				}
 				if ((io.x_missing && io.gmt_i == io.x_period) || (io.y_missing && io.gmt_j == 0)) continue;
+				if (Ctrl->N.active && GMT_is_dnan (d_value)) d_value = Ctrl->N.value;
 				(io.write_item) (GMT_stdout, d_value);
 			}
 		}
@@ -294,12 +310,13 @@ int main (int argc, char **argv)
 			}
 
 			for (j = ij = 0; j < grd.ny; j++) for (i = 0; i < grd.nx; i++, ij++) {
-				out[2] = z[ij];
-				if (Ctrl->S.active && (GMT_is_dnan (out[2]) + Ctrl->S.reverse) == 1) {
+				out[GMT_Z] = z[ij];
+				if (Ctrl->S.active && (GMT_is_dnan (out[GMT_Z]) + Ctrl->S.reverse) == 1) {
 					n_suppressed++;
 					continue;
 				}
 				out[GMT_X] = x[i];	out[GMT_Y] = y[j];
+				if (Ctrl->N.active && GMT_is_dnan (out[GMT_Z])) out[GMT_Z] = Ctrl->N.value;
 				GMT_output (GMT_stdout, n_out, out);
 			}
 			GMT_free ((void *)x);
@@ -317,17 +334,17 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: %ld NaN values suppressed\n", GMT_program, n_suppressed);
 	}
 
-	Free_Grd2xyz_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grd2xyz_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grd2xyz_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grd2xyz_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRD2XYZ_CTRL *C;
 	
-	C = (struct GRD2XYZ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRD2XYZ_CTRL), "New_Grd2xyz_Ctrl");
+	C = (struct GRD2XYZ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRD2XYZ_CTRL), "New_grd2xyz_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -339,6 +356,6 @@ void *New_Grd2xyz_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Grd2xyz_Ctrl (struct GRD2XYZ_CTRL *C) {	/* Deallocate control structure */
+void Free_grd2xyz_Ctrl (struct GRD2XYZ_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
