@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *    $Id: grdblend.c,v 1.71 2009/01/09 04:02:33 guru Exp $
+ *    $Id: grdblend.c,v 1.80 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -67,9 +67,9 @@ struct GRDBLEND_CTRL {
 
 struct GRDBLEND_INFO {	/* Structure with info about each input grid file */
 	struct GMT_GRDFILE G;				/* I/O structure for grid files, including grd header */
-	int in_i0, in_i1, out_i0, out_i1;		/* Indices of outer and inner x-coordinates (in output grid coordinates) */
-	int in_j0, in_j1, out_j0, out_j1;		/* Indices of outer and inner y-coordinates (in output grid coordinates) */
-	int offset;					/* grid offset when the grid extends beyond north */
+	GMT_LONG in_i0, in_i1, out_i0, out_i1;		/* Indices of outer and inner x-coordinates (in output grid coordinates) */
+	GMT_LONG in_j0, in_j1, out_j0, out_j1;		/* Indices of outer and inner y-coordinates (in output grid coordinates) */
+	GMT_LONG offset;				/* grid offset when the grid extends beyond north */
 	long skip;					/* Byte offset to skip in native binary files */
 	BOOLEAN outside;				/* TRUE if the current output row is outside the range of this grid */
 	BOOLEAN invert;					/* TRUE if weight was given as negative and we want to taper to zero INSIDE the grid region */
@@ -82,24 +82,24 @@ struct GRDBLEND_INFO {	/* Structure with info about each input grid file */
 
 int main (int argc, char **argv)
 {
-	int i, col, pcol, row, nx_360 = 0, k, kk, m, n_blend, err, error = 0;
-	GMT_LONG n_fill, n_tot;
+	GMT_LONG i, col, pcol, row, nx_360 = 0, k, kk, m, n_blend, err, error = 0;
+	GMT_LONG n_fill, n_tot, type;
 	double wt_x, w, wt;
 	float *z, no_data_f;
-	char mode[2] = {'w', 'W'}, type;
+	char mode[2] = {'w', 'W'};
 	BOOLEAN wrap_x;
 	FILE *fp = NULL;
 	struct GRDBLEND_INFO *blend = NULL;
 	struct GMT_GRDFILE S;
 	struct GRDBLEND_CTRL *Ctrl;
 
-	void sync_input_rows (int row, struct GRDBLEND_INFO *blend, int n_blend, double half);
-	int init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend);
-	void *New_Grdblend_Ctrl (), Free_Grdblend_Ctrl (struct GRDBLEND_CTRL *C);
+	void sync_input_rows (GMT_LONG row, struct GRDBLEND_INFO *blend, GMT_LONG n_blend, double half);
+	GMT_LONG init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend);
+	void *New_grdblend_Ctrl (), Free_grdblend_Ctrl (struct GRDBLEND_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDBLEND_CTRL *)New_Grdblend_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDBLEND_CTRL *)New_grdblend_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	GMT_grd_init (&S.header, argc, argv, FALSE);
 
@@ -316,10 +316,10 @@ int main (int argc, char **argv)
 		}
 		GMT_err_fail (GMT_write_grd_row (&S, 0, z), Ctrl->G.file);
 
-		if (gmtdefs.verbose && row%10 == 0)  fprintf (stderr, "%s: Processed row %7d of %d\r", GMT_program, row, S.header.ny);
+		if (gmtdefs.verbose && row%10 == 0)  fprintf (stderr, "%s: Processed row %7ld of %d\r", GMT_program, row, S.header.ny);
 
 	}
-	if (gmtdefs.verbose)  fprintf (stderr, "%s: Processed row %7d\n", GMT_program, row);
+	if (gmtdefs.verbose)  fprintf (stderr, "%s: Processed row %7ld\n", GMT_program, row);
 
 	GMT_close_grd (&S);	/* Close the output gridfile */
 	if (!Ctrl->Q.active) GMT_err_fail (GMT_update_grd_info (Ctrl->G.file, &S.header), Ctrl->G.file);
@@ -346,29 +346,29 @@ int main (int argc, char **argv)
 
 	GMT_free ((void *)blend);
 
-	Free_Grdblend_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdblend_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-int init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend) {
-	int n = 0, nr, one_or_zero = 0;
-	size_t n_alloc = GMT_SMALL_CHUNK;
+GMT_LONG init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend) {
+	GMT_LONG n = 0, nr, one_or_zero = 0, n_alloc = 0, type;
 	struct GRDBLEND_INFO *B;
-	char line[BUFSIZ], r_in[GMT_LONG_TEXT], type, *sense[2] = {"normal", "inverse"};
+	char line[BUFSIZ], r_in[GMT_LONG_TEXT], *sense[2] = {"normal", "inverse"};
 	void decode_R (char *string, double *w, double *e, double *s, double *n);
 
-	B = (struct GRDBLEND_INFO *) GMT_memory (VNULL, n_alloc, sizeof (struct GRDBLEND_INFO), GMT_program);
-
+	GMT_set_meminc (GMT_SMALL_CHUNK);
 	while (GMT_fgets (line, BUFSIZ, fp)) {	/* Read each input file for grid information */
-		if (line[0] == '#' || line[0] == '\n' || line[0] == '\r') continue;	/* Skip comment lines or blank lines */
+		GMT_chop (line);
+		if (line[0] == '#' || line[0] == '\0') continue;	/* Skip comment lines or blank lines */
 
+		if (n == n_alloc) n_alloc = GMT_alloc_memory ((void **)&B, n, n_alloc, sizeof (struct GRDBLEND_INFO), GMT_program);
 		memset ((void *)&B[n], 0, sizeof (struct GRDBLEND_INFO));	/* Initialize memory */
 		nr = sscanf (line, "%s %s %lf", B[n].file, r_in, &B[n].weight);
 		if (nr != 3) {
-			fprintf (stderr, "%s: Read error for blending parameters near row %d\n", GMT_program, n);
+			fprintf (stderr, "%s: Read error for blending parameters near row %ld\n", GMT_program, n);
 			exit (EXIT_FAILURE);
 		}
 		GMT_err_fail (GMT_read_grd_info (B[n].file, &B[n].G.header), B[n].file);	/* Read header structure */
@@ -444,26 +444,23 @@ int init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend
 		/* Allocate space for one entire row */
 
 		B[n].z = (float *) GMT_memory (VNULL, (size_t)(B[n].G.header.nx), sizeof (float), GMT_program);
-		if (gmtdefs.verbose) fprintf (stderr, "%s: Blend file %s in %g/%g/%g/%g with %s weight %g [%d-%d]\n",
+		if (gmtdefs.verbose) fprintf (stderr, "%s: Blend file %s in %g/%g/%g/%g with %s weight %g [%ld-%ld]\n",
 			GMT_program, B[n].G.header.name, B[n].w_in, B[n].e_in, B[n].s_in, B[n].n_in, sense[B[n].invert], B[n].weight, B[n].out_j0, B[n].out_j1);
 
 		GMT_close_grd (&B[n].G);
 
 		n++;
-		if (n == (GMT_LONG)n_alloc) {
-			n_alloc <<= 1;
-			B = (struct GRDBLEND_INFO *) GMT_memory ((void *)B, n_alloc, sizeof (struct GRDBLEND_INFO), GMT_program);
-		}
 	}
 
-	B = (struct GRDBLEND_INFO *) GMT_memory ((void *)B, (size_t)n, sizeof (struct GRDBLEND_INFO), GMT_program);
+	n_alloc = GMT_alloc_memory ((void **)&B, 0, n, sizeof (struct GRDBLEND_INFO), GMT_program);
 	*blend = B;
+	GMT_reset_meminc ();
 
 	return (n);
 }
 
-void sync_input_rows (int row, struct GRDBLEND_INFO *B, int n_blend, double half) {
-	int k;
+void sync_input_rows (GMT_LONG row, struct GRDBLEND_INFO *B, GMT_LONG n_blend, double half) {
+	GMT_LONG k;
 
 	for (k = 0; k < n_blend; k++) {	/* Get every input grid ready for the new row */
 		if (row < B[k].out_j0 || row > B[k].out_j1) {	/* Either done with grid or haven't gotten to this range yet */
@@ -497,7 +494,7 @@ void sync_input_rows (int row, struct GRDBLEND_INFO *B, int n_blend, double half
 
 void decode_R (char *string, double *w, double *e, double *s, double *n) {
 	double *p[4];
-	int i, pos, error = 0;
+	GMT_LONG i, pos, error = 0;
 	char text[BUFSIZ];
 
 	/* Needed to decode the inner region -Rw/e/s/n string */
@@ -514,10 +511,10 @@ void decode_R (char *string, double *w, double *e, double *s, double *n) {
 	}
 }
 
-void *New_Grdblend_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdblend_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDBLEND_CTRL *C;
 	
-	C = (struct GRDBLEND_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDBLEND_CTRL), "New_Grdblend_Ctrl");
+	C = (struct GRDBLEND_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDBLEND_CTRL), "New_grdblend_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -527,7 +524,7 @@ void *New_Grdblend_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Grdblend_Ctrl (struct GRDBLEND_CTRL *C) {	/* Deallocate control structure */
+void Free_grdblend_Ctrl (struct GRDBLEND_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
