@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdclip.c,v 1.25 2008/04/25 04:00:41 guru Exp $
+ *	$Id: grdclip.c,v 1.31 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -50,18 +50,17 @@ int main (int argc, char **argv)
 {
 	BOOLEAN	error;
 	char *infile = CNULL, format[BUFSIZ], txt[50];
-	int i;
-	size_t k, nxy;
-	GMT_LONG n_above, n_below, n;
+	GMT_LONG i;
+	GMT_LONG k, nxy, n_above, n_below, n;
 	float	*data;
 	struct GRD_HEADER header;
 	struct GRDCLIP_CTRL *Ctrl;
 
-	void *New_Grdclip_Ctrl (), Free_Grdclip_Ctrl (struct GRDCLIP_CTRL *C);
+	void *New_grdclip_Ctrl (), Free_grdclip_Ctrl (struct GRDCLIP_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDCLIP_CTRL *) New_Grdclip_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDCLIP_CTRL *) New_grdclip_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	error = FALSE;
 	n_above = n_below = 0;
@@ -155,8 +154,9 @@ int main (int argc, char **argv)
 
 	GMT_grd_init (&header, argc, argv, TRUE);
 
-	nxy = ((size_t)header.nx) * ((size_t)header.ny);
-	data = (float *) GMT_memory (VNULL, nxy, sizeof (float), GMT_program);
+	nxy = GMT_get_nm (header.nx, header.ny);
+	
+	data = (float *) GMT_memory (VNULL, (size_t)nxy, sizeof (float), GMT_program);
 
 	GMT_err_fail (GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), infile);
 
@@ -187,24 +187,24 @@ int main (int argc, char **argv)
 		}
 	}
 
-	Free_Grdclip_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdclip_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdclip_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdclip_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDCLIP_CTRL *C;
 	
-	C = (struct GRDCLIP_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDCLIP_CTRL), "New_Grdclip_Ctrl");
+	C = (struct GRDCLIP_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDCLIP_CTRL), "New_grdclip_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 			
 	return ((void *)C);
 }
 
-void Free_Grdclip_Ctrl (struct GRDCLIP_CTRL *C) {	/* Deallocate control structure */
+void Free_grdclip_Ctrl (struct GRDCLIP_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
