@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c,v 1.142 2009/09/11 10:57:37 guru Exp $
+ *	$Id: grdcontour.c,v 1.147 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -137,11 +137,11 @@ int main (int argc, char **argv)
 	void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, BOOLEAN tick_low, BOOLEAN tick_high, BOOLEAN tick_label, char Llabel, char Hlabel);
 	void GMT_grd_minmax (float *a, struct GRD_HEADER *h, double xyz[2][3]);
 	void adjust_hill_label (struct GMT_CONTOUR *G, struct GRD_HEADER *h, float *z);
-	void *New_Grdcontour_Ctrl (), Free_Grdcontour_Ctrl (struct GRDCONTOUR_CTRL *C);
+	void *New_grdcontour_Ctrl (), Free_grdcontour_Ctrl (struct GRDCONTOUR_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDCONTOUR_CTRL *)New_Grdcontour_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDCONTOUR_CTRL *)New_grdcontour_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -367,7 +367,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-L only contour inside this range\n");
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
-		fprintf (stderr, "\t-Q Do not draw contours with less than <cut> points [Draw all contours]\n");
+		fprintf (stderr, "\t-Q Do not draw closed contours with less than <cut> points [Draw all contours]\n");
 		GMT_explain_option ('R');
 		fprintf (stderr, "\t   [Default is extent of grid]\n");
 		fprintf (stderr, "\t-S will Smooth contours by splining and resampling\n");
@@ -481,7 +481,7 @@ int main (int argc, char **argv)
 		GMT_plotinit (argc, argv);
 		GMT_map_basemap ();
 		GMT_plotend ();
-		Free_Grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
+		Free_grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
@@ -507,7 +507,7 @@ int main (int argc, char **argv)
 	if (Ctrl->L.active && header.z_max < header.z_min) {	/* Specified contour range outside range of data - quit */
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Warning: No contours within specified -L range\n", GMT_program);
 		GMT_free ((void *)grd_original);
-		Free_Grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
+		Free_grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
@@ -568,7 +568,8 @@ int main (int argc, char **argv)
 			exit (EXIT_FAILURE);
 		}
 		while (GMT_fgets (line, BUFSIZ, fpc)) {
-			if (line[0] == '#') continue;
+			GMT_chop (line);
+			if (line[0] == '#' || line[0] == '\0') continue;
 			if (n_contours == n_alloc) {
 				(void)GMT_alloc_memory2 ((void **)&contour, (void **)&cont_angle, n_contours, n_alloc, sizeof (double), GMT_program);
 				n_alloc = GMT_alloc_memory2 ((void **)&cont_type, (void **)&cont_do_tick, n_contours, n_alloc, sizeof (char), GMT_program);
@@ -611,7 +612,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *)cont_angle);
 		GMT_free ((void *)cont_do_tick);
 		GMT_free ((void *)grd_original);
-		Free_Grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
+		Free_grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
@@ -678,7 +679,7 @@ int main (int argc, char **argv)
 				else
 					interior = FALSE;
 
-				if (n >= Ctrl->Q.min) {
+				if (!interior || n >= Ctrl->Q.min) {
 					if (Ctrl->D.active) GMT_dump_contour (x, y, n, cval, section, interior, Ctrl->D.file);
 					if ((nn = GMT_clip_to_map (x, y, n, &xp, &yp))) {	/* Lines inside the region */
 						/* From here on, xp/yp are map inches */
@@ -752,7 +753,7 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdcontour_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -761,7 +762,7 @@ int main (int argc, char **argv)
 
 void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, BOOLEAN tick_low, BOOLEAN tick_high, BOOLEAN tick_label, char Llabel, char Hlabel)
 {
-	GMT_LONG np, i, j, inside, ix, iy, iy_s, done, n_ticks;
+	GMT_LONG np, i, j, inside, ix, iy, done, n_ticks, stop;
 	double x0, y0, add, sign, dx, dy, x_back, y_back, x_front, y_front;
 	double xmin, xmax, ymin, ymax, x_mean = 0.0, y_mean = 0.0, inc, dist, a, small, this_lon, this_lat, sa, ca, *s;
 	char txt[2][2];
@@ -788,40 +789,37 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 		if (!save[i].do_it) continue;
 		np = save[i].n;
 
-		/* Get rectangular surrounding box for this polygon */
+		/* Loop around the contour and get min/max original x,y (longitude, latitude) coordinates */
 
-		xmin = xmax = save[i].x[0];
-		ymin = ymax = save[i].y[0];
+		GMT_xy_to_geo (&xmax, &ymax, save[i].x[0], save[i].y[0]);
+		xmin = xmax;
+		ymin = ymax;
 		for (j = 1; j < np; j++) {
-			xmin = MIN (xmin, save[i].x[j]);
-			xmax = MAX (xmax, save[i].x[j]);
-			ymin = MIN (ymin, save[i].y[j]);
-			ymax = MAX (ymax, save[i].y[j]);
+			GMT_xy_to_geo (&this_lon, &this_lat, save[i].x[j], save[i].y[j]);
+			xmin = MIN (xmin, this_lon);
+			xmax = MAX (xmax, this_lon);
+			ymin = MIN (ymin, this_lat);
+			ymax = MAX (ymax, this_lat);
 		}
 
-		/* Find a point inside the polygon to test for high or low.
-		 * We select the mid-top point and march down until we are inside
-		 */
-
-		GMT_xy_to_geo (&this_lon, &this_lat, 0.5 * (xmin + xmax), ymax);
-		if (GMT_is_dnan (this_lon) || GMT_is_dnan (this_lat)) continue;
-		ix = GMT_x_to_i (this_lon, h->x_min, h->x_inc, h->xy_off, h->nx);
-		iy = GMT_y_to_j (this_lat, h->y_min, h->y_inc, h->xy_off, h->ny);
-		this_lon = GMT_i_to_x (ix, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);	/* This is that mid longitude */
-		GMT_xy_to_geo (&a, &this_lat, 0.5 * (xmin + xmax), ymin);			/* Get bottom latitude */
-		if (GMT_is_dnan (a)) continue;
-		iy_s = MIN (h->ny, GMT_y_to_j (this_lat, h->y_min, h->y_inc, h->xy_off, h->ny) + 1);	/* And its j-row */
+		/* Pick the mid-latitude and march along that line from east to west */
+		
+		this_lat = 0.5 * (ymax + ymin);	/* Mid latitude, probably not exactly on a y-node */
+		iy = MIN (h->ny - 1, GMT_y_to_j (this_lat, h->y_min, h->y_inc, h->xy_off, h->ny));	/* Get closest j-row */
+		this_lat = GMT_j_to_y (iy, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);		/* Get its matching latitude */
+		ix = GMT_x_to_i (xmin, h->x_min, h->x_inc, h->xy_off, h->nx);	/* Westernmost point */
+		stop  = GMT_x_to_i (xmax, h->x_min, h->x_inc, h->xy_off, h->nx);	/* Eastermost point */
 		done = FALSE;
-		while (!done && iy < iy_s) {
-			this_lat = GMT_j_to_y (iy, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
+		while (!done && ix <= stop) {
+			this_lon = GMT_i_to_x (ix, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);	/* Current longitude */
 			GMT_geo_to_xy (this_lon, this_lat, &x0, &y0);
 			inside = GMT_non_zero_winding (x0, y0, save[i].x, save[i].y, (GMT_LONG)np);
 			if (inside == 2)	/* OK, this point is inside */
 				done = TRUE;
 			else
-				iy++;
+				ix++;
 		}
-		if (iy == h->ny) iy--;	/* Check to make sure we don't exceed array bounds in next line. However, iy may thus be wrong */ 
+		if (!done) continue;	/* Failed to find an inside point */
 		save[i].high = (grd[iy*h->nx+ix] > save[i].cval);
 
 		if (save[i].high && !tick_high) continue;	/* Do not tick highs */
@@ -965,10 +963,10 @@ void adjust_hill_label (struct GMT_CONTOUR *G, struct GRD_HEADER *h, float *z)
 	}
 }
 	
-void *New_Grdcontour_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdcontour_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDCONTOUR_CTRL *C;
 	
-	C = (struct GRDCONTOUR_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDCONTOUR_CTRL), "New_Grdcontour_Ctrl");
+	C = (struct GRDCONTOUR_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDCONTOUR_CTRL), "New_grdcontour_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -993,7 +991,7 @@ void *New_Grdcontour_Ctrl () {	/* Allocate and initialize a new control structur
 	return ((void *)C);
 }
 
-void Free_Grdcontour_Ctrl (struct GRDCONTOUR_CTRL *C) {	/* Deallocate control structure */
+void Free_grdcontour_Ctrl (struct GRDCONTOUR_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	if (C->D.file) free ((void *)C->D.file);	
 	GMT_free ((void *)C);	
