@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcut.c,v 1.37 2009/01/09 04:02:33 guru Exp $
+ *	$Id: grdcut.c,v 1.45 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
  * Author:	Walter Smith
  * Date:	5 august, 1988
  * Version:	4
+ * 		PW: 4/20/09 Added -Z option
  *
  */
  
@@ -32,17 +33,25 @@ struct GRDCUT_CTRL {
 		BOOLEAN active;
 		char *file;
 	} G;
+	struct Z {	/* -Z[min/max] */
+		BOOLEAN active;
+		GMT_LONG mode;	/* 1 means NaN */
+		double min, max;
+	} Z;
 };
 
+#define NAN_IS_INSIDE	0
+#define NAN_IS_OUTSIDE	1
+
 int main (int argc, char **argv)
 {
 	BOOLEAN	error = FALSE;
 
-	int	i, nx_old, ny_old, nx_new, ny_new, one_or_zero;
+	GMT_LONG	i, k, nx_old, ny_old, nx_new, ny_new, one_or_zero;
 	
 	GMT_LONG	nm;
 
-	char *grd_in, format[BUFSIZ];
+	char *grd_in, format[BUFSIZ], za[GMT_TEXT_LEN], zb[GMT_TEXT_LEN];
 
 	float	*grd;
 
@@ -52,17 +61,18 @@ int main (int argc, char **argv)
 	struct GRD_HEADER header, test_header;
 	struct GRDCUT_CTRL *Ctrl;
 
-	void *New_Grdcut_Ctrl (), Free_Grdcut_Ctrl (struct GRDCUT_CTRL *C);
+	void *New_grdcut_Ctrl (), Free_grdcut_Ctrl (struct GRDCUT_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDCUT_CTRL *) New_Grdcut_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDCUT_CTRL *) New_grdcut_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	grd_in = CNULL;
+	za[0] = zb[0] = '\0';
 
 	/* Check and interpret the command line arguments */
 
-	for (i =1; i < argc; i++) {
+	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch(argv[i][1]) {
 				/* Common parameters */
@@ -78,6 +88,20 @@ int main (int argc, char **argv)
 					Ctrl->G.active = TRUE;
 					Ctrl->G.file = strdup (&argv[i][2]);
 					break;
+					
+	 			case 'Z':
+					Ctrl->Z.active = TRUE;
+					k = 2;
+					if (argv[i][k] == 'n') {
+						Ctrl->Z.mode = NAN_IS_OUTSIDE;
+						k = 3;
+					}
+					if (sscanf (&argv[i][k], "%[^/]/%s", za, zb) == 2) {
+						if (!(za[0] == '-' && za[1] == '\0')) error += GMT_verify_expectations (GMT_io.in_col_type[GMT_Z], GMT_scanf_arg (za, GMT_io.in_col_type[GMT_Z], &Ctrl->Z.min), za);
+						if (!(zb[0] == '-' && zb[1] == '\0')) error += GMT_verify_expectations (GMT_io.in_col_type[GMT_Z], GMT_scanf_arg (zb, GMT_io.in_col_type[GMT_Z], &Ctrl->Z.max), zb);
+					}
+					break;
+	
 				default:		/* Options not recognized */
 					error = TRUE;
 					GMT_default_error (argv[i][1]);
@@ -90,7 +114,7 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"grdcut %s - Extract subsets from grid files\n\n", GMT_VERSION);
-		fprintf (stderr, "usage: grdcut <input_grd> -G<output_grd> %s [-V] [%s]\n", GMT_Rgeo_OPT, GMT_f_OPT);
+		fprintf (stderr, "usage: grdcut <input_grd> -G<output_grd> %s [-V] [-Z[n][min/max]] [%s]\n", GMT_Rgeo_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -101,14 +125,17 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   If in doubt, run grdinfo first and check range of old file.\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		GMT_explain_option ('V');
+		fprintf (stderr, "\t-Z Specify a range and determine the corresponding rectangular region so that\n");
+		fprintf (stderr, "\t   all values outside this region are outside the range [-inf/+inf].\n");
+		fprintf (stderr, "\t   Use -Zn to consider NaNs outside as well [Default just ignores NaNs]\n");
 		GMT_explain_option ('f');
 		exit (EXIT_FAILURE);
 	}
 
 	/* Check that the options selected make sense */
 
-	if (!project_info.region_supplied) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
+	if ((project_info.region_supplied + Ctrl->Z.active) != 1) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify either the -R or the -Z options\n", GMT_program);
 		error++;
 	}
 	if (!Ctrl->G.file) {
@@ -123,6 +150,60 @@ int main (int argc, char **argv)
 
 	GMT_err_fail (GMT_read_grd_info (grd_in, &header), grd_in);
 
+	if (Ctrl->Z.active) {	/* Must determine new region via -Z */
+		GMT_LONG i0, i1, j0, j1, j, ij;
+		
+		nm = GMT_get_nm (header.nx, header.ny);
+		grd = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
+		GMT_err_fail (GMT_read_grd (grd_in, &header, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), grd_in);
+		for (i = 0, i0 = -1; i0 == -1 && i < header.nx; i++) {	/* Scan from xmin towards xmax */
+			for (j = 0, ij = i; i0 == -1 && j < header.ny; j++, ij += header.ny) {
+				if (GMT_is_fnan (grd[ij])) {
+					if (Ctrl->Z.mode == NAN_IS_OUTSIDE) i0 = i;	/* Must stop since this value defines the inner box */
+				}
+				else if (grd[ij] >= Ctrl->Z.min && grd[ij] <= Ctrl->Z.max)
+					i0 = i;
+			}
+		}
+		if (i0 == -1) {
+			fprintf (stderr, "%s: The sub-region is empty\n", GMT_program);
+			GMT_free ((void *)grd);
+			exit (EXIT_FAILURE);
+		}
+		for (i = header.nx-1, i1 = -1; i1 == -1 && i > i0; i--) {	/* Scan from xmax towards xmin */
+			for (j = 0, ij = i; i1 == -1 && j < header.ny; j++, ij += header.ny) {
+				if (GMT_is_fnan (grd[ij])) {
+					if (Ctrl->Z.mode == NAN_IS_INSIDE) i1 = i;	/* Must stop since this value defines the inner box */
+				}
+				else if (grd[ij] >= Ctrl->Z.min && grd[ij] <= Ctrl->Z.max)
+					i1 = i;
+			}
+		}
+		for (j = 0, j0 = -1; j0 == -1 && j < header.ny; j++) {	/* Scan from ymin towards ymax */
+			for (i = i0, ij = GMT_IJ(j,i0,header.nx); j0 == -1 && i < i1; i++, ij++) {
+				if (GMT_is_fnan (grd[ij])) {
+					if (Ctrl->Z.mode == NAN_IS_INSIDE) j0 = j;	/* Must stop since this value defines the inner box */
+				}
+				else if (grd[ij] >= Ctrl->Z.min && grd[ij] <= Ctrl->Z.max)
+					j0 = j;
+			}
+		}
+		for (j = header.ny-1, j1 = -1; j1 == -1 && j >= j0; j--) {	/* Scan from ymax towards ymin */
+			for (i = i0, ij = GMT_IJ(j,i0,header.nx); j1 == -1 && i < i1; i++, ij++) {
+				if (GMT_is_fnan (grd[ij])) {
+					if (Ctrl->Z.mode == NAN_IS_INSIDE) j1 = j;	/* Must stop since this value defines the inner box */
+				}
+				else if (grd[ij] >= Ctrl->Z.min && grd[ij] <= Ctrl->Z.max)
+					j1 = j;
+			}
+		}
+		w_new = GMT_i_to_x (i0, header.x_min, header.x_max, header.x_inc, 0.5 * header.node_offset, header.nx);
+		e_new = GMT_i_to_x (i1, header.x_min, header.x_max, header.x_inc, 0.5 * header.node_offset, header.nx);
+		n_new = GMT_j_to_y (j0, header.y_min, header.y_max, header.y_inc, 0.5 * header.node_offset, header.ny);
+		s_new = GMT_j_to_y (j1, header.y_min, header.y_max, header.y_inc, 0.5 * header.node_offset, header.ny);
+		GMT_free ((void *)grd);
+	}
+	
 	if (s_new < header.y_min || s_new > header.y_max) error = TRUE;
 	if (n_new < header.y_min || n_new > header.y_max) error = TRUE;
 
@@ -200,24 +281,25 @@ int main (int argc, char **argv)
 
 	GMT_free ((void *) grd);
 
-	Free_Grdcut_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdcut_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdcut_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdcut_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDCUT_CTRL *C;
 	
-	C = (struct GRDCUT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDCUT_CTRL), "New_Grdcut_Ctrl");
+	C = (struct GRDCUT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDCUT_CTRL), "New_grdcut_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 			
+	C->Z.min = -DBL_MAX;	C->Z.max = DBL_MAX;			/* No limits on z-range */
 	return ((void *)C);
 }
 
-void Free_Grdcut_Ctrl (struct GRDCUT_CTRL *C) {	/* Deallocate control structure */
+void Free_grdcut_Ctrl (struct GRDCUT_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
