@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdedit.c,v 1.52 2009/01/09 04:02:33 guru Exp $
+ *	$Id: grdedit.c,v 1.58 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ int main (int argc, char **argv)
 {
 	BOOLEAN error = FALSE;
 
-	int i, j, n_expected_fields, n_fields;
+	GMT_LONG i, j, n_expected_fields, n_fields;
 	
 	GMT_LONG n_data, k, nm;
 	
@@ -77,11 +77,11 @@ int main (int argc, char **argv)
 	struct GRD_HEADER grd;
 	struct GRDEDIT_CTRL *Ctrl;
 
-	void *New_Grdedit_Ctrl (), Free_Grdedit_Ctrl (struct GRDEDIT_CTRL *C);
+	void *New_grdedit_Ctrl (), Free_grdedit_Ctrl (struct GRDEDIT_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDEDIT_CTRL *)New_Grdedit_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDEDIT_CTRL *)New_grdedit_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	grdfile = CNULL;
 	w = e = s = n = 0.0;
@@ -254,10 +254,11 @@ int main (int argc, char **argv)
 		GMT_free ((void *)a);
 	}
 	else if (Ctrl->N.active) {
+		char *not_used = NULL;
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Replacing nodes using xyz values from file %s\n", GMT_program, Ctrl->N.file);
 		if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 			char *type[2] = {"double", "single"};
-			fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+			fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 		}
 		nm = GMT_get_nm (grd.nx, grd.ny);
 		a = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
@@ -266,7 +267,7 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: Could not open file %s\n", GMT_program, Ctrl->N.file);
 			exit (EXIT_FAILURE);
 		}
-		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp);
+		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (buffer, BUFSIZ, fp);
 
 		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3;
 
@@ -274,17 +275,17 @@ int main (int argc, char **argv)
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 			n_data++;
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_data);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_data);
 				exit (EXIT_FAILURE);
 			}
-			if (GMT_y_is_outside (in[1],  grd.y_min, grd.y_max)) continue;	/* Outside y-range */
-			if (GMT_x_is_outside (&in[0], grd.x_min, grd.x_max)) continue;	/* Outside x-range */
-			j = GMT_y_to_j(in[1], grd.y_min, grd.y_inc, grd.xy_off, grd.ny);
+			if (GMT_y_is_outside (in[GMT_Y],  grd.y_min, grd.y_max)) continue;	/* Outside y-range */
+			if (GMT_x_is_outside (&in[GMT_X], grd.x_min, grd.x_max)) continue;	/* Outside x-range */
+			j = GMT_y_to_j(in[GMT_Y], grd.y_min, grd.y_inc, grd.xy_off, grd.ny);
 			if (j < 0 || j >= grd.ny) continue;
-			i = GMT_x_to_i(in[0], grd.x_min, grd.x_inc, grd.xy_off, grd.nx);
+			i = GMT_x_to_i(in[GMT_X], grd.x_min, grd.x_inc, grd.xy_off, grd.nx);
 			if (i < 0 || i >= grd.nx) continue;
 			k = GMT_IJ (j, i, grd.nx);
-			a[k] = (float)in[2];
+			a[k] = (float)in[GMT_Z];
 		}
 		if (fp != GMT_stdin) GMT_fclose (fp);
 
@@ -293,7 +294,7 @@ int main (int argc, char **argv)
 	}
 	else if (Ctrl->E.active) {	/* Transpose the matrix and exchange x and y info */
 		struct GRD_HEADER grd_tr;
-		int row, col;
+		GMT_LONG row, col;
 		GMT_LONG ij, ij_tr;
 		float *a_tr;
 		
@@ -352,24 +353,24 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: File %s updated.\n", GMT_program, grdfile);
 
-	Free_Grdedit_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdedit_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdedit_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdedit_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDEDIT_CTRL *C;
 	
-	C = (struct GRDEDIT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDEDIT_CTRL), "New_Grdedit_Ctrl");
+	C = (struct GRDEDIT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDEDIT_CTRL), "New_grdedit_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 
 	return ((void *)C);
 }
 
-void Free_Grdedit_Ctrl (struct GRDEDIT_CTRL *C) {	/* Deallocate control structure */
+void Free_grdedit_Ctrl (struct GRDEDIT_CTRL *C) {	/* Deallocate control structure */
 	if (C->D.information) free ((void *)C->D.information);	
 	if (C->N.file) free ((void *)C->N.file);	
 	GMT_free ((void *)C);	
