@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfft.c,v 1.48 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdfft.c,v 1.50 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -169,11 +169,11 @@ int main (int argc, char **argv)
 	void do_filter(void), do_spectrum(double *par, GMT_LONG give_wavelength), do_isostasy(double *par);
 	double get_filter_weight (GMT_LONG k);
 
-	void *New_Grdfft_Ctrl (), Free_Grdfft_Ctrl (struct GRDFFT_CTRL *C);
+	void *New_grdfft_Ctrl (), Free_grdfft_Ctrl (struct GRDFFT_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDFFT_CTRL *) New_Grdfft_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDFFT_CTRL *) New_grdfft_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 0; i < 3; i++) {
 		f_info.lc[i] = f_info.lp[i] = -1.0;	/* Set negative, below valid frequency range  */
@@ -504,7 +504,7 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "Done\n");
 
-	Free_Grdfft_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdfft_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -1406,17 +1406,17 @@ GMT_LONG get_prime_factors (GMT_LONG n, GMT_LONG *f)
 	return (n_factors);
 }
 
-void *New_Grdfft_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdfft_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDFFT_CTRL *C;
 	
-	C = (struct GRDFFT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDFFT_CTRL), "New_Grdfft_Ctrl");
+	C = (struct GRDFFT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDFFT_CTRL), "New_grdfft_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 
 	return ((void *)C);
 }
 
-void Free_Grdfft_Ctrl (struct GRDFFT_CTRL *C) {	/* Deallocate control structure */
+void Free_grdfft_Ctrl (struct GRDFFT_CTRL *C) {	/* Deallocate control structure */
 	if (C->operation) GMT_free ((void *)C->operation);	
 	if (C->par) GMT_free ((void *)C->par);	
 	if (C->G.file) free ((void *)C->G.file);	
