@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfilter.c,v 1.73 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdfilter.c,v 1.76 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -138,11 +138,11 @@ int main (int argc, char **argv)
 	double CartScaledRadius (double x0, double y0, double x1, double y1, double par[]);
 	double FlatEarthRadius (double x0, double y0, double x1, double y1, double par[]);
 	double SphericalRadius (double x0, double y0, double x1, double y1, double par[]);
-	void *New_Grdfilter_Ctrl (), Free_Grdfilter_Ctrl (struct GRDFILTER_CTRL *C);
+	void *New_grdfilter_Ctrl (), Free_grdfilter_Ctrl (struct GRDFILTER_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDFILTER_CTRL *)New_Grdfilter_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDFILTER_CTRL *)New_grdfilter_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	error = new_range = FALSE;
 	fin = NULL;
@@ -173,7 +173,7 @@ int main (int argc, char **argv)
 						if (Ctrl->F.width < 0.0) Ctrl->F.highpass = TRUE;
 						Ctrl->F.width = fabs (Ctrl->F.width);
 						if (Ctrl->F.filter == 'p') {	/* Check for some futher info in case of mode filtering */
-							c = argv[i][strlen(argv[i]-1)];
+							c = argv[i][strlen(argv[i])-1];
 							if (c == '-') Ctrl->F.mode = -1;
 							if (c == '+') Ctrl->F.mode = +1;
 						}
@@ -713,7 +713,7 @@ int main (int argc, char **argv)
 	if (slow) GMT_free ((void *) work_array);
 	if (!fast_way) GMT_free ((void *) x_shift);
 
-	Free_Grdfilter_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdfilter_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -811,17 +811,17 @@ double GaussianWeight (double r, double par[])
 	return (exp (r * r * par[GRDFILTER_INV_R_SCALE]));
 }
 
-void *New_Grdfilter_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdfilter_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDFILTER_CTRL *C;
 	
-	C = (struct GRDFILTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDFILTER_CTRL), "New_Grdfilter_Ctrl");
+	C = (struct GRDFILTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDFILTER_CTRL), "New_grdfilter_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->D.mode = -1;	
 	return ((void *)C);
 }
 
-void Free_Grdfilter_Ctrl (struct GRDFILTER_CTRL *C) {	/* Deallocate control structure */
+void Free_grdfilter_Ctrl (struct GRDFILTER_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
