@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdgradient.c,v 1.42 2009/01/09 04:02:33 guru Exp $
+ *	$Id: grdgradient.c,v 1.51 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -55,13 +55,13 @@ struct GRDGRADIENT_CTRL {
 	} A;
 	struct D {	/* -D[a][o][n] */
 		BOOLEAN active;
-		int mode;
+		GMT_LONG mode;
 	} D;
 	struct E {	/* -E[s|p]<azim>/<elev[ambient/diffuse/specular/shine]> */
 		BOOLEAN active;
 		double azimuth, elevation;
 		double ambient, diffuse, specular, shine;
-		int mode;
+		GMT_LONG mode;
 	} E;
 	struct G {	/* -G<file> */
 		BOOLEAN active;
@@ -76,7 +76,7 @@ struct GRDGRADIENT_CTRL {
 	} M;
 	struct N {	/* -N[t_or_e][<amp>[/<sigma>[/<offset>]]] */
 		BOOLEAN active;
-		int mode;
+		GMT_LONG mode;
 		double norm, sigma, offset;
 	} N;
 	struct S {	/* -S<slopefile> */
@@ -85,13 +85,15 @@ struct GRDGRADIENT_CTRL {
 	} S;
 };
 
+EXTERN_MSC GMT_LONG GMT_parse_f_option (char *arg);	/* Needed for -L setup */
+
 int main (int argc, char **argv)
 {
 	char	*infile = CNULL, format[BUFSIZ], ptr[BUFSIZ];
 	
 	BOOLEAN	error = FALSE, sigma_set = FALSE, offset_set = FALSE, bad;
 	
-	int pos, p[4], entry, mx, my;
+	GMT_LONG pos, p[4], entry, mx, my;
 	
 	GMT_LONG	i, j, ij, k, n, nm, nm2, n_used = 0;
 	
@@ -108,11 +110,11 @@ int main (int argc, char **argv)
 	struct GRDGRADIENT_CTRL *Ctrl;
 	
 	double specular (double nx, double ny, double nz, double *s);
-	void *New_Grdgradient_Ctrl (), Free_Grdgradient_Ctrl (struct GRDGRADIENT_CTRL *C);
+	void *New_grdgradient_Ctrl (), Free_grdgradient_Ctrl (struct GRDGRADIENT_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDGRADIENT_CTRL *)New_Grdgradient_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDGRADIENT_CTRL *)New_grdgradient_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	GMT_boundcond_init (&edgeinfo);
 	memset ((void *)s, 0, 3*sizeof(double));
@@ -212,6 +214,8 @@ int main (int argc, char **argv)
 				case 'L':
 					Ctrl->L.active = TRUE;
 					strncpy (Ctrl->L.mode, &argv[i][2], (size_t)4);
+					/* We turn on geographic coordinates if -Lg is given by faking -fg */
+					if (! strcmp (Ctrl->L.mode, "g")) GMT_parse_f_option ("g");
 					break;
 				case 'M':
 					Ctrl->M.active = TRUE;
@@ -346,15 +350,15 @@ int main (int argc, char **argv)
 		while (Ctrl->E.azimuth > 360.0) Ctrl->E.azimuth -= 360.0;
 	}
 	if (Ctrl->E.mode == 2) {
-		p0 = cos((90.0 - Ctrl->E.azimuth)*D2R) * tan((90.0 - Ctrl->E.elevation)*D2R);
-		q0 = sin((90.0 - Ctrl->E.azimuth)*D2R) * tan((90.0 - Ctrl->E.elevation)*D2R);
+		p0 = cosd(90.0 - Ctrl->E.azimuth) * tand(90.0 - Ctrl->E.elevation);
+		q0 = sind(90.0 - Ctrl->E.azimuth) * tand(90.0 - Ctrl->E.elevation);
 		p0q0_cte = sqrt(1 + p0*p0 + q0*q0);
 	}
 	if (Ctrl->E.mode == 3) {
 		Ctrl->E.elevation = 90 - Ctrl->E.elevation;
-		s[0] = sin(Ctrl->E.azimuth*D2R) * cos(Ctrl->E.elevation*D2R);
-		s[1] = cos(Ctrl->E.azimuth*D2R) * cos(Ctrl->E.elevation*D2R);
-		s[2] =  sin(Ctrl->E.elevation*D2R);
+		s[0] = sind(Ctrl->E.azimuth) * cosd(Ctrl->E.elevation);
+		s[1] = cosd(Ctrl->E.azimuth) * cosd(Ctrl->E.elevation);
+		s[2] = sind(Ctrl->E.elevation);
 		k_ads = Ctrl->E.ambient + Ctrl->E.diffuse + Ctrl->E.specular;
 	}
 	GMT_boundcond_param_prep (&header, &edgeinfo);
@@ -411,7 +415,7 @@ int main (int argc, char **argv)
 	for (j = k = 0; j < header.ny; j++) {
 		if (Ctrl->M.active) {
 			lat = GMT_j_to_y (j, header.y_min, header.y_max, header.y_inc, 0.5 * header.node_offset, header.ny);
-			dx_grid = project_info.M_PR_DEG * header.x_inc * cos (D2R * lat);
+			dx_grid = project_info.M_PR_DEG * header.x_inc * cosd (lat);
 			if (dx_grid > 0.0) x_factor = -1.0 / (2.0 * dx_grid);	/* Use previous value at the poles */
 			if (Ctrl->A.active) {
 				if (Ctrl->A.two) {
@@ -452,7 +456,7 @@ int main (int argc, char **argv)
 				max_gradient = MAX (max_gradient, data[k]);
 			}
 			else if (Ctrl->D.active) {
-				azim = (Ctrl->D.mode & 1) ? atan2 (-dzdy, -dzdx) * R2D : 90.0 - atan2 (-dzdy, -dzdx) * R2D;
+				azim = (Ctrl->D.mode & 1) ? atan2d (-dzdy, -dzdx) : 90.0 - atan2d (-dzdy, -dzdx);
 				if (Ctrl->D.mode & 4) azim += 90.0;
 				if (azim < 0.0) azim += 360.0;
 				if (azim >= 360.0) azim -= 360.0;
@@ -481,6 +485,21 @@ int main (int argc, char **argv)
 		}
 	}
 
+	if (Ctrl->M.active || GMT_io.in_col_type[GMT_Y] == GMT_IS_LAT) {	/* Data is geographic */
+		double sum;
+		/* If the N or S poles are included then we only want a single estimate at these repeating points */
+		if (header.y_min == -90.0 && header.node_offset == 0) {	/* Average all the multiple N pole estimates */
+			for (k = 0, sum = 0.0; k < header.nx; k++) sum += data[k];
+			sum /= header.nx;	/* Average NP gradient */
+			for (k = 0; k < header.nx; k++) data[k] = (float)sum;
+		}
+		if (header.y_min == -90.0 && header.node_offset == 0) {	/* Average all the multiple S pole estimates */
+			for (i = 0, k = header.nx * (header.ny - 1), sum = 0.0; i < header.nx; i++, k++) sum += data[k];
+			sum /= header.nx;	/* Average SP gradient */
+			for (i = 0, k = header.nx * (header.ny - 1); i < header.nx; i++, k++) data[k] = (float)sum;
+		}
+	}
+	
 	if (Ctrl->E.active) {	/* data must be scaled to the [-1,1] interval, but we'll do it into [-.95, .95] to not get too bright */
 		scale = 1.0 / (r_max - r_min);
 		for (k = 0; k < nm; k++) {
@@ -581,7 +600,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *)slp);
 	}
 
-	Free_Grdgradient_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdgradient_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -595,9 +614,9 @@ double specular (double nx, double ny, double nz, double *s) {
 	   to the light source and to the viewer, respectively. 
 	   For the time beeing I'm using V = [azim elev] = [0 90] so the following
 
-	   V[0] =  sin(V[0]*D2R)*cos(V[1]*D2R);
-	   V[1] = -cos(V[0]*D2R)*cos(V[1]*D2R);
-	   V[2] =  sin(V[1]*D2R);
+	   V[0] =  sind(V[0])*cosd(V[1]);
+	   V[1] = -cosd(V[0])*cosd(V[1]);
+	   V[2] =  sind(V[1]);
 
 	   Reduces to V[0] = 0;		V[1] = 0;	V[2] = 1 */
 
@@ -606,10 +625,10 @@ double specular (double nx, double ny, double nz, double *s) {
 	return (MAX(0, 2 * (s[0]*nx + s[1]*ny + s[2]*nz) * nz - s[2]));
 }
 
-void *New_Grdgradient_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdgradient_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDGRADIENT_CTRL *C;
 	
-	C = (struct GRDGRADIENT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDGRADIENT_CTRL), "New_Grdgradient_Ctrl");
+	C = (struct GRDGRADIENT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDGRADIENT_CTRL), "New_grdgradient_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.ambient = 0.55;
@@ -620,7 +639,7 @@ void *New_Grdgradient_Ctrl () {	/* Allocate and initialize a new control structu
 	return ((void *)C);
 }
 
-void Free_Grdgradient_Ctrl (struct GRDGRADIENT_CTRL *C) {	/* Deallocate control structure */
+void Free_grdgradient_Ctrl (struct GRDGRADIENT_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	if (C->S.file) free ((void *)C->S.file);	
 	GMT_free ((void *)C);	
