@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdhisteq.c,v 1.32 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdhisteq.c,v 1.34 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -86,11 +86,11 @@ int main (int argc, char **argv)
 
 	void do_usual (char *infile, char *outfile, GMT_LONG n_cells, BOOLEAN quadratic, BOOLEAN dump_intervals, int argc, char **argv);
 	void do_gaussian (char *infile, char *outfile, double norm, int argc, char **argv);
-	void *New_Grdhisteq_Ctrl (), Free_Grdhisteq_Ctrl (struct GRDHISTEQ_CTRL *C);
+	void *New_grdhisteq_Ctrl (), Free_grdhisteq_Ctrl (struct GRDHISTEQ_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDHISTEQ_CTRL *)New_Grdhisteq_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDHISTEQ_CTRL *)New_grdhisteq_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -171,7 +171,7 @@ int main (int argc, char **argv)
 	else
 		do_usual (infile, Ctrl->G.file, Ctrl->C.value, Ctrl->Q.active, Ctrl->D.active, argc, argv);
 
-	Free_Grdhisteq_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdhisteq_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -359,16 +359,16 @@ int compare_indices (const void *point_1, const void *point_2)
 		return (0);
 }
 
-void *New_Grdhisteq_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdhisteq_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDHISTEQ_CTRL *C;
 	
-	C = (struct GRDHISTEQ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDHISTEQ_CTRL), "New_Grdhisteq_Ctrl");
+	C = (struct GRDHISTEQ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDHISTEQ_CTRL), "New_grdhisteq_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	return ((void *)C);
 }
 
-void Free_Grdhisteq_Ctrl (struct GRDHISTEQ_CTRL *C) {	/* Deallocate control structure */
+void Free_grdhisteq_Ctrl (struct GRDHISTEQ_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
