@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdinfo.c,v 1.62 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdinfo.c,v 1.64 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -72,11 +72,11 @@ int main (int argc, char **argv)
 	struct GRD_HEADER grd;
 	struct GRDINFO_CTRL *Ctrl;
 
-	void *New_Grdinfo_Ctrl (), Free_Grdinfo_Ctrl (struct GRDINFO_CTRL *C);
+	void *New_grdinfo_Ctrl (), Free_grdinfo_Ctrl (struct GRDINFO_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDINFO_CTRL *)New_Grdinfo_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDINFO_CTRL *)New_grdinfo_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -463,23 +463,23 @@ int main (int argc, char **argv)
 
 	GMT_free ((void *)a);
 
-	Free_Grdinfo_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdinfo_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdinfo_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdinfo_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDINFO_CTRL *C;
 
-	C = (struct GRDINFO_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDINFO_CTRL), "New_Grdinfo_Ctrl");
+	C = (struct GRDINFO_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDINFO_CTRL), "New_grdinfo_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 
 	return ((void *)C);
 }
 
-void Free_Grdinfo_Ctrl (struct GRDINFO_CTRL *C) {	/* Deallocate control structure */
+void Free_grdinfo_Ctrl (struct GRDINFO_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);
 }
