@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdlandmask.c,v 1.49 2009/01/16 21:43:11 guru Exp $
+ *	$Id: grdlandmask.c,v 1.56 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -38,9 +38,7 @@ struct GRDLANDMASK_CTRL {	/* All control options for this program (except common
 	/* ctive is TRUE if the option has been activated */
 	struct A {	/* -A<min_area>[/<min_level>/<max_level>] */
 		BOOLEAN active;
-		int low;	/* Lowest hierarchical level to use [0] */
-		int high;	/* Highest hierarchical level to use [4] */
-		double area;	/* Area of smallest geographical feature to include [0] */
+		struct GMT_SHORE_SELECT info;
 	} A;
 	struct D {	/* -D<resolution> */
 		BOOLEAN active;
@@ -73,10 +71,8 @@ int main (int argc, char **argv)
 	char line[GMT_LONG_TEXT], ptr[BUFSIZ];
 	char *shore_resolution[5] = {"full", "high", "intermediate", "low", "crude"};
 
-	int	i, j, k, ii, bin, ind, nm, np, side, i_min, i_max, j_min, j_max, nx1, ny1, np_new, pos;
-	int	base = 3, direction, is_inside = 1, err;
-	
-	GMT_LONG ij;
+	GMT_LONG	i, j, k, ii, bin, ind, np, side, i_min, i_max, j_min, j_max, nx1, ny1, np_new, pos;
+	GMT_LONG	base = 3, direction, is_inside = 1, err, ij, nm;
 
 	float *data;
 
@@ -88,11 +84,11 @@ int main (int argc, char **argv)
 	struct GMT_GSHHS_POL *p;
 	struct GRDLANDMASK_CTRL *Ctrl;
 
-	void *New_Grdlandmask_Ctrl (), Free_Grdlandmask_Ctrl (struct GRDLANDMASK_CTRL *C);
+	void *New_grdlandmask_Ctrl (), Free_grdlandmask_Ctrl (struct GRDLANDMASK_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDLANDMASK_CTRL *) New_Grdlandmask_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct GRDLANDMASK_CTRL *) New_grdlandmask_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	GMT_grd_init (&header, argc, argv, FALSE);
 
@@ -115,8 +111,7 @@ int main (int argc, char **argv)
 
 				case 'A':
 					Ctrl->A.active = TRUE;
-					j = sscanf (&argv[i][2], "%lf/%d/%d", &Ctrl->A.area, &Ctrl->A.low, &Ctrl->A.high);
-					if (j == 1) Ctrl->A.low = 0, Ctrl->A.high = GMT_MAX_GSHHS_LEVEL;
+					GMT_set_levels (&argv[i][2], &Ctrl->A.info);
 					break;
 				case 'D':
 					Ctrl->D.active = TRUE;
@@ -166,7 +161,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "grdlandmask %s - Create \"wet-dry\" mask grid file from shoreline data base\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdlandmask -G<mask_grd_file> %s %s\n", GMT_I_OPT, GMT_Rgeo_OPT);
-		fprintf (stderr, "\t[-A<min_area>[/<min_level>/<max_level>]] [-D<resolution>][+] [-F] [-N<maskvalues>[o]] [-V]\n\n");
+		fprintf (stderr, "\t[%s] [-D<resolution>][+] [-F] [-N<maskvalues>[o]] [-V]\n\n", GMT_A_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -174,8 +169,7 @@ int main (int argc, char **argv)
 		GMT_inc_syntax ('I', 0);
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "\t-A features smaller than <min_area> (in km^2) or of levels (0-4) outside the min-max levels\n");
-		fprintf (stderr, "\t   will be skipped [0/4] (see pscoast for details)]\n");
+		GMT_GSHHS_syntax ('A', "Place limits on coastline features from the GSHHS data base.");
 		fprintf (stderr, "\t-D Choose one of the following resolutions:\n");
 		fprintf (stderr, "\t   f - full resolution (may be very slow for large regions)\n");
 		fprintf (stderr, "\t   h - high resolution (may be slow for large regions)\n");
@@ -234,10 +228,11 @@ int main (int argc, char **argv)
 		Ctrl->N.mask[2] = Ctrl->N.mask[4] = Ctrl->N.mask[0];
 	}
 
-	if (GMT_init_shore (Ctrl->D.set, &c, header.x_min, header.x_max, header.y_min, header.y_max)) {
+	if (GMT_init_shore (Ctrl->D.set, &c, header.x_min, header.x_max, header.y_min, header.y_max, &Ctrl->A.info)) {
 		fprintf (stderr, "%s: %s resolution shoreline data base not installed\n", GMT_program, shore_resolution[base]);
 		exit (EXIT_FAILURE);
 	}
+	if (gmtdefs.verbose == 2) fprintf (stderr, "GSHHS version %s\n%s\n%s\n", c.version, c.title, c.source);
 
 	sprintf (line, "%s\n", gmtdefs.d_format);
 	if (gmtdefs.verbose && dry_wet_only) {
@@ -290,9 +285,9 @@ int main (int argc, char **argv)
 	for (ind = 0; ind < c.nb; ind++) {	/* Loop over necessary bins only */
 
 		bin = c.bins[ind];
-		if (gmtdefs.verbose) fprintf (stderr, "%s: Working on block # %5d\r", GMT_program, bin);
+		if (gmtdefs.verbose) fprintf (stderr, "%s: Working on block # %5ld\r", GMT_program, bin);
 
-		if ((err = GMT_get_shore_bin (ind, &c, Ctrl->A.area, Ctrl->A.low, Ctrl->A.high))) {
+		if ((err = GMT_get_shore_bin (ind, &c))) {
 			fprintf (stderr, "%s: %s [%s resolution shoreline]\n", GMT_program, GMT_strerror(err), shore_resolution[base]);
 			exit (EXIT_FAILURE);
 		}
@@ -305,7 +300,7 @@ int main (int argc, char **argv)
 
 			/* Assemble one or more segments into polygons */
 
-			np = GMT_assemble_shore (&c, direction, Ctrl->A.low, TRUE, greenwich, west_border, east_border, &p);
+			np = GMT_assemble_shore (&c, direction, TRUE, greenwich, west_border, east_border, &p);
 
 			/* Get clipped polygons in x,y inches that can be processed */
 
@@ -327,12 +322,12 @@ int main (int argc, char **argv)
 					if (p[k].lat[i] < ymin) ymin = p[k].lat[i];
 					if (p[k].lat[i] > ymax) ymax = p[k].lat[i];
 				}
-				i_min = (int)MAX (0, ceil (xmin * i_dx_inch - del_off - GMT_CONV_LIMIT));
+				i_min = (GMT_LONG)MAX (0, ceil (xmin * i_dx_inch - del_off - GMT_CONV_LIMIT));
 				if (i_min > nx1) i_min = 0;
-				i_max = (int)MIN (nx1, floor (xmax * i_dx_inch - del_off + GMT_CONV_LIMIT));
+				i_max = (GMT_LONG)MIN (nx1, floor (xmax * i_dx_inch - del_off + GMT_CONV_LIMIT));
 				if (i_max <= 0 || i_max < i_min) i_max = nx1;
-				j_min = (int)MAX (0, ceil ((project_info.ymax - ymax) * i_dy_inch - del_off - GMT_CONV_LIMIT));
-				j_max = (int)MIN (ny1, floor ((project_info.ymax - ymin) * i_dy_inch - del_off + GMT_CONV_LIMIT));
+				j_min = (GMT_LONG)MAX (0, ceil ((project_info.ymax - ymax) * i_dy_inch - del_off - GMT_CONV_LIMIT));
+				j_max = (GMT_LONG)MIN (ny1, floor ((project_info.ymax - ymin) * i_dy_inch - del_off + GMT_CONV_LIMIT));
 
 				for (j = j_min; j <= j_max; j++) {
 					for (i = i_min; i <= i_max; i++) {
@@ -356,6 +351,9 @@ int main (int argc, char **argv)
 			k = INT_MAX;	/* Initialize to outside range of levels (4 is highest) */
 			/* Visit each of the 4 nodes, test if it is inside -R, and if so update lowest level found so far */
 
+if (c.lon_sw == 179.0 && c.lat_sw == -80.0) {
+	k = INT_MAX;
+}
 			if (!GMT_map_outside (c.lon_sw, c.lat_sw)) k = MIN (k, c.node_level[0]);			/* SW */
 			if (!GMT_map_outside (c.lon_sw + c.bsize, c.lat_sw)) k = MIN (k, c.node_level[1]);		/* SE */
 			if (!GMT_map_outside (c.lon_sw + c.bsize, c.lat_sw - c.bsize)) k = MIN (k, c.node_level[2]);	/* NE */
@@ -367,14 +365,16 @@ int main (int argc, char **argv)
 
 			/* Determine nodes to initialize */
 
-			j_min = (int)MAX (0, ceil ((header.y_max - c.lat_sw - c.bsize) * i_dy - del_off));
-			j_max = (int)MIN (ny1, floor ((header.y_max - c.lat_sw) * i_dy - del_off));
-			i_min = (int)ceil (fmod (c.lon_sw - header.x_min + 360.0, 360.0) * i_dx - del_off);
-			i_max = (int)floor (fmod (c.lon_sw + c.bsize - header.x_min + 360.0, 360.0) * i_dx - del_off);
-			if (wrap && i_max < i_min) i_max += nx1;
+			j_min = (GMT_LONG)MAX (0, ceil ((header.y_max - c.lat_sw - c.bsize) * i_dy - del_off));
+			j_max = (GMT_LONG)MIN (ny1, floor ((header.y_max - c.lat_sw) * i_dy - del_off));
+			i_min = (GMT_LONG)ceil (fmod (c.lon_sw - header.x_min + 360.0, 360.0) * i_dx - del_off);
+			i_max = (GMT_LONG)floor (fmod (c.lon_sw + c.bsize - header.x_min + 360.0, 360.0) * i_dx - del_off);
+			/* Was: if (wrap && i_max < i_min) i_max += nx1; */
+			if (wrap && i_max < i_min) i_max += header.nx;
 			for (j = j_min; j <= j_max; j++) {
 				for (i = i_min; i <= i_max; i++) {
-					ii = (wrap) ? i % nx1 : i;
+				/*	Was: ii = (wrap) ? i % nx1 : i; */
+					ii = (wrap) ? i % header.nx : i;
 					if (ii < 0 || ii > nx1) continue;
 					ij = GMT_IJ (j, ii, header.nx);
 					data[ij] = (float)k;
@@ -394,7 +394,7 @@ int main (int argc, char **argv)
 	}
 
 	if (wrap && header.node_offset == 0) { /* Copy over values to the repeating right column */
-		for (j = ij = 0; j < header.ny; j++, ij += header.nx) data[ij+nx1] = data[ij];
+		for (j = 0, ij = 0; j < header.ny; j++, ij += header.nx) data[ij+nx1] = data[ij];
 	}
 	
 	if (temp_shift) {
@@ -410,21 +410,21 @@ int main (int argc, char **argv)
 	GMT_free ((void *)x);
 	GMT_free ((void *)y);
 
-	Free_Grdlandmask_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdlandmask_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdlandmask_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdlandmask_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDLANDMASK_CTRL *C;
 	
-	C = (struct GRDLANDMASK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDLANDMASK_CTRL), "New_Grdlandmask_Ctrl");
+	C = (struct GRDLANDMASK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDLANDMASK_CTRL), "New_grdlandmask_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
-	C->A.high = GMT_MAX_GSHHS_LEVEL;				/* Include all GSHHS levels */
+	C->A.info.high = GMT_MAX_GSHHS_LEVEL;				/* Include all GSHHS levels */
 	C->D.set = 'l';							/* Low-resolution coastline data */
 	memset ((void *)C->N.mask, 0, (size_t)(GRDLANDMASK_N_CLASSES * sizeof (float)));	/* Default "wet" value = 0 */
 	C->N.mask[1] = C->N.mask[3] = 1.0;				/* Default for "dry" areas = 1 (inside) */
@@ -432,7 +432,7 @@ void *New_Grdlandmask_Ctrl () {	/* Allocate and initialize a new control structu
 	return ((void *)C);
 }
 
-void Free_Grdlandmask_Ctrl (struct GRDLANDMASK_CTRL *C) {	/* Deallocate control structure */
+void Free_grdlandmask_Ctrl (struct GRDLANDMASK_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
