@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmask.c,v 1.71 2009/01/09 04:02:33 guru Exp $
+ *	$Id: grdmask.c,v 1.80 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@
 struct GRDMASK_CTRL {
 	struct A {	/* -A[m|p|step] */
 		BOOLEAN active;
-		int mode;
+		GMT_LONG mode;
 		double step;
 	} A;
 	struct F {	/* -F */
@@ -72,12 +72,11 @@ int main (int argc, char **argv)
 {
 	BOOLEAN	error = FALSE, done, nofile = TRUE, periodic = FALSE, resample = FALSE;
 
-	char line[BUFSIZ], ptr[BUFSIZ];
+	char line[BUFSIZ], ptr[BUFSIZ], *not_used = NULL;
 
-	int	i, j, side, fno, n_files = 0, n_args;
-	int	di, dj, i0, j0, n_fields, n_expected_fields, pos;
-	int 	distance_flag = 0, n_pol = 0;
-	
+	GMT_LONG	i, j, side, fno, n_files = 0, n_args;
+	GMT_LONG	di, dj, i0, j0, n_fields, n_expected_fields, pos;
+	GMT_LONG 	distance_flag = 0, n_pol = 0;
 	GMT_LONG	k, ij, nm, n_path, n_read, n_alloc = GMT_CHUNK;
 
 	float *data;
@@ -92,11 +91,11 @@ int main (int argc, char **argv)
 	struct GMT_LINE_SEGMENT P;
 	struct GRDMASK_CTRL *Ctrl;
 	
-	void *New_Grdmask_Ctrl (), Free_Grdmask_Ctrl (struct GRDMASK_CTRL *C);
+	void *New_grdmask_Ctrl (), Free_grdmask_Ctrl (struct GRDMASK_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDMASK_CTRL *)New_Grdmask_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDMASK_CTRL *)New_grdmask_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&header, argc, argv, FALSE);
 
@@ -109,11 +108,13 @@ int main (int argc, char **argv)
 				/* Common parameters */
 
 				case 'H':
+				case 'M':
 				case 'R':
 				case 'V':
 				case ':':
 				case 'b':
 				case 'f':
+				case 'm':
 				case '\0':
 					error += GMT_parse_common_options (argv[i], &header.x_min, &header.x_max, &header.y_min, &header.y_max);
 					break;
@@ -157,9 +158,6 @@ int main (int argc, char **argv)
 					GMT_io.in_col_type[GMT_Y] = GMT_io.out_col_type[GMT_Y] = GMT_IS_LAT;
 					fprintf (stderr, "%s: Option -L is obsolete (but is processed correctly).  Please use -f instead\n", GMT_program);
 					break;
-				case 'M':
-					GMT_multisegment (&argv[i][2]);
-					break;
 				case 'S':
 					Ctrl->S.active = TRUE;
 					Ctrl->S.radius = GMT_getradius (&argv[i][2]);
@@ -179,7 +177,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "grdmask %s - Create mask grid file from polygons or point coverage\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdmask [<xyfiles>] -G<mask_grd_file> %s\n", GMT_I_OPT);
 		fprintf (stderr, "\t%s [-A[m|p]] [-F] [%s] [-N<out>/<edge>/<in>]\n", GMT_Rgeo_OPT, GMT_H_OPT);
-		fprintf (stderr, "\t[%s] [-S<radius>[m|c|k|K] [-V] [%s] [%s] [%s]\n\n", GMT_Mo_OPT, GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
+		fprintf (stderr, "\t[-S<radius>[m|c|k|K] [-V] [%s] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT, GMT_mo_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -192,7 +190,6 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   unless m or p is appended to first follow meridian then parallel, or vice versa.\n");
 		fprintf (stderr, "\t-F Force pixel registration for output grid [Default is gridline orientation]\n");
 		GMT_explain_option ('H');
-		GMT_explain_option ('M');
 		fprintf (stderr, "\t-N sets values to use if point is outside, on the path, or inside.\n");
 		fprintf (stderr, "\t   NaN is a valid entry.  Default values are 0/0/1.\n");
 		fprintf (stderr, "\t-S sets search radius in -R, -I units; append m or c for minutes or seconds.\n");
@@ -200,7 +197,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   whether they are inside a circle of specified radius [0] from the nearest data point.\n");
 		fprintf (stderr, "\t   Append k for km (implies -R,-I in degrees), use flat Earth approximation.\n");
 		fprintf (stderr, "\t   Append K for km (implies -R,-I in degrees), use exact geodesic distances.\n");
-		fprintf (stderr, "\t   If the current ELLIPSOID is Sphere then spherical great circle distances are used.\n");
+		fprintf (stderr, "\t   If the current ELLIPSOID is spherical then great circle distances are used.\n");
 		fprintf (stderr, "\t    [Default is to treat xyfiles as polygons and use inside/outside searching].\n");
 		GMT_explain_option ('V');
 		GMT_explain_option (':');
@@ -208,6 +205,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('n');
 		fprintf (stderr, "\t    [Default is 2 input columns].\n");
 		GMT_explain_option ('f');
+		GMT_explain_option ('m');
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
@@ -243,7 +241,7 @@ int main (int argc, char **argv)
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 	if (Ctrl->S.unit == 'k') distance_flag = 1;
@@ -277,12 +275,12 @@ int main (int argc, char **argv)
 		double width;
 		shrink = cosd (MAX(fabs(header.y_min), fabs(header.y_max)));
 		width = (shrink < GMT_CONV_LIMIT) ? DBL_MAX : ceil (Ctrl->S.radius / (project_info.KM_PR_DEG * header.x_inc * shrink));
-		di = (width < (double)header.nx) ? (int) width : header.nx;
-		dj = (int)ceil (Ctrl->S.radius / (project_info.KM_PR_DEG * header.y_inc));
+		di = (width < (double)header.nx) ? (GMT_LONG) width : header.nx;
+		dj = (GMT_LONG)ceil (Ctrl->S.radius / (project_info.KM_PR_DEG * header.y_inc));
 	}
 	else {
-		di = (int)ceil (Ctrl->S.radius * idx);
-		dj = (int)ceil (Ctrl->S.radius * idy);
+		di = (GMT_LONG)ceil (Ctrl->S.radius * idx);
+		dj = (GMT_LONG)ceil (Ctrl->S.radius * idy);
 	}
 	periodic = (GMT_io.in_col_type[GMT_X] == GMT_IS_LON);	/* Dealing with geographic coordinates */
 	resample = (!Ctrl->A.active && periodic);
@@ -340,7 +338,7 @@ int main (int argc, char **argv)
 
 		if (!nofile && gmtdefs.verbose) fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
 
-		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
+		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (line, BUFSIZ, fp);
 
 		n_read = 0;
 		n_fields = GMT_input (fp,  &n_expected_fields, &in);
@@ -358,7 +356,7 @@ int main (int argc, char **argv)
 
 			while (!(GMT_io.status & (GMT_IO_SEGMENT_HEADER | GMT_IO_EOF))) {	/* Keep going until FALSE  */
 				if (GMT_io.status & GMT_IO_MISMATCH) {
-					fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_read);
+					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_read);
 					exit (EXIT_FAILURE);
 				}
 				x[n_path] = in[GMT_X];
@@ -520,7 +518,7 @@ int main (int argc, char **argv)
 						ij = GMT_IJ (j, i, header.nx);
 						data[ij] = (float)Ctrl->N.mask[side];
 					}
-					if (gmtdefs.verbose) fprintf (stderr, "%s: Polygon %d scanning row %5.5d\r", GMT_program, n_pol, j);
+					if (gmtdefs.verbose) fprintf (stderr, "%s: Polygon %ld scanning row %5.5ld\r", GMT_program, n_pol, j);
 				}
 			}
 		}
@@ -535,18 +533,20 @@ int main (int argc, char **argv)
 	GMT_free ((void *)x);
 	GMT_free ((void *)y);
 	GMT_free ((void *)P.coord);
+	GMT_free ((void *)P.min);
+	GMT_free ((void *)P.max);
 
-	Free_Grdmask_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdmask_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdmask_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdmask_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDMASK_CTRL *C;
 	
-	C = (struct GRDMASK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDMASK_CTRL), "New_Grdmask_Ctrl");
+	C = (struct GRDMASK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDMASK_CTRL), "New_grdmask_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->A.step = gmtdefs.line_step;
@@ -554,7 +554,7 @@ void *New_Grdmask_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Grdmask_Ctrl (struct GRDMASK_CTRL *C) {	/* Deallocate control structure */
+void Free_grdmask_Ctrl (struct GRDMASK_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
