@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdproject.c,v 1.49 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdproject.c,v 1.51 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -91,11 +91,11 @@ int main (int argc, char **argv)
 	struct GMT_EDGEINFO edgeinfo;
 	struct GRDPROJECT_CTRL *Ctrl;
 
-	void *New_Grdproject_Ctrl (), Free_Grdproject_Ctrl (struct GRDPROJECT_CTRL *C);
+	void *New_grdproject_Ctrl (), Free_grdproject_Ctrl (struct GRDPROJECT_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDPROJECT_CTRL *)New_Grdproject_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDPROJECT_CTRL *)New_grdproject_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	infile = CNULL;
 	w = e = s = n = 0.0;
@@ -548,17 +548,17 @@ int main (int argc, char **argv)
 	GMT_free ((void *)geo);
 	GMT_free ((void *)rect);
 
-	Free_Grdproject_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdproject_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdproject_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdproject_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDPROJECT_CTRL *C;
 	
-	C = (struct GRDPROJECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDPROJECT_CTRL), "New_Grdproject_Ctrl");
+	C = (struct GRDPROJECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDPROJECT_CTRL), "New_grdproject_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->S.antialias = TRUE; C->S.interpolant = BCR_BICUBIC; C->S.threshold = 0.5;
@@ -566,7 +566,7 @@ void *New_Grdproject_Ctrl () {	/* Allocate and initialize a new control structur
 	return ((void *)C);
 }
 
-void Free_Grdproject_Ctrl (struct GRDPROJECT_CTRL *C) {	/* Deallocate control structure */
+void Free_grdproject_Ctrl (struct GRDPROJECT_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
