@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdsample.c,v 1.53 2008/05/01 18:36:32 remko Exp $
+ *	$Id: grdsample.c,v 1.63 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ struct GRDSAMPLE_CTRL {
 	} L;
 	struct Q {	/* -Q[b|c|l|n][[/]<threshold>] */
 		BOOLEAN active;
-		int interpolant;
+		GMT_LONG interpolant;
 		double threshold;
 	} Q;
 	struct T {	/* -T */
@@ -63,9 +63,7 @@ int main (int argc, char **argv)
 
 	char *infile = CNULL, format[BUFSIZ];
 
-	int i, j, ii = 0, jj = 0;
-
-	GMT_LONG ij, nm;
+	GMT_LONG ij, nm, i, j, ii = 0, jj = 0;
 	
 	float *a, *b;
 
@@ -76,11 +74,11 @@ int main (int argc, char **argv)
 	struct GMT_BCR bcr;
 	struct GRDSAMPLE_CTRL *Ctrl;
 
-	void *New_Grdsample_Ctrl (), Free_Grdsample_Ctrl (struct GRDSAMPLE_CTRL *C);
+	void *New_grdsample_Ctrl (), Free_grdsample_Ctrl (struct GRDSAMPLE_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDSAMPLE_CTRL *)New_Grdsample_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDSAMPLE_CTRL *)New_grdsample_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	GMT_grd_init (&grd_b, argc, argv, FALSE);
 
@@ -110,9 +108,9 @@ int main (int argc, char **argv)
 					break;
 				case 'N':	/* Backwards compatible.  nx/ny can now be set with -I */
 					Ctrl->I.active = TRUE;
-					sscanf (&argv[i][2], "%d/%d", &ii, &jj);
+					sscanf (&argv[i][2], "%ld/%ld", &ii, &jj);
 					if (jj == 0) jj = ii;
-					sprintf (format, "%d+/%d+", ii, jj);
+					sprintf (format, "%ld+/%ld+", ii, jj);
 					GMT_getinc (format, &Ctrl->I.xinc, &Ctrl->I.yinc);
 					break;
 				case 'I':
@@ -144,7 +142,7 @@ int main (int argc, char **argv)
 								Ctrl->Q.threshold = atof (&argv[i][j]);
 								if (j == 2 && Ctrl->Q.threshold < GMT_SMALL) {
 									Ctrl->Q.interpolant = BCR_NEARNEIGHBOR;
-									fprintf (stderr, "%s: Warning: Option -Q0 depreciated. Use -Qn instead.\n", GMT_program);
+									fprintf (stderr, "%s: Warning: Option -Q0 deprecated. Use -Qn instead.\n", GMT_program);
 								}
 								j = 5; break;
 						}
@@ -164,7 +162,7 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "grdsample %s - Resample a gridded file onto a new grid\n\n", GMT_VERSION);
+		fprintf (stderr, "grdsample %s - Resample a grid file onto a new grid\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdsample <old_grdfile> -G<new_grdfile> [-F] [%s] [-L<flag>]\n", GMT_I_OPT);
 		fprintf (stderr, "\t[-Q[<value>]] [%s] [-T] [-V] [%s]\n", GMT_Rgeo_OPT, GMT_f_OPT);
 
@@ -196,6 +194,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->F.active, &Ctrl->I.active);
+	
 	if (Ctrl->Q.active && (Ctrl->Q.threshold < 0.0 || Ctrl->Q.threshold > 1.0)) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -Q:  threshold must be in [0,1] range\n", GMT_program);
 		error++;
@@ -250,7 +250,7 @@ int main (int argc, char **argv)
 
 	GMT_boundcond_param_prep (&grd_a, &edgeinfo);
 
-	nm = ((size_t)grd_a.nx + 4) * ((size_t)grd_a.ny + 4);	/* Reserve space for padding */
+	nm = GMT_get_nm (4 + grd_a.nx, 4 + grd_a.ny);	/* Reserve space for padding */
 	a = (float *) GMT_memory (VNULL, (size_t)nm, sizeof(float), GMT_program);
 
 	if (project_info.region_supplied) {
@@ -271,7 +271,7 @@ int main (int argc, char **argv)
 
 	GMT_err_fail (GMT_grd_RI_verify (&grd_b, 1), Ctrl->G.file);
 
-	nm = ((size_t)grd_b.nx) * ((size_t)grd_b.ny);
+	nm = GMT_get_nm (grd_b.nx, grd_b.ny);
 	b = (float *) GMT_memory (VNULL, (size_t)nm, sizeof(float), GMT_program);
 
 	sprintf (format, "%%s: New grid (%s/%s/%s/%s) nx = %%d ny = %%d dx = %s dy = %s node_offset = %%d\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
@@ -322,24 +322,24 @@ int main (int argc, char **argv)
 	GMT_free ((void *)b);
 	GMT_free ((void *)lon);
 
-	Free_Grdsample_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdsample_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdsample_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdsample_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDSAMPLE_CTRL *C;
 	
-	C = (struct GRDSAMPLE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDSAMPLE_CTRL), "New_Grdsample_Ctrl");
+	C = (struct GRDSAMPLE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDSAMPLE_CTRL), "New_grdsample_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->Q.interpolant = BCR_BICUBIC; C->Q.threshold = 1.0;
 	return ((void *)C);
 }
 
-void Free_Grdsample_Ctrl (struct GRDSAMPLE_CTRL *C) {	/* Deallocate control structure */
+void Free_grdsample_Ctrl (struct GRDSAMPLE_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
