@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrack.c,v 1.57 2008/03/24 08:58:31 guru Exp $
+ *	$Id: grdtrack.c,v 1.75 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -48,8 +48,8 @@ struct GRDTRACK_CTRL {
 		BOOLEAN active;
 		char *file;
 		double scale, lat;
-		int mode;
-		int type;	/*HIDDEN */
+		GMT_LONG mode;
+		GMT_LONG type;	/*HIDDEN */
 	} G;
 	struct L {	/* -L<flag> */
 		BOOLEAN active;
@@ -57,7 +57,7 @@ struct GRDTRACK_CTRL {
 	} L;
 	struct Q {	/* -Q[b|c|l|n][[/]<threshold>] */
 		BOOLEAN active;
-		int interpolant;
+		GMT_LONG interpolant;
 		double threshold;
 	} Q;
 	struct S {	/* -S */
@@ -72,11 +72,10 @@ int main (int argc, char **argv)
 {
 	BOOLEAN error = FALSE, pure_ascii = FALSE;
 
-	char line[BUFSIZ];
+	char line[BUFSIZ], *not_used = NULL;
 
-	int i, j, ix, iy, mx, my, nx, ny, n_fields;
-	int n_output = 0, n_expected_fields = 0;
-	
+	GMT_LONG i, j, ix, iy, mx, my, nx, ny, n_fields;
+	GMT_LONG n_output = 0, n_expected_fields = 0;
 	GMT_LONG nm, n_points = 0, n_read = 0;
 
 	float *f;
@@ -90,11 +89,11 @@ int main (int argc, char **argv)
 	struct GMT_BCR bcr;
 	struct GRDTRACK_CTRL *Ctrl;
 
-	void *New_Grdtrack_Ctrl (), Free_Grdtrack_Ctrl (struct GRDTRACK_CTRL *C);
+	void *New_grdtrack_Ctrl (), Free_grdtrack_Ctrl (struct GRDTRACK_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDTRACK_CTRL *) New_Grdtrack_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDTRACK_CTRL *) New_grdtrack_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	west = east = south = north = 0.0;
 	memset ((void *)line, 0, (size_t)BUFSIZ);
@@ -109,11 +108,13 @@ int main (int argc, char **argv)
 				/* Common parameters */
 
 				case 'H':
+				case 'M':
 				case 'R':
 				case 'V':
 				case ':':
 				case 'b':
 				case 'f':
+				case 'm':
 				case '\0':
 					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
@@ -123,7 +124,7 @@ int main (int argc, char **argv)
 				case 'G':
 					Ctrl->G.active = TRUE;
 					if (strchr (argv[i], ',') && !strchr (argv[i], '?')) {	/* IMG grid file with required parameters */
-						if ((j = sscanf (&argv[i][2], "%[^,],%lf,%d,%lf", line, &Ctrl->G.scale, &Ctrl->G.mode, &Ctrl->G.lat)) < 3) {
+						if ((j = sscanf (&argv[i][2], "%[^,],%lf,%ld,%lf", line, &Ctrl->G.scale, &Ctrl->G.mode, &Ctrl->G.lat)) < 3) {
 							fprintf (stderr, "%s: SYNTAX ERROR -G option: Give imgfile, scale, mode [and optionally max_lat]\n", GMT_program);
 							error = TRUE;
 						}
@@ -145,12 +146,9 @@ int main (int argc, char **argv)
 					}
 					fprintf (stderr, "%s: Option -L is obsolete (but is processed correctly).  Please use -f instead\n", GMT_program);
 					break;
-				case 'M':
-					GMT_multisegment (&argv[i][2]);
-					break;
 				case 'N':	/* Backwards compatible */
 					Ctrl->Q.interpolant = BCR_NEARNEIGHBOR;
-					fprintf (stderr, "%s: Warning: Option -N depreciated. Use -Qn instead.\n", GMT_program);
+					fprintf (stderr, "%s: Warning: Option -N deprecated. Use -Qn instead.\n", GMT_program);
 					break;
 				case 'Q':
 					Ctrl->Q.active = TRUE;
@@ -170,7 +168,7 @@ int main (int argc, char **argv)
 								Ctrl->Q.threshold = atof (&argv[i][j]);
 								if (j == 2 && Ctrl->Q.threshold < GMT_SMALL) {
 									Ctrl->Q.interpolant = BCR_NEARNEIGHBOR;
-									fprintf (stderr, "%s: Warning: Option -Q0 depreciated. Use -Qn instead.\n", GMT_program);
+									fprintf (stderr, "%s: Warning: Option -Q0 deprecated. Use -Qn instead.\n", GMT_program);
 								}
 								j = 5; break;
 						}
@@ -197,15 +195,15 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "grdtrack %s - Sampling of a 2-D gridded netCDF grid file along 1-D trackline\n\n", GMT_VERSION);
-		fprintf (stderr, "usage: grdtrack <xyfile> -G<grdfile> [%s] [-L<flag>] [%s] [-Q[b|c|l|n][[/]<threshold>]]\n", GMT_H_OPT, GMT_M_OPT); 
-		fprintf (stderr, "\t[%s] [-S] [-V] [-Z] [%s] [%s]\n\t[%s]\n", GMT_Rgeo_OPT, GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
+		fprintf (stderr, "usage: grdtrack <xyfile> -G<grdfile> [%s] [-L<flag>] [-Q[b|c|l|n][[/]<threshold>]]\n", GMT_H_OPT); 
+		fprintf (stderr, "\t[%s] [-S] [-V] [-Z] [%s] [%s]\n\t[%s] [%s]\n", GMT_Rgeo_OPT, GMT_t_OPT, GMT_b_OPT, GMT_f_OPT, GMT_m_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr, "\t<xyfile> is an multicolumn ASCII file with (lon,lat) in the first two columns\n");
 		fprintf (stderr, "\t-G <grdfile> is the name of the 2-D binary data set to sample\n");
 		fprintf (stderr, "\t   If the file is a Sandwell/Smith Mercator grid (IMG format) instead,\n");
-		fprintf (stderr, "\t   append comma-separated scale (0.1 or 1), mode, and optionally max latitude [72.0059773539].  Modes are\n");
+		fprintf (stderr, "\t   append comma-separated scale (0.1 or 1), mode, and optionally max latitude [%g].  Modes are\n", GMT_IMG_MAXLAT_80);
 		fprintf (stderr, "\t     0 = img file w/ no constraint code, interpolate to get data at track.\n");
                 fprintf (stderr, "\t     1 = img file w/ constraints coded, interpolate to get data at track.\n");
                 fprintf (stderr, "\t     2 = img file w/ constraints coded, gets data only at constrained points, NaN elsewhere.\n");
@@ -219,7 +217,6 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   x for periodic boundary conditions on x\n");
 		fprintf (stderr, "\t   y for periodic boundary conditions on y\n");
 		fprintf (stderr, "\t   [Default is natural conditions for grids and geographic for IMG grids]\n");
-		GMT_explain_option ('M');
 		fprintf (stderr, "\t-Q Quick mode, use bilinear rather than bicubic [Default] interpolation.\n");
 		fprintf (stderr, "\t   Alternatively, select interpolation mode by adding b = B-spline, c = bicubic,\n");
 		fprintf (stderr, "\t   l = bilinear, or n = nearest-neighbor.\n");
@@ -238,6 +235,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('o');
 		GMT_explain_option ('n');
 		GMT_explain_option ('f');
+		GMT_explain_option ('m');
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
@@ -278,7 +276,7 @@ int main (int argc, char **argv)
 	
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 	pure_ascii = !(GMT_io.binary[GMT_IN] || GMT_io.binary[GMT_OUT]);
@@ -291,6 +289,7 @@ int main (int argc, char **argv)
 #endif
 	}
 
+	GMT_grd_init (&grd, argc, argv, FALSE);
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
 	if (Ctrl->G.type == 0) {	/* Regular GMT grids */
 		GMT_err_fail (GMT_read_grd_info (Ctrl->G.file, &grd), Ctrl->G.file);
@@ -304,7 +303,7 @@ int main (int argc, char **argv)
 		nx = GMT_get_n (west, east, grd.x_inc, grd.node_offset);
 		ny = GMT_get_n (south, north, grd.y_inc, grd.node_offset);
 		mx = nx + 4;	my = ny + 4;
-		nm = ((GMT_LONG)mx) * ((GMT_LONG)my);
+		nm = GMT_get_nm (mx, my);
 
 		f = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 
@@ -333,17 +332,18 @@ int main (int argc, char **argv)
 	
 	if (GMT_io.io_header[GMT_IN]) {	/* First echo headers, if any */
 		for (i = 0; i < GMT_io.n_header_recs - 1; i++) {
-			GMT_fgets (line, BUFSIZ, fp);
+			not_used = GMT_fgets (line, BUFSIZ, fp);
 			if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", line);
 		}
-		GMT_fgets (line, BUFSIZ, fp);
-		line[strlen(line)-1] = 0;
+		not_used = GMT_fgets (line, BUFSIZ, fp);
+		GMT_chop (line);
 		if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s\tsample\n", line);
 	}
 
-	ix = (gmtdefs.xy_toggle[1]);	iy = 1 - ix;	/* These are used for output purposes only */
+	ix = (gmtdefs.xy_toggle[GMT_OUT]);	iy = 1 - ix;	/* These are used for output purposes only */
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
 	memset ((void *)line, 0, (size_t)BUFSIZ);
+	if (Ctrl->Z.active) GMT_io.out_col_type[0] = GMT_IS_FLOAT;	/* Since we are outputting z in the longitude column */
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
@@ -354,7 +354,7 @@ int main (int argc, char **argv)
 		if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
 		if ((GMT_io.status & GMT_IO_MISMATCH) && n_fields < 2) {
-			fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_read);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_read);
 			exit (EXIT_FAILURE);
 		}
 		if (n_output == 0) n_output = n_expected_fields + 1;
@@ -362,17 +362,17 @@ int main (int argc, char **argv)
 		n_read++;
 
 		if (Ctrl->G.type == 1) {	/* Mercator IMG grid - get Mercator coordinates x,y */
-			GMT_geo_to_xy (in[0], in[1], &x, &y);
+			GMT_geo_to_xy (in[GMT_X], in[GMT_Y], &x, &y);
 			if (x > grd.x_max) x -= 360.0;
 		}
 		else {			/* Regular grd, just copy the x,y */
-			x = in[0];
-			y = in[1];
+			x = in[GMT_X];
+			y = in[GMT_Y];
 		}
 
 		/* If point is outside grd area, shift it using periodicity or skip if not periodic. */
 
-		while ( (in[1] < grd.y_min) && (edgeinfo.nyp > 0) ) y += (grd.y_inc * edgeinfo.nyp);
+		while ( (in[GMT_Y] < grd.y_min) && (edgeinfo.nyp > 0) ) y += (grd.y_inc * edgeinfo.nyp);
 		if (y < grd.y_min) continue;
 
 		while ( (y > grd.y_max) && (edgeinfo.nyp > 0) ) y -= (grd.y_inc * edgeinfo.nyp);
@@ -426,17 +426,17 @@ int main (int argc, char **argv)
 	GMT_free ((void *)f);
 	GMT_free ((void *)out);
 
-	Free_Grdtrack_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdtrack_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grdtrack_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdtrack_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDTRACK_CTRL *C;
 	
-	C = (struct GRDTRACK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDTRACK_CTRL), "New_Grdtrack_Ctrl");
+	C = (struct GRDTRACK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDTRACK_CTRL), "New_grdtrack_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->G.scale = 1.0;
@@ -444,7 +444,7 @@ void *New_Grdtrack_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Grdtrack_Ctrl (struct GRDTRACK_CTRL *C) {	/* Deallocate control structure */
+void Free_grdtrack_Ctrl (struct GRDTRACK_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
