@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrend.c,v 1.35 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdtrend.c,v 1.38 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -131,19 +131,20 @@ int main(int argc, char **argv)
 
 	void	set_up_vals(double *val, GMT_LONG nval, double vmin, double vmax, double dv, GMT_LONG pixel_reg);		/* Store x[i], y[j] once for all to save time  */
 	void	grd_trivial_model(float *data, GMT_LONG nx, GMT_LONG ny, double *xval, double *yval, double *gtd, GMT_LONG n_model);	/* Fit trivial models.  See Remarks above.  */
+	void	load_pstuff(double *pstuff, GMT_LONG n_model, double x, double y, GMT_LONG newx, GMT_LONG newy);		/* Compute Legendre polynomials of x[i],y[j] as needed  */
 	void	compute_trend(float *trend, GMT_LONG nx, GMT_LONG ny, double *xval, double *yval, double *gtd, GMT_LONG n_model, double *pstuff);	/* Find trend from a model  */
 	void	compute_resid(float *data, float *trend, float *resid, GMT_LONG nxy);	/* Find residuals from a trend  */
 	void	compute_chisq(float *resid, float *weight, GMT_LONG nxy, double *chisq, double scale);	/* Find Chi-Squared from weighted residuals  */
 	void	compute_robust_weight(float *resid, float *weight, GMT_LONG nxy, double *scale);	/* Find weights from residuals  */
 	void	write_model_parameters(double *gtd, GMT_LONG n_model);	/* Do reports if gmtdefs.verbose == TRUE  */
 	void	load_gtg_and_gtd(float *data, GMT_LONG nx, GMT_LONG ny, double *xval, double *yval, double *pstuff, double *gtg, double *gtd, GMT_LONG n_model, float *weight, GMT_LONG weighted);		/* Fill normal equations matrices  */
-	void	*New_Grdtrend_Ctrl (), Free_Grdtrend_Ctrl (struct GRDTREND_CTRL *C);
+	void	*New_grdtrend_Ctrl (), Free_grdtrend_Ctrl (struct GRDTREND_CTRL *C);
 
 /* Execution begins here with loop over arguments:  */
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDTREND_CTRL *) New_Grdtrend_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct GRDTREND_CTRL *) New_grdtrend_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -236,7 +237,8 @@ int main(int argc, char **argv)
 
 /* End of argument parsing.  */
 
-	trivial = ( (Ctrl->N.value < 5) && (!(Ctrl->N.robust)) && (!Ctrl->W.file) );
+	weighted = (Ctrl->N.robust || Ctrl->W.active);
+	trivial = (Ctrl->N.value < 5 && !weighted);
 
 /* Read the input file:  */
 
@@ -266,11 +268,10 @@ int main(int argc, char **argv)
 	gtd = (double *) GMT_memory (VNULL, (size_t)Ctrl->N.value, sizeof (double), GMT_program);
 	old = (double *) GMT_memory (VNULL, (size_t)Ctrl->N.value, sizeof (double), GMT_program);
 	pstuff = (double *) GMT_memory (VNULL, (size_t)Ctrl->N.value, sizeof (double), GMT_program);
-
+	pstuff[0] = 1.0; /* This is P0(x) = 1, which is not altered in this program. */
 
 /* If a weight array is needed, get one:  */
 
-	weighted = (Ctrl->N.robust || Ctrl->W.file);
 	if (weighted) {
 		weight = (float *) GMT_memory (VNULL, (size_t)nxy, sizeof (float), GMT_program);
 		if (!GMT_access (Ctrl->W.file, R_OK)) {	/* We have weights on input  */
@@ -283,9 +284,8 @@ int main(int argc, char **argv)
 			else
 				GMT_err_fail (GMT_read_grd (Ctrl->W.file, &head_w, weight, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->W.file);
 		}
-		else {
+		else
 			for (i = 0; i < nxy; i++) weight[i] = 1.0;
-		}
 	}
 
 /* End of weight set up.  */
@@ -323,7 +323,7 @@ int main(int argc, char **argv)
 			sprintf(format, "%%s Robust iteration %%d:  Old Chi Squared:  %s  New Chi Squared %s\n", gmtdefs.d_format, gmtdefs.d_format);
 			do {
 				old_chisq = chisq;
-				for(k = 0; k < Ctrl->N.value; k++) old[k] = gtd[k];
+				for (k = 0; k < Ctrl->N.value; k++) old[k] = gtd[k];
 				compute_robust_weight(resid, weight, nxy, &scale);
 				load_gtg_and_gtd(data, head_d.nx, head_d.ny, xval, yval, pstuff, gtg, gtd, Ctrl->N.value, weight, weighted);
 				GMT_gauss (gtg, gtd, Ctrl->N.value, Ctrl->N.value, zero_test, &ierror, 1);
@@ -336,11 +336,11 @@ int main(int argc, char **argv)
 				compute_chisq(resid, weight, nxy, &chisq, scale);
 				if (gmtdefs.verbose) fprintf (stderr, format, GMT_program, iterations, old_chisq, chisq);
 				iterations++;
-			} while ( (old_chisq / chisq) > 1.0001);
+			} while (old_chisq / chisq > 1.0001);
 
 			/* Get here when new model not significantly better; use old one:  */
 
-			for(k = 0; k < Ctrl->N.value; k++) gtd[k] = old[k];
+			for (k = 0; k < Ctrl->N.value; k++) gtd[k] = old[k];
 			compute_trend(trend, head_d.nx, head_d.ny, xval, yval, gtd, Ctrl->N.value, pstuff);
 			compute_resid(data, trend, resid, nxy);
 		}
@@ -377,7 +377,7 @@ int main(int argc, char **argv)
 	GMT_free ((void *)trend);
 	GMT_free ((void *)data);
 
-	Free_Grdtrend_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdtrend_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -431,15 +431,12 @@ void compute_trend (float *trend, GMT_LONG nx, GMT_LONG ny, double *xval, double
 {
 	GMT_LONG	i, j, k;
 	GMT_LONG	ij;
-	void	load_pstuff(double *pstuff, GMT_LONG n_model, double x, double y, GMT_LONG newx, GMT_LONG newy);		/* Compute Legendre polynomials of x[i],y[j] as needed  */
 
 	for (ij = 0, j = 0; j < ny; j++) {
 		for (i = 0; i < nx; i++, ij++) {
 			load_pstuff(pstuff, n_model, xval[i], yval[j], 1, (!(i)));
-			trend[ij] = (float)gtd[0];
-			for (k = 1; k < n_model; k++) {
-				trend[ij] += (float)(pstuff[k]*gtd[k]);
-			}
+			trend[ij] = 0.0;
+			for (k = 0; k < n_model; k++) trend[ij] += (float)(pstuff[k]*gtd[k]);
 		}
 	}
 }
@@ -448,14 +445,7 @@ void compute_resid (float *data, float *trend, float *resid, GMT_LONG nxy)
 {
 	GMT_LONG	i;
 
-	for (i = 0; i < nxy; i++) {
-		if (GMT_is_fnan (data[i])) {
-			resid[i] = data[i];
-		}
-		else {
-			resid[i] = data[i] - trend[i];
-		}
-	}
+	for (i = 0; i < nxy; i++) resid[i] = data[i] - trend[i];
 	return;
 }
 
@@ -507,18 +497,12 @@ void compute_chisq (float *resid, float *weight, GMT_LONG nxy, double *chisq, do
 
 	*chisq = 0.0;
 	for (i = 0; i < nxy; i++) {
-		if (GMT_is_fnan (resid[i]))continue;
+		if (GMT_is_fnan (resid[i])) continue;
 		tmp = resid[i];
 		if (scale != 1.0) tmp /= scale;
 		tmp *= tmp;
-
-		if (weight[i] == 1.0) {
-			*chisq += tmp;
-		}
-		else {
-			/* Weight has already been squared  */
-			*chisq += (tmp * weight[i]);
-		}
+		if (weight[i] != 1.0) tmp *= weight[i];
+		*chisq += tmp;
 	}
 	return;
 }
@@ -537,12 +521,10 @@ void compute_robust_weight (float *resid, float *weight, GMT_LONG nxy, double *s
 	qsort ((void *)weight, (size_t)j, sizeof(float), GMT_comp_float_asc);
 
 	j2 = j / 2;
-	if (j%2) {
+	if (j%2)
 		mad = weight[j2];
-	}
-	else {
+	else
 		mad = 0.5 *(weight[j2] + weight[j2 - 1]);
-	}
 
 	/* Adjust mad to equal Gaussian sigma:  */
 
@@ -580,7 +562,7 @@ void write_model_parameters (double *gtd, GMT_LONG n_model)
 	sprintf(pbasis[9], "P3(y)");
 
 	sprintf(format, "Coefficient fit to %%s:  %s\n", gmtdefs.d_format);
-	for(i = 0; i < n_model; i++) fprintf (stderr, format, pbasis[i], gtd[i]);
+	for (i = 0; i < n_model; i++) fprintf (stderr, format, pbasis[i], gtd[i]);
 
 	return;
 }
@@ -597,16 +579,13 @@ void load_gtg_and_gtd (float *data, GMT_LONG nx, GMT_LONG ny, double *xval, doub
 
 	GMT_LONG	i, j, k, l, n_used;
 	GMT_LONG	ij;
-	void	load_pstuff(double *pstuff, GMT_LONG n_model, double x, double y, GMT_LONG newx, GMT_LONG newy);		/* Compute Legendre polynomials of x[i],y[j] as needed  */
 
 /*	First zero things out to start:  */
 
 	n_used = 0;
 	for (k = 0; k < n_model; k++) {
 		gtd[k] = 0.0;
-		for (l = 0; l < n_model; l++) {
-			gtg[k*n_model+l] = 0.0;
-		}
+		for (l = 0; l < n_model; l++) gtg[k*n_model+l] = 0.0;
 	}
 
 /*  Now get going.  Have to load_pstuff separately in i and j,
@@ -624,25 +603,18 @@ void load_gtg_and_gtd (float *data, GMT_LONG nx, GMT_LONG ny, double *xval, doub
 
 /* If weighted  */	if (weighted) {
 				/* Loop over all gtg and gtd elements:  */
-				gtd[0] += (data[ij] * weight[ij]);
-				gtg[0] += (weight[ij]);
-				for (k = 1; k < n_model; k++) {
+				for (k = 0; k < n_model; k++) {
 					gtd[k] += (data[ij] * weight[ij] * pstuff[k]);
 					gtg[k] += (weight[ij] * pstuff[k]);
-					for (l = k; l < n_model; l++) {
-						gtg[k + l*n_model] += (pstuff[k]*pstuff[l]*weight[ij]);
-					}
+					for (l = k; l < n_model; l++) gtg[k + l*n_model] += (pstuff[k]*pstuff[l]*weight[ij]);
 				}
 			}
 /* If !weighted  */	else {
 				/* Loop over all gtg and gtd elements:  */
-				gtd[0] += data[ij];
-				for (k = 1; k < n_model; k++) {
+				for (k = 0; k < n_model; k++) {
 					gtd[k] += (data[ij] * pstuff[k]);
 					gtg[k] += pstuff[k];
-					for (l = k; l < n_model; l++) {
-						gtg[k + l*n_model] += (pstuff[k]*pstuff[l]);
-					}
+					for (l = k; l < n_model; l++) gtg[k + l*n_model] += (pstuff[k]*pstuff[l]);
 				}
 /* End if  */		}
 		}
@@ -651,29 +623,27 @@ void load_gtg_and_gtd (float *data, GMT_LONG nx, GMT_LONG ny, double *xval, doub
 
 /* Now if !weighted, use more accurate sum for gtg[0], and set symmetry:  */
 
-	if (!(weighted)) gtg[0] = n_used;
+	if (!weighted) gtg[0] = n_used;
 
 	for (k = 0; k < n_model; k++) {
-		for (l = 0; l < k; l++) {
-			gtg[l + k*n_model] = gtg[k + l*n_model];
-		}
+		for (l = 0; l < k; l++) gtg[l + k*n_model] = gtg[k + l*n_model];
 	}
 /* That is all there is to it!  */
 
 	return;
 }
 
-void *New_Grdtrend_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdtrend_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDTREND_CTRL *C;
 	
-	C = (struct GRDTREND_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDTREND_CTRL), "New_Grdtrend_Ctrl");
+	C = (struct GRDTREND_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDTREND_CTRL), "New_grdtrend_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 		
 	return ((void *)C);
 }
 
-void Free_Grdtrend_Ctrl (struct GRDTREND_CTRL *C) {	/* Deallocate control structure */
+void Free_grdtrend_Ctrl (struct GRDTREND_CTRL *C) {	/* Deallocate control structure */
 	if (C->D.file) free ((void *)C->D.file);	
 	if (C->T.file) free ((void *)C->T.file);	
 	if (C->W.file) free ((void *)C->W.file);	
