@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdview.c,v 1.107 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdview.c,v 1.109 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -164,11 +164,11 @@ int main (int argc, char **argv)
 	GMT_LONG quick_idist(GMT_LONG x1, GMT_LONG y1, GMT_LONG x2, GMT_LONG y2);
 	GMT_LONG get_side (double x, double y, double x_left, double y_bottom, double xinc, double yinc, double dx2, double dy2);
 	BOOLEAN GMT_rgb_is_nan_rgb (int rgb[]);
-	void *New_Grdview_Ctrl (), Free_Grdview_Ctrl (struct GRDVIEW_CTRL *C);
+	void *New_grdview_Ctrl (), Free_grdview_Ctrl (struct GRDVIEW_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDVIEW_CTRL *)New_Grdview_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDVIEW_CTRL *)New_grdview_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	topofile = CNULL;
 	GMT_3D_mode = 1;	/* Only do background axis first; do foreground at end */
@@ -1547,7 +1547,7 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Grdview_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdview_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -1732,10 +1732,10 @@ BOOLEAN GMT_rgb_is_nan_rgb (int rgb[])
 	return (rgb[0] == GMT_bfn[GMT_NAN].rgb[0] && rgb[1] == GMT_bfn[GMT_NAN].rgb[1] && rgb[2] == GMT_bfn[GMT_NAN].rgb[2]);
 }
 
-void *New_Grdview_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdview_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDVIEW_CTRL *C;
 	
-	C = (struct GRDVIEW_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDVIEW_CTRL), "New_Grdview_Ctrl");
+	C = (struct GRDVIEW_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDVIEW_CTRL), "New_grdview_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
@@ -1751,7 +1751,7 @@ void *New_Grdview_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Grdview_Ctrl (struct GRDVIEW_CTRL *C) {	/* Deallocate control structure */
+void Free_grdview_Ctrl (struct GRDVIEW_CTRL *C) {	/* Deallocate control structure */
 	GMT_LONG i;
 	if (C->C.file) free ((void *)C->C.file);	
 	for (i = 0; i < 3; i++) if (C->G.file[i]) free ((void *)C->G.file[i]);	
