@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: greenspline.c,v 1.43 2009/09/09 23:27:03 guru Exp $
+ *	$Id: greenspline.c,v 1.46 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 2008-2009 by P. Wessel
+ *	Copyright (c) 2008-2010 by P. Wessel
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,8 +28,8 @@
  * 5. Minimum curvature spherical spline in tension [Wessel & Becker, Geophys. J. Int, 2008]
  *
  * Originally published as:
- *   "P. Wessel, 2009, A general-purpose Green's function-based interpolator,
- *	Computers & Geosciences, in press".
+ *   "Wessel, P., 2009. A general-purpose Green's function-based interpolator,
+ *	Computers & Geosciences, 35: 1247–1254".
  *
  * Author:	Paul Wessel
  * Date:	05-DEC-2008
@@ -191,7 +191,7 @@ int main (int argc, char **argv)
 
 	struct GREENSPLINE_CTRL *Ctrl;
 
-	void *New_Greenspline_Ctrl (), Free_Greenspline_Ctrl (struct GREENSPLINE_CTRL *C);
+	void *New_greenspline_Ctrl (), Free_greenspline_Ctrl (struct GREENSPLINE_CTRL *C);
 
 	double spline1d_sandwell (double r, double par[], double *z);
 	double spline1d_Wessel_Bercovici (double r, double par[], double *z);
@@ -226,7 +226,7 @@ int main (int argc, char **argv)
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GREENSPLINE_CTRL *)New_Greenspline_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GREENSPLINE_CTRL *)New_greenspline_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 	memset ((void *)par,  0, (size_t)(7*sizeof(double)));
@@ -2227,17 +2227,17 @@ void GMT_check_lattice_cpy (struct GMT_GRD_INFO *info, double *x_inc, double *y_
 	if (active) *active = TRUE;	/* When 4th arg is not NULL it is set to TRUE (for Ctrl->active args) */
 }
 
-void *New_Greenspline_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_greenspline_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GREENSPLINE_CTRL *C;
 	
-	C = (struct GREENSPLINE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GREENSPLINE_CTRL), "New_Greenspline_Ctrl");
+	C = (struct GREENSPLINE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GREENSPLINE_CTRL), "New_greenspline_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->S.mode = SANDWELL_1987_2D;
 	return ((void *)C);
 }
 
-void Free_Greenspline_Ctrl (struct GREENSPLINE_CTRL *C) {	/* Deallocate control structure */
+void Free_greenspline_Ctrl (struct GREENSPLINE_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) GMT_free ((void *)C->C.file);	
 	if (C->G.file) GMT_free ((void *)C->G.file);	
 	if (C->N.file) GMT_free ((void *)C->N.file);	
