@@ -1,6 +1,6 @@
-/* $Id: img2mercgrd.c,v 1.33 2009/09/13 00:52:03 guru Exp $
+/* $Id: img2mercgrd.c,v 1.35 2010/01/05 01:15:48 guru Exp $
  *
- * Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ * Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  * See LICENSE.TXT file for copying and redistribution conditions.
  *
  * img2mercgrd.c
@@ -110,11 +110,11 @@ int main (int argc, char **argv)
 
 	struct IMG2MERCGRD_CTRL *Ctrl;
 	
-	void *New_Img2mercgrd_Ctrl (), Free_Img2mercgrd_Ctrl (struct IMG2MERCGRD_CTRL *C);
+	void *New_img2mercgrd_Ctrl (), Free_img2mercgrd_Ctrl (struct IMG2MERCGRD_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 	
-	Ctrl = (struct IMG2MERCGRD_CTRL *)New_Img2mercgrd_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct IMG2MERCGRD_CTRL *)New_img2mercgrd_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 	
@@ -503,17 +503,17 @@ int main (int argc, char **argv)
 	GMT_free((void *)ix);
 	GMT_free((void *)row);
 	
-	Free_Img2mercgrd_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_img2mercgrd_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Img2mercgrd_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_img2mercgrd_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct IMG2MERCGRD_CTRL *C;
 	
-	C = (struct IMG2MERCGRD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct IMG2MERCGRD_CTRL), "New_Img2mercgrd_Ctrl");
+	C = (struct IMG2MERCGRD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct IMG2MERCGRD_CTRL), "New_img2mercgrd_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->D.min = GMT_IMG_MINLAT;
@@ -525,7 +525,7 @@ void *New_Img2mercgrd_Ctrl () {	/* Allocate and initialize a new control structu
 	return ((void *)C);
 }
 
-void Free_Img2mercgrd_Ctrl (struct IMG2MERCGRD_CTRL *C) {	/* Deallocate control structure */
+void Free_img2mercgrd_Ctrl (struct IMG2MERCGRD_CTRL *C) {	/* Deallocate control structure */
 	if (C->file) free ((void *)C->file);	
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
