@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: makecpt.c,v 1.49 2009/09/09 23:27:03 guru Exp $
+ *	$Id: makecpt.c,v 1.52 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -75,11 +75,11 @@ int main(int argc, char **argv)
 
 	struct MAKECPT_CTRL *Ctrl;
 
-	void *New_Makecpt_Ctrl (), Free_Makecpt_Ctrl (struct MAKECPT_CTRL *C);
+	void *New_makecpt_Ctrl (), Free_makecpt_Ctrl (struct MAKECPT_CTRL *C);
 
 	argc = GMT_begin(argc, argv);
 
-	Ctrl = (struct MAKECPT_CTRL *)New_Makecpt_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct MAKECPT_CTRL *)New_makecpt_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	/* Get list of available color tables in $GMT_SHAREDIR */
 
@@ -198,6 +198,7 @@ int main(int argc, char **argv)
 		nz = 0;
 		while (GMT_fgets (buffer, BUFSIZ, fpl)) {
 			if (GMT_is_a_blank_line (buffer)) continue;	/* Skip blank lines or # comments */
+			GMT_chop (buffer);
 			z[nz] = atof (buffer);
 			nz++;
 			if (nz == n_alloc) {
@@ -254,23 +255,23 @@ int main(int argc, char **argv)
 
 	GMT_free ((void *)z);
 
-	Free_Makecpt_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_makecpt_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Makecpt_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_makecpt_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct MAKECPT_CTRL *C;
 	
-	C = (struct MAKECPT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct MAKECPT_CTRL), "New_Makecpt_Ctrl");
+	C = (struct MAKECPT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct MAKECPT_CTRL), "New_makecpt_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	return ((void *)C);
 }
 
-void Free_Makecpt_Ctrl (struct MAKECPT_CTRL *C) {	/* Deallocate control structure */
+void Free_makecpt_Ctrl (struct MAKECPT_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	if (C->T.file) free ((void *)C->T.file);	
 	GMT_free ((void *)C);	
