@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
-*	$Id: mapproject.c,v 1.95 2009/01/09 04:02:34 guru Exp $
+*	$Id: mapproject.c,v 1.112 2010/01/05 01:15:46 guru Exp $
 *
-*	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
-*	See COPYING file for copying and redistribution conditions.
+*	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+*	See LICENSE.TXT file for copying and redistribution conditions.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
@@ -67,8 +67,7 @@ struct MAPPROJECT_CTRL {	/* All control options for this program (except common
 	} F;
 	struct G {	/* -G<lon0>/<lat0>[/e|E|k|K|m|M|n|N|c|C|d|D] */
 		BOOLEAN active;
-		int mode;		/* 1 = distance to fixed point, 2 = cumulative distances, 3 = incremental distances, 4 = 2nd point in cols 3/4 */
-		BOOLEAN geodesic;	/* TRUE if we want geodesic distances [Default is great circle distances] */
+		GMT_LONG mode;		/* 1 = distance to fixed point, 2 = cumulative distances, 3 = incremental distances, 4 = 2nd point in cols 3/4 */
 		double lon, lat;	/* Fixed point of reference */
 		char unit;
 	} G;
@@ -77,13 +76,13 @@ struct MAPPROJECT_CTRL {	/* All control options for this program (except common
 	} I;
 	struct L {	/* -L<line.xy>[/<unit>] */
 		BOOLEAN active;
-		int mode;	/* 0 = dist to nearest point, 1 = also get the point, 2 = instead get seg#, pt# */
+		GMT_LONG mode;	/* 0 = dist to nearest point, 1 = also get the point, 2 = instead get seg#, pt# */
 		char *file;	/* Name of file with lines */
 		char unit;
 	} L;
 	struct Q {	/* -Q[e|d] */
 		BOOLEAN active;
-		int mode;	/* 1 = print =Qe, 2 print -Qd, 3 print both */
+		GMT_LONG mode;	/* 1 = print =Qe, 2 print -Qd, 3 print both */
 	} Q;
 	struct S {	/* -S */
 		BOOLEAN active;
@@ -98,12 +97,9 @@ struct MAPPROJECT_CTRL {	/* All control options for this program (except common
 
 int main (int argc, char **argv)
 {
-	int k, fno, n_files = 0, x, y, n_args, unit = 0, n_slash;
-	int n_fields, n_expected_fields, proj_type = 0, *n_output, save[2] = {0,0}, two, n_out;
-	int fmt[2], pos;
-	
-	GMT_LONG i, j, n = 0, n_read = 0;
-	
+	GMT_LONG k, fno, n_files = 0, x, y, n_args, unit = 0, n_slash;
+	GMT_LONG n_fields, n_expected_fields, proj_type = 0, *n_output, save[2] = {0,0}, two, n_out;
+	GMT_LONG fmt[2], pos, i, j, n = 0, n_read = 0;
 
 	BOOLEAN error = FALSE;
 	BOOLEAN nofile = TRUE, done = FALSE, first = TRUE;
@@ -119,7 +115,7 @@ int main (int argc, char **argv)
 
 	char line[BUFSIZ], format[BUFSIZ], unit_name[GMT_TEXT_LEN], scale_unit_name[GMT_TEXT_LEN];
 	char txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], p[BUFSIZ], c;
-	char from[GMT_LONG_TEXT], to[GMT_LONG_TEXT];
+	char from[GMT_LONG_TEXT], to[GMT_LONG_TEXT], *not_used = NULL;
 
 	FILE *fp = NULL;
 
@@ -130,11 +126,11 @@ int main (int argc, char **argv)
 	PFI near_a_line;
 	PFD azimuth_func;
 
-	void *New_Mapproject_Ctrl (), Free_Mapproject_Ctrl (struct MAPPROJECT_CTRL *C);
+	void *New_mapproject_Ctrl (), Free_mapproject_Ctrl (struct MAPPROJECT_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct MAPPROJECT_CTRL *) New_Mapproject_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct MAPPROJECT_CTRL *) New_mapproject_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 	
 	out = (double *)NULL;
 
@@ -149,9 +145,12 @@ int main (int argc, char **argv)
 				case 'R':
 				case 'H':
 				case 'J':
+				case 'M':
 				case ':':
 				case 'b':
 				case 'f':
+				case 'g':
+				case 'm':
 				case '\0':
 					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
@@ -245,7 +244,7 @@ int main (int argc, char **argv)
 				case 'L':
 					Ctrl->L.active = TRUE;
 					Ctrl->L.file = strdup (&argv[i][2]);
-					k = strlen (Ctrl->L.file) - 1;
+					k = (int)strlen (Ctrl->L.file) - 1;
 					if (Ctrl->L.file[k] == '+') {	/* Flag to get point number instead of coordinates at nearest point on line */
 						Ctrl->L.mode = 3;
 						Ctrl->L.file[k] = '\0';
@@ -257,9 +256,6 @@ int main (int argc, char **argv)
 						Ctrl->L.file[k] = 0;
 					}
 					break;
-				case 'M':               /* Multiple line segments */
-					GMT_multisegment (&argv[i][2]);
-					break;
 				case 'Q':
 					Ctrl->Q.active = TRUE;
 					if (argv[i][2] == 'e') Ctrl->Q.mode |= 1;
@@ -303,8 +299,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "mapproject %s - Forward and Inverse map transformations and geodesy\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: mapproject <infiles> %s %s [-C[<dx/dy>]]\n", GMT_J_OPT, GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[-Ab|B|f|F[<lon0/lat0>]] [-Dc|i|m|p] [-E[<datum>]] [-F[k|m|n|i|c|p]] [-G[<lon0/lat0>/][+|-][<unit>]\n");
-		fprintf (stderr, "\t[%s] [-I] [-L<line.xy>[/<unit>]] [%s] [-Q[e|d]] [-S] [-T[h]<from>[/<to>]\n", GMT_H_OPT, GMT_M_OPT);
-		fprintf (stderr, "\t[-V[l]] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
+		fprintf (stderr, "\t[%s] [-I] [-L<line.xy>[/<unit>]] [-Q[e|d]] [-S] [-T[h]<from>[/<to>]\n", GMT_H_OPT);
+		fprintf (stderr, "\t[-V[l]] [%s] [%s] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_b_OPT, GMT_f_OPT, GMT_g_OPT, GMT_m_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -324,7 +320,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Cannot be used if -F is set.\n");
 		fprintf (stderr, "\t-E Convert (lon, lat, h) to Earth Centered Earth Fixed (ECEF) coordinates [-I for inverse].\n");
 		fprintf (stderr, "\t   Specify <datum> using datum ID (see -Qd or man page) or as <ellipsoid>:<dx,dy,dz>\n");
-		fprintf (stderr, "\t   where <ellipsoid> may be ellipsoid ID (see -Qe or man page) or <major,inv_flattening>.\n");
+		fprintf (stderr, "\t   where <ellipsoid> may be ellipsoid ID (see -Qe or man page) or <semimajor>[,<inv_flattening>].\n");
 		fprintf (stderr, "\t   If <datum> = - or not given we assume WGS-84.\n");
 		fprintf (stderr, "\t-F force projected values to be in actual meters [Default uses the given plot scale]\n");
 		fprintf (stderr, "\t   Specify unit by appending k (km), m (miles), n (nautical miles), i (inch), c (cm), or p (points)\n");
@@ -342,7 +338,6 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Unit C means Cartesian distances after first projecting the input coordinates (-R, -J).\n");
 		fprintf (stderr, "\t   Calculations uses spherical approximations.  Default unit is meters.\n");
 		fprintf (stderr, "\t   Three columns are added on output: min dist and lon, lat of the closest point on the line\n");
-		GMT_explain_option ('M');
 		fprintf (stderr, "\t-Q list projection parameters and exit.  For subsets [Default is all] use\n");
 		fprintf (stderr, "\t   -Qe shows ellipsoid parameters\n");
 		fprintf (stderr, "\t   -Qd shows datum parameters\n");
@@ -350,7 +345,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-T means coordinate transformation from datum <from> to datum <to>.\n");
 		fprintf (stderr, "\t   Prepend h if input data are lon, lat, height [Default sets height = 0].\n");
 		fprintf (stderr, "\t   Specify datums using datum ID (see -Qd or man page) or as <ellipsoid>:<dx,dy,dz>\n");
-		fprintf (stderr, "\t   where <ellipsoid> may be ellipsoid ID (see -Qe or man page) or <major,inv_flattening>.\n");
+		fprintf (stderr, "\t   where <ellipsoid> may be ellipsoid ID (see -Qe or man page) or <semimajor>[,<inv_flattening>].\n");
 		fprintf (stderr, "\t   <from> = - means WGS-84.  If /<to> is not given we assume WGS-84.\n");
 		fprintf (stderr, "\t   -T can be used as pre- or post- (-I) processing for -J -R.\n");
 		GMT_explain_option ('V');
@@ -362,19 +357,21 @@ int main (int argc, char **argv)
 		GMT_explain_option ('o');
 		GMT_explain_option ('n');
 		GMT_explain_option ('f');
+		GMT_explain_option ('g');
+		GMT_explain_option ('m');
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
 
 	if (Ctrl->Q.mode & 1) {	/* List ellipsoid parameters */
 		fprintf (stderr, "GMT supports %d ellipsoids, given below (-> indicates default setting)\n", GMT_N_ELLIPSOIDS);
-		fprintf (stderr, "  ID                      Date        a         1/f\n");
-		fprintf (stderr, "--------------------------------------------------------\n");
+		fprintf (stderr, "  ID                      Date        a           1/f\n");
+		fprintf (stderr, "-----------------------------------------------------------\n");
 		for (i = 0; i < GMT_N_ELLIPSOIDS; i++) {
 			(i == gmtdefs.ellipsoid) ? fprintf (stderr, "->") : fprintf (stderr, "  ");
-			fprintf (stderr, "%-23s %4d %.3f %.9f\n", gmtdefs.ref_ellipsoid[i].name, gmtdefs.ref_ellipsoid[i].date, gmtdefs.ref_ellipsoid[i].eq_radius, 1.0/gmtdefs.ref_ellipsoid[i].flattening);
+			fprintf (stderr, "%-23s %4ld %13.3f %14.9f\n", gmtdefs.ref_ellipsoid[i].name, gmtdefs.ref_ellipsoid[i].date, gmtdefs.ref_ellipsoid[i].eq_radius, 1.0/gmtdefs.ref_ellipsoid[i].flattening);
 		}
-		fprintf (stderr, "--------------------------------------------------------\n");
+		fprintf (stderr, "-----------------------------------------------------------\n");
 	}
 	if (Ctrl->Q.mode & 2) {	/* List datum parameters */
 		fprintf (stderr, "GMT supports %d datums, given below (-> indicates default setting)\n", GMT_N_DATUMS);
@@ -447,7 +444,7 @@ int main (int argc, char **argv)
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 #ifdef SET_IO_MODE
@@ -565,7 +562,7 @@ int main (int argc, char **argv)
 
 	/* Now we are ready to take on some input values */
 
-	x = (gmtdefs.xy_toggle[1]) ? 1 : 0;	y = 1 - x;		/* Set up which columns have x and y for output only*/
+	x = (gmtdefs.xy_toggle[GMT_OUT]) ? 1 : 0;	y = 1 - x;		/* Set up which columns have x and y for output only*/
 	if ((GMT_IS_MAPPING || Ctrl->E.active) && Ctrl->I.active) {
 		GMT_io.out_col_type[0] = GMT_IS_LON;	GMT_io.out_col_type[1] = GMT_IS_LAT;	/* Inverse projection expects x,y and gives lon, lat */
 		GMT_io.in_col_type[0] = GMT_io.in_col_type[1] = GMT_IS_FLOAT;
@@ -651,276 +648,90 @@ int main (int argc, char **argv)
 
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
-				GMT_fgets (line, BUFSIZ, fp);
+				not_used = GMT_fgets (line, BUFSIZ, fp);
 				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", line);
 			}
 			first = FALSE;
 		}
+		if (GMT_IO_GAP_CHECKING) GMT_write_segmentheader (GMT_stdout, *n_output);
 
 		if (Ctrl->I.active) {		/* Do inverse transformation */
 
-			while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
+			n_fields = GMT_input (fp, &n_expected_fields, &in);
+			while (!GMT_REC_IS_EOF) {	/* Not yet EOF */
 
-				while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {
+				while (GMT_REC_IS_NEW_SEGMENT && !GMT_REC_IS_EOF) {
 					GMT_write_segmentheader (GMT_stdout, n_expected_fields);
 					n_fields = GMT_input (fp, &n_expected_fields, &in);
 				}
-				if (GMT_io.status & GMT_IO_EOF) continue;
-
-				if (GMT_io.status & GMT_IO_MISMATCH && n_fields < 2) {
-					fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
-					continue;
-				}
-				if (!out) out = (double *) GMT_memory (VNULL, (size_t)n_expected_fields, sizeof (double), GMT_program);
-
-				if (gmtdefs.verbose) {
-					x_in = in[0];
-					y_in = in[1];
-				}
-				if (shift_xy) {
-					in[0] -= Ctrl->C.easting;
-					in[1] -= Ctrl->C.northing;
-				}
-				if (Ctrl->E.active) {
-					GMT_ECEF_inverse (in, out);
-				}
-				else {
-					if (Ctrl->F.active) {	/* Convert from 1:1 scale */
-						if (unit) {
-							in[0] *= u_scale;
-							in[1] *= u_scale;
-						}
-						in[0] *= project_info.x_scale;
-						in[1] *= project_info.y_scale;
-					}
-					else if (gmtdefs.measure_unit != GMT_INCH) {	/* Convert from whatever to inch */
-						in[0] *= unit_to_inch;
-						in[1] *= unit_to_inch;
-					}
-					if (Ctrl->C.active) {	/* Then correct so lower left corner is (0,0) */
-						in[0] += project_info.x0;
-						in[1] += project_info.y0;
-					}
-					GMT_xy_to_geo (&out[0], &out[1], in[0], in[1]);
-				}
-				if (double_whammy) {	/* Now apply datum shift */
-					in[0] = out[0];
-					in[1] = out[1];
-					GMT_conv_datum (in, out);
-				}
-
-				n_read++;
-				if (Ctrl->S.active && GMT_map_outside (out[0], out[1])) continue;
-				if (gmtdefs.verbose) {
-					x_in_min = MIN (x_in_min, x_in);
-					x_in_max = MAX (x_in_max, x_in);
-					y_in_min = MIN (y_in_min, y_in);
-					y_in_max = MAX (y_in_max, y_in);
-					x_out_min = MIN (x_out_min, out[0]);
-					x_out_max = MAX (x_out_max, out[0]);
-					y_out_min = MIN (y_out_min, out[1]);
-					y_out_max = MAX (y_out_max, out[1]);
-				}
-
-				if (pure_ascii && n_expected_fields > 2) {
-					/* Special case: ASCII i/o and at least 3 columns:
-					  Columns beyond first two could be text strings */
-
-					/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
-					* will then be the user text that we want to preserve.  Since strtok places
-					* 0 to indicate start of next token we count our way to the start of the text. */
-
-					strcpy (line, GMT_io.current_record);
-					GMT_chop (line);
-					pos = 0;
-					GMT_strtok (line, " \t,", &pos, p);	/* Returns xstring and update pos */
-					GMT_strtok (line, " \t,", &pos, p);	/* Returns ystring and update pos */
-					GMT_ascii_output_one (GMT_stdout, out[x], 0);
-					fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-					GMT_ascii_output_one (GMT_stdout, out[y], 1);
-					fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-					if (Ctrl->E.active) {
-						GMT_strtok (line, " \t,", &pos, p);	/* Returns zstring and update pos */
-						GMT_ascii_output_one (GMT_stdout, out[2], 2);
-						fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-					}
-					fprintf (GMT_stdout, "%s\n", &line[pos]);	/* Start of user text */
-				}
-				else {	/* Simply copy other columns and output */
-					for (k = two; k < *n_output; k++) out[k] = in[k];
-					GMT_output (GMT_stdout, *n_output, out);
-				}
-				n++;
-				if (long_verbose && (n%1000) == 0) fprintf (stderr, "%s: Projected %ld points\r", GMT_program, n);
-			}
-		}
-		else {		/* Do forward transformation */
-
-			while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
-
-				while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {
-					GMT_write_segmentheader (GMT_stdout, n_expected_fields);
-					n_fields = GMT_input (fp, &n_expected_fields, &in);
+				if (GMT_REC_IS_GAP) {
+					GMT_write_segmentheader (GMT_stdout, *n_output);
+					GMT_io.status = 0;	/* Done with gap */
 					line_start = TRUE;
 				}
-				if (GMT_io.status & GMT_IO_EOF) continue;
+				if (GMT_REC_IS_EOF) continue;
 
-				if (GMT_io.status & GMT_IO_MISMATCH && n_fields < 2) {
-					fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
-					continue;
-				}
-				if (!out) out = (double *) GMT_memory (VNULL, (size_t)n_expected_fields+3, sizeof (double), GMT_program);
-				n_read++;
-
-				/* Because -: is processed in GMT_input we use [0] for lon and [1] for y always */
-
-				if (Ctrl->S.active && GMT_map_outside (in[0], in[1])) continue;
-
-				if (datum_conv_only) {
-					GMT_conv_datum (in, out);
-				}
-				else if (Ctrl->E.active) {
-					GMT_ECEF_forward (in, out);
-				}
-				else {
-					if (double_whammy) {	/* Apply datum shift first */
-						GMT_conv_datum (in, out);
-						in[0] = out[0];
-						in[1] = out[1];
+				while (!GMT_REC_IS_LINE_BREAK && !GMT_REC_IS_EOF) {	/* Keep going until FALSE or = 2 segment header */
+					if (GMT_REC_IS_ERROR && n_fields < 2) {
+						fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+						continue;
 					}
-					GMT_geo_to_xy (in[0], in[1], &out[0], &out[1]);
-					if (Ctrl->C.active) {	/* Change origin from lower left to projection center */
-						out[0] -= project_info.x0;
-						out[1] -= project_info.y0;
-					}
-					if (Ctrl->F.active) {	/* Convert to 1:1 scale */
-						out[0] /= project_info.x_scale;
-						out[1] /= project_info.y_scale;
-						if (unit) {
-							out[0] *= u_scale;
-							out[1] *= u_scale;
-						}
-					}
-					else if (gmtdefs.measure_unit != GMT_INCH) {	/* Convert from inch to whatever */
-						out[0] *= inch_to_unit;
-						out[1] *= inch_to_unit;
+					if (!out) out = (double *) GMT_memory (VNULL, (size_t)n_expected_fields, sizeof (double), GMT_program);
+
+					if (gmtdefs.verbose) {
+						x_in = in[GMT_X];
+						y_in = in[GMT_Y];
 					}
 					if (shift_xy) {
-						out[0] += Ctrl->C.easting;
-						out[1] += Ctrl->C.northing;
+						in[GMT_X] -= Ctrl->C.easting;
+						in[GMT_Y] -= Ctrl->C.northing;
 					}
-				}
-				if (gmtdefs.verbose) {
-					x_in_min = MIN (x_in_min, in[0]);
-					x_in_max = MAX (x_in_max, in[0]);
-					y_in_min = MIN (y_in_min, in[1]);
-					y_in_max = MAX (y_in_max, in[1]);
-				}
-				if (geodetic_calc) {	/* Get either distances or azimuths */
-					if (Ctrl->G.mode) {	/* Cumulative distances along track */
-						if (Ctrl->G.mode == 4) {
-							if (proj_type == 2) {	/* Calculate Cartesian distances using projected units */
-								GMT_geo_to_xy (in[2], in[3], &xtmp, &ytmp);
-								s = hypot (xtmp - out[0], ytmp - out[1]);
+					if (Ctrl->E.active) {
+						GMT_ECEF_inverse (in, out);
+					}
+					else {
+						if (Ctrl->F.active) {	/* Convert from 1:1 scale */
+							if (unit) {
+								in[GMT_X] *= u_scale;
+								in[GMT_Y] *= u_scale;
 							}
-							else
-								s = d_scale * (*distance_func) (in[0], in[1], in[2], in[3]);
+							in[GMT_X] *= project_info.x_scale;
+							in[GMT_Y] *= project_info.y_scale;
 						}
-						else if (Ctrl->G.mode >= 2 && line_start)
-							s = d = 0.0;
-						else if (proj_type == 2)	/* Calculate Cartesian distances using projected units */
-							s = hypot (Ctrl->G.lon - out[0], Ctrl->G.lat - out[1]);
-						else if (proj_type == 1)	/* Plain Cartesian distances using input points */
-							s = hypot (Ctrl->G.lon - in[0], Ctrl->G.lat - in[1]);
-						else				/* Great circle distances */
-							s = d_scale * (*distance_func) (Ctrl->G.lon, Ctrl->G.lat, in[0], in[1]);
-						if (Ctrl->G.mode >= 2) {
-							line_start = FALSE;
-							if (Ctrl->G.mode >= 3)	/* Increments */
-								d = s;
-							else
-								d += s;		/* Cumulative */
-							if (proj_type == 2) {	/* Calculate distances using projected units */
-								Ctrl->G.lon = out[0];
-								Ctrl->G.lat = out[1];
-							}
-							else {
-								Ctrl->G.lon = in[0];
-								Ctrl->G.lat = in[1];
-							}
+						else if (gmtdefs.measure_unit != GMT_INCH) {	/* Convert from whatever to inch */
+							in[GMT_X] *= unit_to_inch;
+							in[GMT_Y] *= unit_to_inch;
 						}
-						else
-							d = s;
-					}
-					else if (Ctrl->L.active) {	/* Compute closest distance to line */
-						if (proj_type == 2)	/* Using projected coordinates */
-							(void) near_a_line (out[0], out[1], xyline, Ctrl->L.mode, &d, &xnear, &ynear);
-						else			/* Using input coordinates */
-							(void) near_a_line (in[0], in[1], xyline, Ctrl->L.mode, &d, &xnear, &ynear);
-						d *= d_scale;
-					}
-					else if (Ctrl->A.azims) {	/* Azimuth from previous point */
-						if (n_read == 1) {	/* First point has undefined azimuth since there is no previous point */
-							d = GMT_d_NaN;
+						if (Ctrl->C.active) {	/* Then correct so lower left corner is (0,0) */
+							in[GMT_X] += project_info.x0;
+							in[GMT_Y] += project_info.y0;
 						}
-						else {
-							d = (*azimuth_func) (lon_prev, lat_prev, in[0], in[1], Ctrl->A.reverse);
-						}
-						lon_prev = in[0];
-						lat_prev = in[1];
+						GMT_xy_to_geo (&out[GMT_X], &out[GMT_Y], in[GMT_X], in[GMT_Y]);
 					}
-					else {	/* Azimuths with respect to a fixed point */
-						d = (*azimuth_func) (Ctrl->A.lon, Ctrl->A.lat, in[0], in[1], Ctrl->A.reverse);
+					if (double_whammy) {	/* Now apply datum shift */
+						in[GMT_X] = out[GMT_X];
+						in[GMT_Y] = out[GMT_Y];
+						GMT_conv_datum (in, out);
 					}
-					if (pure_ascii && n_expected_fields > 2) {
-						/* Special case: Ascii input and at least 3 columns:
-						 Columns beyond first two could be text strings */
 
-						/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
-						* will then be the user text that we want to preserve.  Since strtok places
-						* 0 to indicate start of next token we count our way to the start of the text. */
-
-						strcpy (line, GMT_io.current_record);
-						GMT_chop (line);
-						pos = 0;
-						GMT_strtok (line, " \t,", &pos, p);	/* Returns xstring */
-						GMT_strtok (line, " \t,", &pos, p);	/* Returns ystring */
-
-						GMT_ascii_output_one (GMT_stdout, in[x], 0);
-						fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-						GMT_ascii_output_one (GMT_stdout, in[y], 1);
-						fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-						fprintf (GMT_stdout, "%s", &line[pos]);
-						fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-						GMT_ascii_output_one (GMT_stdout, d, 2);
-						if (Ctrl->L.active) {
-							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-							GMT_ascii_output_one (GMT_stdout, xnear, fmt[0]);
-							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-							GMT_ascii_output_one (GMT_stdout, ynear, fmt[1]);
-						}
-						fprintf (GMT_stdout, "\n");
+					n_read++;
+					if (Ctrl->S.active && GMT_map_outside (out[GMT_X], out[GMT_Y])) {
+						n_fields = GMT_input (fp, &n_expected_fields, &in);
+						continue;
 					}
-					else {	/* Simply copy other columns and output */
-						for (k = 0; k < *n_output; k++) out[k] = in[k];
-						n_out = *n_output;
-						out[n_out++] = d;
-						if (Ctrl->L.active) {
-							out[n_out++] = xnear;
-							out[n_out++] = ynear;
-						}
-						GMT_output (GMT_stdout, n_out, out);
-					}
-				}
-				else {
 					if (gmtdefs.verbose) {
-						x_out_min = MIN (x_out_min, out[0]);
-						x_out_max = MAX (x_out_max, out[0]);
-						y_out_min = MIN (y_out_min, out[1]);
-						y_out_max = MAX (y_out_max, out[1]);
+						x_in_min = MIN (x_in_min, x_in);
+						x_in_max = MAX (x_in_max, x_in);
+						y_in_min = MIN (y_in_min, y_in);
+						y_in_max = MAX (y_in_max, y_in);
+						x_out_min = MIN (x_out_min, out[GMT_X]);
+						x_out_max = MAX (x_out_max, out[GMT_X]);
+						y_out_min = MIN (y_out_min, out[GMT_Y]);
+						y_out_max = MAX (y_out_max, out[GMT_Y]);
 					}
+
 					if (pure_ascii && n_expected_fields > 2) {
-						/* Special case: Ascii input and at least 3 columns:
+						/* Special case: ASCII i/o and at least 3 columns:
 						  Columns beyond first two could be text strings */
 
 						/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
@@ -936,20 +747,231 @@ int main (int argc, char **argv)
 						fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
 						GMT_ascii_output_one (GMT_stdout, out[y], 1);
 						fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-						if (Ctrl->E.active || (Ctrl->T.active && GMT_datum.h_given)) {
+						if (Ctrl->E.active) {
 							GMT_strtok (line, " \t,", &pos, p);	/* Returns zstring and update pos */
 							GMT_ascii_output_one (GMT_stdout, out[2], 2);
 							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
 						}
-						fprintf (GMT_stdout, "%s\n", &line[pos]);
+						fprintf (GMT_stdout, "%s\n", &line[pos]);	/* Start of user text */
 					}
 					else {	/* Simply copy other columns and output */
 						for (k = two; k < *n_output; k++) out[k] = in[k];
 						GMT_output (GMT_stdout, *n_output, out);
 					}
+					n++;
+					if (long_verbose && (n%1000) == 0) fprintf (stderr, "%s: Projected %ld points\r", GMT_program, n);
+					n_fields = GMT_input (fp, &n_expected_fields, &in);
+				}
+			}
+		}
+		else {		/* Do forward transformation */
+
+			n_fields = GMT_input (fp, &n_expected_fields, &in);
+			while (!GMT_REC_IS_EOF) {	/* Not yet EOF */
+
+				while (GMT_REC_IS_NEW_SEGMENT && !GMT_REC_IS_EOF) {
+					GMT_write_segmentheader (GMT_stdout, n_expected_fields);
+					n_fields = GMT_input (fp, &n_expected_fields, &in);
+					line_start = TRUE;
+				}
+				if (GMT_REC_IS_GAP) {
+					GMT_write_segmentheader (GMT_stdout, *n_output);
+					GMT_io.status = 0;	/* Done with gap */
+					line_start = TRUE;
+				}
+				if (GMT_REC_IS_EOF) continue;
+
+				while (!GMT_REC_IS_LINE_BREAK && !GMT_REC_IS_EOF) {	/* Keep going until FALSE or = 2 segment header */
+					if (GMT_REC_IS_ERROR && n_fields < 2) {
+						fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+						continue;
+					}
+					if (!out) out = (double *) GMT_memory (VNULL, (size_t)n_expected_fields+3, sizeof (double), GMT_program);
+					n_read++;
+
+					/* Because -: is processed in GMT_input we use [0] for lon and [1] for y always */
+
+					if (Ctrl->S.active && GMT_map_outside (in[GMT_X], in[GMT_Y])) {
+						n_fields = GMT_input (fp, &n_expected_fields, &in);
+						continue;
+					}
+
+					if (datum_conv_only) {
+						GMT_conv_datum (in, out);
+					}
+					else if (Ctrl->E.active) {
+						GMT_ECEF_forward (in, out);
+					}
+					else {
+						if (double_whammy) {	/* Apply datum shift first */
+							GMT_conv_datum (in, out);
+							in[GMT_X] = out[GMT_X];
+							in[GMT_Y] = out[GMT_Y];
+						}
+						GMT_geo_to_xy (in[GMT_X], in[GMT_Y], &out[GMT_X], &out[GMT_Y]);
+						if (Ctrl->C.active) {	/* Change origin from lower left to projection center */
+							out[GMT_X] -= project_info.x0;
+							out[GMT_Y] -= project_info.y0;
+						}
+						if (Ctrl->F.active) {	/* Convert to 1:1 scale */
+							out[GMT_X] /= project_info.x_scale;
+							out[GMT_Y] /= project_info.y_scale;
+							if (unit) {
+								out[GMT_X] *= u_scale;
+								out[GMT_Y] *= u_scale;
+							}
+						}
+						else if (gmtdefs.measure_unit != GMT_INCH) {	/* Convert from inch to whatever */
+							out[GMT_X] *= inch_to_unit;
+							out[GMT_Y] *= inch_to_unit;
+						}
+						if (shift_xy) {
+							out[GMT_X] += Ctrl->C.easting;
+							out[GMT_Y] += Ctrl->C.northing;
+						}
+					}
+					if (gmtdefs.verbose) {
+						x_in_min = MIN (x_in_min, in[GMT_X]);
+						x_in_max = MAX (x_in_max, in[GMT_X]);
+						y_in_min = MIN (y_in_min, in[GMT_Y]);
+						y_in_max = MAX (y_in_max, in[GMT_Y]);
+					}
+					if (geodetic_calc) {	/* Get either distances or azimuths */
+						if (Ctrl->G.mode) {	/* Cumulative distances along track */
+							if (Ctrl->G.mode == 4) {
+								if (proj_type == 2) {	/* Calculate Cartesian distances using projected units */
+									GMT_geo_to_xy (in[2], in[3], &xtmp, &ytmp);
+									s = hypot (xtmp - out[GMT_X], ytmp - out[GMT_Y]);
+								}
+								else
+									s = d_scale * (*distance_func) (in[GMT_X], in[GMT_Y], in[2], in[3]);
+							}
+							else if (Ctrl->G.mode >= 2 && line_start)
+								s = d = 0.0;
+							else if (proj_type == 2)	/* Calculate Cartesian distances using projected units */
+								s = hypot (Ctrl->G.lon - out[GMT_X], Ctrl->G.lat - out[GMT_Y]);
+							else if (proj_type == 1)	/* Plain Cartesian distances using input points */
+								s = hypot (Ctrl->G.lon - in[GMT_X], Ctrl->G.lat - in[GMT_Y]);
+							else				/* Great circle distances */
+								s = d_scale * (*distance_func) (Ctrl->G.lon, Ctrl->G.lat, in[GMT_X], in[GMT_Y]);
+							if (Ctrl->G.mode >= 2) {
+								line_start = FALSE;
+								if (Ctrl->G.mode >= 3)	/* Increments */
+									d = s;
+								else
+									d += s;		/* Cumulative */
+								if (proj_type == 2) {	/* Calculate distances using projected units */
+									Ctrl->G.lon = out[GMT_X];
+									Ctrl->G.lat = out[GMT_Y];
+								}
+								else {
+									Ctrl->G.lon = in[GMT_X];
+									Ctrl->G.lat = in[GMT_Y];
+								}
+							}
+							else
+								d = s;
+						}
+						else if (Ctrl->L.active) {	/* Compute closest distance to line */
+							if (proj_type == 2)	/* Using projected coordinates */
+								(void) near_a_line (out[GMT_X], out[GMT_Y], xyline, Ctrl->L.mode, &d, &xnear, &ynear);
+							else			/* Using input coordinates */
+								(void) near_a_line (in[GMT_X], in[GMT_Y], xyline, Ctrl->L.mode, &d, &xnear, &ynear);
+							d *= d_scale;
+						}
+						else if (Ctrl->A.azims) {	/* Azimuth from previous point */
+							if (n_read == 1) {	/* First point has undefined azimuth since there is no previous point */
+								d = GMT_d_NaN;
+							}
+							else {
+								d = (*azimuth_func) (lon_prev, lat_prev, in[GMT_X], in[GMT_Y], Ctrl->A.reverse);
+							}
+							lon_prev = in[GMT_X];
+							lat_prev = in[GMT_Y];
+						}
+						else {	/* Azimuths with respect to a fixed point */
+							d = (*azimuth_func) (Ctrl->A.lon, Ctrl->A.lat, in[GMT_X], in[GMT_Y], Ctrl->A.reverse);
+						}
+						if (pure_ascii && n_expected_fields > 2) {
+							/* Special case: Ascii input and at least 3 columns:
+							 Columns beyond first two could be text strings */
+
+							/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
+							* will then be the user text that we want to preserve.  Since strtok places
+							* 0 to indicate start of next token we count our way to the start of the text. */
+
+							strcpy (line, GMT_io.current_record);
+							GMT_chop (line);
+							pos = 0;
+							GMT_strtok (line, " \t,", &pos, p);	/* Returns xstring */
+							GMT_strtok (line, " \t,", &pos, p);	/* Returns ystring */
+
+							GMT_ascii_output_one (GMT_stdout, in[x], 0);
+							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+							GMT_ascii_output_one (GMT_stdout, in[y], 1);
+							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+							fprintf (GMT_stdout, "%s", &line[pos]);
+							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+							GMT_ascii_output_one (GMT_stdout, d, 2);
+							if (Ctrl->L.active) {
+								fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+								GMT_ascii_output_one (GMT_stdout, xnear, fmt[0]);
+								fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+								GMT_ascii_output_one (GMT_stdout, ynear, fmt[1]);
+							}
+							fprintf (GMT_stdout, "\n");
+						}
+						else {	/* Simply copy other columns and output */
+							for (k = 0; k < *n_output; k++) out[k] = in[k];
+							n_out = *n_output;
+							out[n_out++] = d;
+							if (Ctrl->L.active) {
+								out[n_out++] = xnear;
+								out[n_out++] = ynear;
+							}
+							GMT_output (GMT_stdout, n_out, out);
+						}
+					}
+					else {
+						if (gmtdefs.verbose) {
+							x_out_min = MIN (x_out_min, out[GMT_X]);
+							x_out_max = MAX (x_out_max, out[GMT_X]);
+							y_out_min = MIN (y_out_min, out[GMT_Y]);
+							y_out_max = MAX (y_out_max, out[GMT_Y]);
+						}
+						if (pure_ascii && n_expected_fields > 2) {
+							/* Special case: Ascii input and at least 3 columns:
+							  Columns beyond first two could be text strings */
+
+							/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
+							* will then be the user text that we want to preserve.  Since strtok places
+							* 0 to indicate start of next token we count our way to the start of the text. */
+
+							strcpy (line, GMT_io.current_record);
+							GMT_chop (line);
+							pos = 0;
+							GMT_strtok (line, " \t,", &pos, p);	/* Returns xstring and update pos */
+							GMT_strtok (line, " \t,", &pos, p);	/* Returns ystring and update pos */
+							GMT_ascii_output_one (GMT_stdout, out[x], 0);
+							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+							GMT_ascii_output_one (GMT_stdout, out[y], 1);
+							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+							if (Ctrl->E.active || (Ctrl->T.active && GMT_datum.h_given)) {
+								GMT_strtok (line, " \t,", &pos, p);	/* Returns zstring and update pos */
+								GMT_ascii_output_one (GMT_stdout, out[2], 2);
+								fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+							}
+							fprintf (GMT_stdout, "%s\n", &line[pos]);
+						}
+						else {	/* Simply copy other columns and output */
+							for (k = two; k < *n_output; k++) out[k] = in[k];
+							GMT_output (GMT_stdout, *n_output, out);
+						}
+					}
+					n++;
+					if (long_verbose && (n%1000) == 0) fprintf (stderr, "%s: Projected %ld points\r", GMT_program, n);
+					n_fields = GMT_input (fp, &n_expected_fields, &in);
 				}
-				n++;
-				if (long_verbose && (n%1000) == 0) fprintf (stderr, "%s: Projected %ld points\r", GMT_program, n);
 			}
 		}
 		if (fp != GMT_stdin) GMT_fclose (fp);
@@ -982,21 +1004,21 @@ int main (int argc, char **argv)
 		if (Ctrl->S.active && n != n_read) fprintf (stderr, "%s: %ld fell outside region\n", GMT_program, n_read - n);
 	}
 
-	GMT_free ((void *)out);
+	if (out) GMT_free ((void *)out);
 
 	if (Ctrl->L.active) GMT_free_table (xyline);
 
-	Free_Mapproject_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_mapproject_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Mapproject_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_mapproject_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct MAPPROJECT_CTRL *C;
 	
-	C = (struct MAPPROJECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct MAPPROJECT_CTRL), "New_Mapproject_Ctrl");
+	C = (struct MAPPROJECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct MAPPROJECT_CTRL), "New_mapproject_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -1005,7 +1027,7 @@ void *New_Mapproject_Ctrl () {	/* Allocate and initialize a new control structur
 	return ((void *)C);
 }
 
-void Free_Mapproject_Ctrl (struct MAPPROJECT_CTRL *C) {	/* Deallocate control structure */
+void Free_mapproject_Ctrl (struct MAPPROJECT_CTRL *C) {	/* Deallocate control structure */
 	if (C->L.file) free ((void *)C->L.file);	
 	GMT_free ((void *)C);	
 }
