@@ -1,5 +1,5 @@
-/*	$Id: utilvelo.c,v 1.8 2008/03/24 08:58:32 guru Exp $
- *    Copyright (c) 1996-2008 by G. Patau
+/*	$Id: utilvelo.c,v 1.12 2010/01/05 01:15:48 guru Exp $
+ *    Copyright (c) 1996-2010 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  */
@@ -140,7 +140,7 @@ void trace_ellipse (double angle, double major, double minor, GMT_LONG npoints,
     double phi = 0.;
     double sd, cd, s, c;
 
-    int i;
+    GMT_LONG i;
 
     sincos (angle*M_PI/180., &sd, &cd);
 
@@ -204,7 +204,7 @@ void ellipse_convert (double sigx,double sigy,double rho,double conrad,double *e
 }
 
 /********************************************************************/
-void paint_ellipse (double x0, double y0, double angle, double major, double minor, double scale, double t11,double t12,double t21,double t22, int polygon, int rgb[3], BOOLEAN outline)
+void paint_ellipse (double x0, double y0, double angle, double major, double minor, double scale, double t11,double t12,double t21,double t22, GMT_LONG polygon, int rgb[3], BOOLEAN outline)
 
 /* Make an ellipse at center x0,y0  */
 
@@ -213,7 +213,7 @@ void paint_ellipse (double x0, double y0, double angle, double major, double min
 #define NPOINTS 362
 
      GMT_LONG    npoints = NPOINTS;
-     int    i;
+     GMT_LONG    i;
      /* relative to center of ellipse */
      double dxe[NPOINTS],dye[NPOINTS];
      /* absolute paper coordinates */
@@ -227,6 +227,6 @@ void paint_ellipse (double x0, double y0, double angle, double major, double min
      if(polygon)
          ps_polygon(axe, aye, npoints - 2, rgb, outline);
      else	
-         ps_line(axe, aye, npoints - 2, 3, TRUE, FALSE);
+         ps_line(axe, aye, npoints - 2, 3, TRUE);
 
 }
