@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77info.c,v 1.59 2008/04/03 01:31:30 guru Exp $
+ *	$Id: mgd77info.c,v 1.67 2010/01/05 01:15:48 guru Exp $
  *
- *    Copyright (c) 2004-2008 by P. Wessel
+ *    Copyright (c) 2004-2010 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -26,7 +26,7 @@
 
 int main (int argc, char **argv)
 {
-	GMT_LONG i, id, rec, argno, col_listing = 3, length, id_col, t_col, x_col, y_col, saved_range;
+	GMT_LONG i, id, rec, argno, col_listing = 3, length, id_col, t_col, x_col, y_col, saved_range, use;
 	GMT_LONG header_flag = 0, n_paths, counter[MGD77_MAX_COLS], agency_listing = 1, quad_no, n_quad;
 	
 	BOOLEAN error = FALSE, greenwich = FALSE, quick_summary = FALSE, dump_raw_header = FALSE;
@@ -46,6 +46,8 @@ int main (int argc, char **argv)
 	struct MGD77_DATASET *D;
 		
 	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	GMT_get_time_system ("unix", &(gmtdefs.time_system));						/* MGD77+ uses GMT's Unix time epoch */
+	GMT_init_time_system_structure (&(gmtdefs.time_system));
 	
 	/* Initialize MGD77 output order and other parameters*/
 	
@@ -205,10 +207,12 @@ int main (int argc, char **argv)
 	saved_range = GMT_io.geo.range;	/* We may have to reset thisso keep a copy */
 	GMT_io.out_col_type[0] = GMT_IS_LON;	GMT_io.out_col_type[1] = GMT_IS_LAT;
 	GMT_io.out_col_type[2] = M.time_format;	
-	if (quick_summary) printf ("#Cruise %sID      %sWest    %sEast    %sSouth   %sNorth   %sStartTime%s%sEndTime%s%s%sDist%snRec",
+	if (quick_summary) fprintf (GMT_stdout, "#Cruise %sID      %sWest    %sEast    %sSouth   %sNorth   %sStartTime%s%sEndTime%s%s%sDist%snRec",
 		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter,
 		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter);
 
+	use = (M.original || M.format != MGD77_FORMAT_CDF) ? MGD77_ORIG : MGD77_REVISED;
+	
 	for (argno = 0; argno < n_paths; argno++) {		/* Process each ID */
 	
 		if (MGD77_Open_File (list[argno], &M, MGD77_READ_MODE)) continue;
@@ -227,22 +231,22 @@ int main (int argc, char **argv)
 		}
 
 		if (dump_hist_header) {	/* Dump of MGD77+ history */
-			printf ("%s: %s", list[argno], D->H.history);
+			fprintf (GMT_stdout, "%s: %s", list[argno], D->H.history);
 			MGD77_Close_File (&M);
 			MGD77_Free (D);
 			continue;
 		}
 		if (dump_e77_header) {	/* Dump of e77 header status */
 			if (D->H.E77 && strlen(D->H.E77) > 0)
-				printf ("%s: %s\n", list[argno], D->H.E77);
+				fprintf (GMT_stdout, "%s: %s\n", list[argno], D->H.E77);
 			else
-				printf ("%s: E77 not applied\n", list[argno]);
+				fprintf (GMT_stdout, "%s: E77 not applied\n", list[argno]);
 			MGD77_Close_File (&M);
 			MGD77_Free (D);
 			continue;
 		}
 		if (dump_formatted_header) {	/* Dump of header items, one per line */
-			MGD77_Dump_Header_Params (&M, D->H.mgd77);	
+			MGD77_Dump_Header_Params (&M, D->H.mgd77[use]);	
 			MGD77_Close_File (&M);
 			MGD77_Free (D);
 			continue;
@@ -255,47 +259,46 @@ int main (int argc, char **argv)
 		if (first && quick_summary) {	/* Output all column headers */
 			for (i = 0; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				printf ("%s%s", gmtdefs.field_delimiter, D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
+				fprintf (GMT_stdout,"%s%s", gmtdefs.field_delimiter, D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
 			}
-			printf ("\n");
+			fprintf (GMT_stdout,"\n");
 		}
 		
 		if (col_summary) {	/* Just list names and info for any extra columns */
 			for (i = 0, first = TRUE; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				if (!first) printf ("%s", gmtdefs.field_delimiter);
+				if (!first) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
 				if (((col_listing & 1) && M.order[i].set == 0) || ((col_listing & 2) && M.order[i].set == 1)) {
-					printf ("%s", D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
+					fprintf (GMT_stdout, "%s", D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
 					first = FALSE;
 				}
 			}
-			if (first) printf ("No columns matching selection found!");
-			printf ("\n");
+			if (first) fprintf (GMT_stdout, "No columns matching selection found!");
+			fprintf (GMT_stdout, "\n");
 			MGD77_Close_File (&M);
 			MGD77_Free (D);
 			continue;
 		}
 			
 		if (dump_raw_header) {	/* Write entire MGD77 header */
-			for (i = 0; i < 31; i++) putchar ('-');
-			printf (" Cruise: %8s ", M.NGDC_id);
-			for (i = 0; i < 31; i++) putchar ('-');
-			putchar ('\n');
+			fprintf (GMT_stdout, "-------------------------------");
+			fprintf (GMT_stdout, " Cruise: %8s ", M.NGDC_id);
+			fprintf (GMT_stdout, "-------------------------------\n");
 			MGD77_Write_Header_Record_m77 ("", &Out, &D->H);
-			for (i = 0; i < 80; i++) putchar ('-');
-			putchar ('\n');
+			fprintf (GMT_stdout, "----------------------------------------");
+			fprintf (GMT_stdout, "----------------------------------------\n");
 			if (M.format == MGD77_FORMAT_CDF) {
-				printf (D->H.history);
+				fprintf (GMT_stdout, "%s\n", D->H.history);
 				for (i = 0; i < M.n_out_columns; i++) {
 					if ((M.order[i].set == MGD77_CDF_SET)) {
-						printf ("> %s%s%s%s%s%s%s", D->H.info[MGD77_CDF_SET].col[M.order[i].item].abbrev, gmtdefs.field_delimiter,
+						fprintf (GMT_stdout, "> %s%s%s%s%s%s%s", D->H.info[MGD77_CDF_SET].col[M.order[i].item].abbrev, gmtdefs.field_delimiter,
 						D->H.info[MGD77_CDF_SET].col[M.order[i].item].name, gmtdefs.field_delimiter,
 						D->H.info[MGD77_CDF_SET].col[M.order[i].item].units, gmtdefs.field_delimiter,
 						D->H.info[MGD77_CDF_SET].col[M.order[i].item].comment);
 					}
 				}
 			}
-			putchar ('\n');
+			fprintf (GMT_stdout, "\n");
 		}
 		
 		GMT_make_dnan (tmin);
@@ -368,7 +371,7 @@ int main (int argc, char **argv)
 
 		GMT_io.geo.range = saved_range;	/* We reset this each time */
 		n_quad = quad[0] + quad[1] + quad[2] + quad[3];	/* How many quadrants had data */
-		if (quad[0] && quad[3]) {	/* Longitudes on either side of Greenwhich only, must use -180/+180 notation */
+		if (quad[0] && quad[3]) {	/* Longitudes on either side of Greenwich only, must use -180/+180 notation */
 			xmin = xmin2;
 			xmax = xmax2;
 			GMT_io.geo.range = 2;	/* Override this setting explicitly */
@@ -400,12 +403,12 @@ int main (int argc, char **argv)
 		if (GMT_is_dnan(tmin) || GMT_is_dnan(tmax)) {
 			int yy[2], mm[2], dd[2];
 			if (gmtdefs.verbose) fprintf (stderr, "%s warning: cruise %s no time records.\n",GMT_program, M.NGDC_id);
-			yy[0] = (!D->H.mgd77->Survey_Departure_Year[0] || !strncmp (D->H.mgd77->Survey_Departure_Year, ALL_BLANKS, (size_t)4)) ? 0 : atoi (D->H.mgd77->Survey_Departure_Year);
-			yy[1] = (!D->H.mgd77->Survey_Arrival_Year[0] || !strncmp (D->H.mgd77->Survey_Arrival_Year, ALL_BLANKS, (size_t)4)) ? 0 : atoi (D->H.mgd77->Survey_Arrival_Year);
-			mm[0] = (!D->H.mgd77->Survey_Departure_Month[0] || !strncmp (D->H.mgd77->Survey_Departure_Month, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77->Survey_Departure_Month);
-			mm[1] = (!D->H.mgd77->Survey_Arrival_Month[0] || !strncmp (D->H.mgd77->Survey_Arrival_Month, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77->Survey_Arrival_Month);
-			dd[0] = (!D->H.mgd77->Survey_Departure_Day[0] || !strncmp (D->H.mgd77->Survey_Departure_Day, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77->Survey_Departure_Day);
-			dd[1] = (!D->H.mgd77->Survey_Arrival_Day[0] || !strncmp (D->H.mgd77->Survey_Arrival_Day, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77->Survey_Arrival_Day);
+			yy[0] = (!D->H.mgd77[use]->Survey_Departure_Year[0] || !strncmp (D->H.mgd77[use]->Survey_Departure_Year, ALL_BLANKS, (size_t)4)) ? 0 : atoi (D->H.mgd77[use]->Survey_Departure_Year);
+			yy[1] = (!D->H.mgd77[use]->Survey_Arrival_Year[0] || !strncmp (D->H.mgd77[use]->Survey_Arrival_Year, ALL_BLANKS, (size_t)4)) ? 0 : atoi (D->H.mgd77[use]->Survey_Arrival_Year);
+			mm[0] = (!D->H.mgd77[use]->Survey_Departure_Month[0] || !strncmp (D->H.mgd77[use]->Survey_Departure_Month, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77[use]->Survey_Departure_Month);
+			mm[1] = (!D->H.mgd77[use]->Survey_Arrival_Month[0] || !strncmp (D->H.mgd77[use]->Survey_Arrival_Month, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77[use]->Survey_Arrival_Month);
+			dd[0] = (!D->H.mgd77[use]->Survey_Departure_Day[0] || !strncmp (D->H.mgd77[use]->Survey_Departure_Day, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77[use]->Survey_Departure_Day);
+			dd[1] = (!D->H.mgd77[use]->Survey_Arrival_Day[0] || !strncmp (D->H.mgd77[use]->Survey_Arrival_Day, ALL_BLANKS, (size_t)2)) ? 1 : atoi (D->H.mgd77[use]->Survey_Arrival_Day);
 			if (! (yy[0] == 0 && yy[1] == 0)) {	/* With year we can do something */
 				rata_die = GMT_rd_from_gymd (yy[0], mm[0], dd[0]);
 				tmin = GMT_rdc2dt (rata_die, 0.0);
@@ -414,7 +417,7 @@ int main (int argc, char **argv)
 			}
 		}			
 		if (quick_summary) {
-			printf ("%8s%s%8s%s", M.NGDC_id, gmtdefs.field_delimiter, D->H.mgd77->Survey_Identifier, gmtdefs.field_delimiter);
+			fprintf (GMT_stdout,"%8s%s%8s%s", M.NGDC_id, gmtdefs.field_delimiter, D->H.mgd77[use]->Survey_Identifier, gmtdefs.field_delimiter);
 			GMT_ascii_output_one (GMT_stdout, xmin, 0);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
 			GMT_ascii_output_one (GMT_stdout, xmax, 0);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
 			GMT_ascii_output_one (GMT_stdout, ymin, 1);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
@@ -423,17 +426,17 @@ int main (int argc, char **argv)
 				GMT_ascii_output_one (GMT_stdout, tmin, 2);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
 				GMT_ascii_output_one (GMT_stdout, tmax, 2);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);						
 			} else {
-				printf ("%4s-%2s-%2s%s%4s-%2s-%2s%s",
-				D->H.mgd77->Survey_Departure_Year, D->H.mgd77->Survey_Departure_Month, D->H.mgd77->Survey_Departure_Day, gmtdefs.field_delimiter,
-				D->H.mgd77->Survey_Arrival_Year, D->H.mgd77->Survey_Arrival_Month, D->H.mgd77->Survey_Arrival_Day, gmtdefs.field_delimiter);
+				fprintf (GMT_stdout, "%4s-%2s-%2s%s%4s-%2s-%2s%s",
+				D->H.mgd77[use]->Survey_Departure_Year, D->H.mgd77[use]->Survey_Departure_Month, D->H.mgd77[use]->Survey_Departure_Day, gmtdefs.field_delimiter,
+				D->H.mgd77[use]->Survey_Arrival_Year, D->H.mgd77[use]->Survey_Arrival_Month, D->H.mgd77[use]->Survey_Arrival_Day, gmtdefs.field_delimiter);
 			}
-			printf ("%ld%s%ld", (GMT_LONG)irint (this_dist), gmtdefs.field_delimiter, D->H.n_records);
+			fprintf (GMT_stdout, "%ld%s%ld", (GMT_LONG)irint (this_dist), gmtdefs.field_delimiter, D->H.n_records);
 			for (i = 1; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
 				if (((col_listing & 1) && M.order[i].set == 0) || ((col_listing & 2) && M.order[i].set == 1))
-					printf ("%s%ld",	gmtdefs.field_delimiter, counter[i]);
+					fprintf (GMT_stdout,"%s%ld",	gmtdefs.field_delimiter, counter[i]);
 			}
-			printf ("\n");
+			fprintf (GMT_stdout,"\n");
 		}
 		MGD77_Free (D);
 	}
