@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77manage.c,v 1.132 2009/09/14 03:22:14 guru Exp $
+ *	$Id: mgd77manage.c,v 1.137 2010/01/14 07:15:20 guru Exp $
  *
- *    Copyright (c) 2005-2009 by P. Wessel
+ *    Copyright (c) 2005-2010 by P. Wessel
  * mgd77manage is used to (1) remove data columns from mgd77+ files
  * or (2) add a new data column to mgd77+ files.  Data can be added
  * from data tables, created from reference field formulas, or by
@@ -960,12 +960,13 @@ int main (int argc, char **argv)
 			FILE *fp_e;
 			int cdf_var_id, cdf_adjust;
 			char ID[16], date[16], field[GMT_TEXT_LEN], efile[BUFSIZ], E77[256], timestamp[GMT_TEXT_LEN], answer[BUFSIZ], code[BUFSIZ], YorN, kind;
-			GMT_LONG n_recs, rec, number;
+			GMT_LONG n_recs, rec, number, tz;
 			GMT_LONG type, it, id, key, n_E77_flags, from, to, day, month, year, item;
-			GMT_LONG n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_unprocessed, e_error = 0;
+			GMT_LONG n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_tz_corr, n_unprocessed, e_error = 0;
 			unsigned int *flags, pattern;
 			size_t length;
-			BOOLEAN has_time, old_flags;
+			BOOLEAN has_time, old_flags, tz_errors = FALSE;
+			short *tz_corr = NULL;
 			struct MGD77_HEADER_PARAMS *P;
 			double rec_time, del_t, value, *tvar = VNULL;
 			
@@ -1038,7 +1039,8 @@ int main (int argc, char **argv)
 			
 			e_error = n_unprocessed = 0;
 			while (GMT_fgets (line, BUFSIZ, fp_e)) {
-				if (line[0] == '#' || line[0] == '\n') continue;	/* Comments or blank lines are OK */
+				GMT_chop (line);		/* Rid the world of CR/LF */
+				if (line[0] == '#' || line[0] == '\0') continue;	/* Comments or blank lines are OK */
 				if (line[1] == '-') {		/* Header record */
 					if (!(line[0] == 'Y' || line[0] == 'N') && !ignore_verify) {		/* Unprocessed recommendation? */
 						fprintf (stderr, "%s: UNDECIDED: %s\n", list[argno], line);
@@ -1074,14 +1076,14 @@ int main (int argc, char **argv)
 			while (GMT_fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Header", (size_t)14));	/* Read until we get to Header record section */
 			
 			flags = (unsigned int *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (unsigned int), GMT_program);
-			n_E77_flags = n_E77_headers = n_E77_scales = n_E77_offsets = n_E77_recalcs = 0;
+			n_E77_flags = n_E77_headers = n_E77_scales = n_E77_offsets = n_E77_recalcs = n_tz_corr = 0;
 
 			MGD77_nc_status (nc_open (In.path, NC_WRITE, &In.nc_id));	/* Open the file */
 			MGD77_nc_status (nc_redef (In.nc_id));				/* Enter define mode */
 			old_flags = MGD77_Remove_E77 (&In);				/* Remove any previously revised header parameters */
 			while (GMT_fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Data", (size_t)14)) {	/* Read until we get to data record section */
-				if (line[0] == '#' || line[0] == '\n') continue;	/* Skip comments */
 				GMT_chop (line);					/* Rid the world of CR/LF */
+				if (line[0] == '#' || line[0] == '\0') continue;	/* Skip comments */
 				/* Example of expected line:  
 				   Y-E-06050010-H15-01: Invalid Gravity Departure Base Station Value: (0000000) [1000009]
 				*/
@@ -1268,6 +1270,15 @@ int main (int argc, char **argv)
 									flags[rec] |= set_bit(NCPOS_LAT);
 									n_E77_flags++;
 									break;
+								case 'F':	/* Time-zone error */
+									if (!tz_errors) {	/* First time we must allocate tz_corr array */
+										tz_corr = (short *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (short), GMT_program);
+										tz_errors = TRUE;
+									}
+									sscanf (line, "%*c %*s %*s %*s %*s %*s %*s %*s %ld", &tz);
+									tz_corr[rec] = (short)tz;
+									n_tz_corr++;
+									break;
 								default:
 									fprintf (stderr, "%s: Unrecognized NAV code %c - skipped\n", list[argno], p[k]);
 									break;
@@ -1299,13 +1310,20 @@ int main (int argc, char **argv)
 			/* Update E77 history */
 
 			(void) time (&now);
-			sprintf (E77, "%s [%s] E77 corrections applied to header: %ld scale: %ld offset: %ld recalc: %ld flags: %ld", ctime(&now), In.user, n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_E77_flags);
+			sprintf (E77, "%s [%s] E77 corrections applied to header: %ld scale: %ld offset: %ld recalc: %ld flags: %ld tz_corr: %ld", ctime(&now), In.user, n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_E77_flags, n_tz_corr);
 			for (i = 0; E77[i]; i++) if (E77[i] == '\n') E77[i] = ' ';	/* Remove the \n returned by ctime() */
 			k = strlen (E77);
 			D->H.E77 = (char *)GMT_memory ((void *)D->H.E77, (size_t)(k+1), sizeof (char), GMT_program);
 			strcpy (D->H.E77, E77);
 			MGD77_nc_status (nc_put_att_text (In.nc_id, NC_GLOBAL, "E77", (size_t)k, D->H.E77));
 		
+			if (tz_errors) {	/* Use time var_id */
+				MGD77_nc_status (nc_put_att_short (In.nc_id, D->H.info[MGD77_M77_SET].col[0].var_id, "tz_corr", NC_SHORT, (size_t)D->H.n_records, tz_corr));
+				memset ((void *)answer, 0, (size_t)BUFSIZ);	/* No default answer */
+				strcpy (answer, "tz_corr in hours to subtract from UTC");
+				MGD77_nc_status (nc_put_att_text (In.nc_id, D->H.info[MGD77_M77_SET].col[0].var_id, "comment", strlen (answer), answer));
+				GMT_free ((void *)tz_corr);
+			}
 			old_flags =  (nc_inq_varid (In.nc_id, "MGD77_flags", &cdf_var_id) == NC_NOERR);	/* TRUE if flag variable exists already */
 			
 			if (n_E77_flags) {	/* Add flags to netCDF file */
