@@ -1,8 +1,8 @@
 /* -------------------------------------------------------------------
- *	$Id: mgd77sniffer.h,v 1.36 2009/09/09 23:27:04 guru Exp $	
+ *	$Id: mgd77sniffer.h,v 1.39 2010/01/05 01:15:48 guru Exp $	
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
- *    Copyright (c) 2004-2009 by P. Wessel and M. T. Chandler
+ *    Copyright (c) 2004-2010 by P. Wessel and M. T. Chandler
  *	File:	mgd77sniffer.h
  *
  *	Include file for mgd77sniffer
@@ -96,7 +96,7 @@ struct MGD77_GRID_INFO {
 	struct GRD_HEADER grdhdr;
 	struct GMT_EDGEINFO edgeinfo;
 	struct GMT_BCR bcr;
-	int one_or_zero, nx, ny, col, sign, g_pts, format, mode, mx, interpolate;
+	int one_or_zero, nx, ny, col, sign, g_pts, format, mode, mx, interpolate, n_nan;
 	double scale, max_lat;
 	char abbrev[8];
 	char fname[32];
@@ -116,7 +116,8 @@ struct MGD77_SNIFFER_DEFAULTS {
 };
 
 struct MGD77_ERROR {
-	unsigned int flags[6];
+	unsigned int flags[N_ERROR_CLASSES];
+	int utc_offset;
 };
 
 struct MGD77_MAG_RF {
