@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77track.c,v 1.60 2008/04/17 01:24:29 guru Exp $
+ *	$Id: mgd77track.c,v 1.68 2010/01/05 01:15:48 guru Exp $
  *
- *    Copyright (c) 2004-2008 by P. Wessel
+ *    Copyright (c) 2004-2010 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -29,6 +29,9 @@
 #define MGD77TRACK_MARK_SAMEDAY	1
 #define MGD77TRACK_MARK_DIST	2
 
+#define ANNOT	0
+#define LABEL	1
+
 struct MGD77TRACK_ANNOT {
 	double annot_int_dist;
 	double tick_int_dist;
@@ -52,18 +55,18 @@ struct MGD77TRACK_MARKER {
 int main (int argc, char **argv)
 {
 	GMT_LONG rec, first_rec, last_rec, n_alloc_c = GMT_SMALL_CHUNK;
-	int i, j, n_id = 0, mrk = 0, annot_name = 0, dist_flag = 2, n_paths;
+	int i, j, n_id = 0, mrk = 0, annot_name = 0, dist_flag = 2, use, n_paths;
 	int this_julian = 0, last_julian, argno, n_cruises = 0;
 	
 	BOOLEAN error = FALSE, first, both = FALSE, no_clip = FALSE;
-	BOOLEAN  annot_tick = FALSE, draw_tick = FALSE;
+	BOOLEAN  annot_tick[2] = {0, 0}, draw_tick[2] = {0, 0}, dist_gap = FALSE, time_gap = FALSE;
 	
 	char *start_date = CNULL, *stop_date = CNULL, ms[GMT_TEXT_LEN], mc[GMT_TEXT_LEN];
        	char label[GMT_LONG_TEXT], date[GMT_TEXT_LEN], clock[GMT_TEXT_LEN], comment[BUFSIZ];
-	char mfs[GMT_TEXT_LEN], mf[GMT_TEXT_LEN], mfc[GMT_TEXT_LEN], name[GMT_TEXT_LEN], **list;
+	char mfs[GMT_TEXT_LEN], mf[GMT_TEXT_LEN], mfc[GMT_TEXT_LEN], name[GMT_TEXT_LEN], **list, *p;
 
-	double west, east, south, north, start_time, stop_time, start_dist;
-	double stop_dist, dist_scale, x, y, annot_dist = 0, tick_dist = 0, annot_time = 0, tick_time = 0;
+	double west, east, south, north, start_time, stop_time, start_dist, gap_d = 0.0, gap_t = 0.0;
+	double stop_dist, dist_scale, x, y, annot_dist[2] = {0, 0}, tick_dist[2] = {0, 0}, annot_time[2] = {0, 0}, tick_time[2] = {0, 0};
 	double *track_dist = NULL, angle, plot_x, plot_y, *lon, *lat, *track_time;
 	double annotsize = MGD77TRACK_ANSIZE, factor = 0.001, scale = 1.0, c_angle;
 	
@@ -73,7 +76,7 @@ int main (int argc, char **argv)
 	struct GMT_PEN pen;
 	struct GMT_gcal calendar;
 	struct MGD77TRACK_MARKER marker[3];	/* Time (2) and distance marker information */
-	struct MGD77TRACK_ANNOT info;
+	struct MGD77TRACK_ANNOT info[2];
 
 	int get_annotinfo (char *args, struct MGD77TRACK_ANNOT *info);
 	void annot_legname (double x, double y, double lon, double lat, double angle, char *text, double size);
@@ -108,6 +111,7 @@ int main (int argc, char **argv)
 	west = 0.0;	east = 360.0;	south = -90.0;	north = 90.0;
 	start_time = start_dist = 0.0;
 	stop_time = stop_dist = DBL_MAX;
+	memset ((void *)info, 0, 2*sizeof (struct MGD77TRACK_ANNOT));
 
 	for (i = 1; !error && i < argc; i++) {	/* Process input options */
 		if (argv[i][0] != '-') continue;
@@ -135,7 +139,12 @@ int main (int argc, char **argv)
 				annot_name = 1;
 				j = 2;
 				if (argv[i][2] == 'c') j = 3, annot_name = 2;
-				if (argv[i][j]) annotsize = atof (&argv[i][j]) * GMT_u2u[GMT_PT][GMT_INCH];
+				if (argv[i][j] && argv[i][j] != ',') annotsize = atof (&argv[i][j]) * GMT_u2u[GMT_PT][GMT_INCH];
+				if ((p = strchr (&argv[i][2], ','))) {	/* Want label at regular spacing */
+					p++;	/* Skip the comma */
+					error += get_annotinfo (p, &info[LABEL]);
+					annot_name = -annot_name;	/* Flag to tell machinery not to annot at entry */
+				}
 				break;
 
 			case 'C':	/* Distance calculation flag */
@@ -162,11 +171,28 @@ int main (int argc, char **argv)
 				M.use_flags[MGD77_M77_SET] = M.use_flags[MGD77_CDF_SET] = FALSE;
 				break;
 				
+			case 'G':
+				switch (argv[i][2]) {
+					case 'd':	/* Distance gap in km */
+						gap_d = atof (&argv[i][3]) * 1000.0;	/* Gap converted to m from km */
+						dist_gap = TRUE;
+						break;
+					case 't':	/* Distance gap in minutes */
+						gap_t = atof (&argv[i][3]) * 60.0;	/* Gap converted to seconds from minutes */
+						time_gap = TRUE;
+						break;
+					default:
+						fprintf(stderr, "%s: ERROR -G: Requires t|d and a positive value in km (d) or minutes (t)\n", GMT_program);
+						error++;
+						break;
+				}
+				break;
+				
 			case 'I':
 				MGD77_Process_Ignore (argv[i][1], &argv[i][2]);
 				break;
 			case 'L':
-				error += get_annotinfo (&argv[i][2], &info);
+				error += get_annotinfo (&argv[i][2], &info[ANNOT]);
 				break;
 	
 			case 'N':
@@ -215,7 +241,7 @@ int main (int argc, char **argv)
 				marker[mrk].marker_size = GMT_convert_units (ms, GMT_INCH);
 				GMT_getfill (mc, &marker[mrk].s);
 				marker[mrk].font_size = atof (mfs) * GMT_u2u[GMT_PT][GMT_INCH];
-				marker[mrk].font_no = (mf[0] >= '0' && mf[0] <= '9') ? atoi (mf) : GMT_font_lookup (mf, GMT_font, GMT_N_FONTS);;
+				marker[mrk].font_no = GMT_font_lookup (mf, GMT_font, GMT_N_FONTS);
 				GMT_getfill (mfc, &marker[mrk].f);
 				break;
 			
@@ -259,11 +285,19 @@ int main (int argc, char **argv)
 		fprintf(stderr, "%s: ERROR: Start distance exceeds stop distance!\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
+	if (dist_gap && gap_d <= 0.0) {
+		fprintf(stderr, "%s: ERROR: -Gd: Must specify a positive gap distance in km\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+	if (time_gap && gap_t <= 0.0) {
+		fprintf(stderr, "%s: ERROR: -Gt: Must specify a positive gap distance in minutes\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
 	
 	if (GMT_give_synopsis_and_exit || argc == 1) {	/* Display usage */
 		fprintf (stderr, "mgd77track %s - Plot track-line map of MGD77 cruises\n\n", MGD77_VERSION);
-		fprintf (stderr, "usage: mgd77track cruise(s) %s %s [-A[c][size]] [%s]\n", GMT_Rgeo_OPT, GMT_J_OPT, GMT_B_OPT);
-		fprintf (stderr, "\t[-Cf|g|e] [-Da<startdate>] [-Db<stopdate>] [-F] [-I<code>] [-K] [-L<trackticks>] [-N] [-O] [-P] [-Sa<startdist>[unit]]\n");
+		fprintf (stderr, "usage: mgd77track cruise(s) %s %s [-A[c][size]][,<inc><unit>] [%s]\n", GMT_Rgeo_OPT, GMT_J_OPT, GMT_B_OPT);
+		fprintf (stderr, "\t[-Cf|g|e] [-Da<startdate>] [-Db<stopdate>] [-F] [-Gt|d<gap>] [-I<code>] [-K] [-L<trackticks>] [-N] [-O] [-P] [-Sa<startdist>[unit]]\n");
 		fprintf (stderr, "\t[-Sb<stopdist>[unit]] [-TT|t|d<ms,mc,mfs,mf,mfc>] [%s] [-V] [-W<pen>] [%s]\n", GMT_U_OPT, GMT_X_OPT);
 		fprintf (stderr, "\t[%s] [%s]\n\n", GMT_Y_OPT, GMT_c_OPT);
       
@@ -275,6 +309,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "	OPTIONS:\n\n");
 		fprintf(stderr, "	-A will Annotate legs when they enter the grid. Append c for cruise ID [Default is file prefix]\n");
 		fprintf(stderr, "	   <size> is optional text size in points [9].  The font used is controlled by LABEL_FONT\n");
+		fprintf(stderr, "	   Optionally, append ,<inc>[unit] to place label every <inc> units apart. <unit> may be\n");
+		fprintf(stderr, "	   k (km), n (nautical miles) or d (days), h (hours).\n");
 		GMT_explain_option ('B');
 		fprintf (stderr,"	-C Select procedure for along-track distance calculations:\n");
 		fprintf (stderr,"	   f Flat Earth\n");
@@ -283,6 +319,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "	-Da plots from <startdate> (given as yyyy-mm-ddT[hh:mm:ss]) [Start of cruise]\n");
 		fprintf (stderr, "	-Db plots up to <stopdate> (given as yyyy-mm-ddT[hh:mm:ss]) [End of cruise]\n");
 		fprintf(stderr,"	-F Do NOT apply bitflags to MGD77+ cruises [Default applies error flags stored in the file]\n");
+		fprintf(stderr,"	-G Consider point separations exceeding d<gap> (km) or t<gap> (minutes) to indicate a gap (do not draw) [0]\n");
 		fprintf(stderr,"	-I Ignore certain data file formats from consideration. Append combination of act to ignore\n");
 		fprintf (stderr, "	   (a) MGD77 ASCII, (c) MGD77+ netCDF, or (t) plain table files. [Default ignores none]\n");
 		GMT_explain_option ('K');
@@ -319,6 +356,7 @@ int main (int argc, char **argv)
 	}
 
 	dist_scale = 1000.0 * project_info.M_PR_DEG;	/* Work internally in meters */
+	use = (M.original) ? MGD77_ORIG : MGD77_REVISED;
 
 	if (east < west) west -= 360.0;
 		
@@ -328,7 +366,7 @@ int main (int argc, char **argv)
 	
 	GMT_map_clip_on (GMT_no_rgb, 3);
 	GMT_setpen (&pen);
-	both = (info.annot_int_time && info.annot_int_dist);
+	both = (info[ANNOT].annot_int_time && info[ANNOT].annot_int_dist);
 	
 	if (no_clip) {
 		cruise_id = (struct MGD77TRACK_LEG_ANNOT *) GMT_memory (VNULL, (size_t)n_alloc_c, sizeof (struct MGD77TRACK_LEG_ANNOT), "mgd77track");
@@ -352,8 +390,8 @@ int main (int argc, char **argv)
 		rec = 0;
 		last_julian = -1;
 		
-		if (annot_name == 2) {	/* Use MGD77 cruise ID */
-			strcpy (name, D.H.mgd77->Survey_Identifier);
+		if (abs(annot_name) == 2) {	/* Use MGD77 cruise ID */
+			strcpy (name, D.H.mgd77[use]->Survey_Identifier);
 		}
 		else {			/* Use file name prefix */
 			strcpy (name, list[argno]);
@@ -375,14 +413,35 @@ int main (int argc, char **argv)
 		first_rec = rec;
 		for (rec = D.H.n_records - 1; rec && track_time[rec] > stop_time && bad_coordinates(lon[rec], lat[rec]) && track_dist[rec] > stop_dist; rec--);	/* Find last record of interest */
 		last_rec = rec;
-		if (gmtdefs.verbose) fprintf (stderr, "mgd77track: Plotting %s [%s]\n", list[argno], D.H.mgd77->Survey_Identifier);
+		if (gmtdefs.verbose) fprintf (stderr, "mgd77track: Plotting %s [%s]\n", list[argno], D.H.mgd77[use]->Survey_Identifier);
 		sprintf (comment, "Tracking %s", list[argno]);
 		ps_comment (comment);
 		
 		/* First draw the track line, clip segments outside the area */
 		
-		GMT_n_plot = GMT_geo_to_xy_line (lon, lat, D.H.n_records);
-		GMT_plot_line (GMT_x_plot, GMT_y_plot, GMT_pen, GMT_n_plot);
+		if (dist_gap || time_gap) {
+			GMT_LONG start, stop;
+			start = first_rec;
+			while (start < last_rec && ((dist_gap && (track_dist[start+1] - track_dist[start]) > gap_d) || (time_gap && (track_time[start+1] - track_time[start]) > gap_t))) {	/* First start of first segment */
+				lon[start] = GMT_d_NaN;	/* Flag to make sure we do not plot this gap later */
+				start++;
+			}
+			while (start <= last_rec) {
+				stop = start;
+				while (stop < last_rec && ((dist_gap && (track_dist[stop+1] - track_dist[stop]) < gap_d) || (time_gap && (track_time[stop+1] - track_time[stop]) < gap_t))) stop++;	/* stop will be last point in segment */
+				GMT_n_plot = GMT_geo_to_xy_line (&lon[start], &lat[start], stop-start+1);
+				GMT_plot_line (GMT_x_plot, GMT_y_plot, GMT_pen, GMT_n_plot);
+				start = stop + 1;
+				while (start < last_rec && ((dist_gap && (track_dist[start+1] - track_dist[start]) > gap_d) || (time_gap && (track_time[start+1] - track_time[start]) > gap_t))) {	/* First start of first segment */
+					lon[start] = GMT_d_NaN;	/* Flag to make sure we do not plot this gap later */
+					start++;
+				}
+			}
+		}
+		else {	/* Plot the whole shabang */
+			GMT_n_plot = GMT_geo_to_xy_line (lon, lat, D.H.n_records);
+			GMT_plot_line (GMT_x_plot, GMT_y_plot, GMT_pen, GMT_n_plot);
+		}
 
 		first = TRUE;
 		for (rec = first_rec; rec <= last_rec; rec++) {
@@ -392,7 +451,7 @@ int main (int argc, char **argv)
 			}
 			GMT_geo_to_xy (lon[rec], lat[rec], &x, &y);
 			if (first) {
-				if (annot_name) {
+				if (annot_name > 0) {
 					c_angle = heading (rec, lon, lat, D.H.n_records);
 					if (no_clip) {	/* Keep these in a list to plot after clipping is turned off */
 						cruise_id[n_id].x = x;
@@ -412,39 +471,43 @@ int main (int argc, char **argv)
 						annot_legname (x, y, lon[rec], lat[rec], c_angle, name, GMT_u2u[GMT_INCH][GMT_PT] * 1.25 * annotsize);
 				}
 				first = FALSE;
-				if (info.annot_int_dist > 0) annot_dist = (track_dist[rec] / info.annot_int_dist + 1) * info.annot_int_dist;
-				if (info.tick_int_dist > 0) tick_dist = (track_dist[rec] / info.tick_int_dist + 1) * info.tick_int_dist;
-				if (info.annot_int_time > 0) annot_time = ceil (track_time[rec] / info.annot_int_time) * info.annot_int_time;
-				if (info.tick_int_time > 0) tick_time = ceil (track_time[rec] / info.tick_int_time) * info.tick_int_time;
+				for (i = 0; i < 2; i++) {
+					if (info[i].annot_int_dist > 0) annot_dist[i] = (track_dist[rec] / info[i].annot_int_dist + 1) * info[i].annot_int_dist;
+					if (info[i].tick_int_dist > 0) tick_dist[i] = (track_dist[rec] / info[i].tick_int_dist + 1) * info[i].tick_int_dist;
+					if (info[i].annot_int_time > 0) annot_time[i] = ceil (track_time[rec] / info[i].annot_int_time) * info[i].annot_int_time;
+					if (info[i].tick_int_time > 0) tick_time[i] = ceil (track_time[rec] / info[i].tick_int_time) * info[i].tick_int_time;
+				}
 			}
 			
-			/* See if we need to annotate/tick the trackline for time/km marks */
+			/* See if we need to annotate/tick the trackline for time/km and/or ID marks */
 			
-			if (info.annot_int_time && (track_time[rec] >= annot_time)) {
-				annot_time += info.annot_int_time;
-				annot_tick = 1;
+			for (i = 0; i < 2; i++) {
+				if (info[i].annot_int_time && (track_time[rec] >= annot_time[i])) {
+					annot_time[i] += info[i].annot_int_time;
+					annot_tick[i] = 1;
+				}
+				if (info[i].annot_int_dist && (track_dist[rec] >= annot_dist[i])) {
+					annot_dist[i] += info[i].annot_int_dist;
+					annot_tick[i] += 2;
+				}
+				if (info[i].tick_int_time && (track_time[rec] >= tick_time[i])) {
+					tick_time[i] += info[i].tick_int_time;
+					draw_tick[i] = 1;
+				}
+				if (info[i].tick_int_dist && (track_dist[rec] >= tick_dist[i])) {
+					tick_dist[i] += info[i].tick_int_dist;
+					draw_tick[i] += 2;
+				}
 			}
-			if (info.annot_int_dist && (track_dist[rec] >= annot_dist)) {
-				annot_dist += info.annot_int_dist;
-				annot_tick += 2;
-			}
-			if (info.tick_int_time && (track_time[rec] >= tick_time)) {
-				tick_time += info.tick_int_time;
-				draw_tick = 1;
-			}
-			if (info.tick_int_dist && (track_dist[rec] >= tick_dist)) {
-				tick_dist += info.tick_int_dist;
-				draw_tick += 2;
-			}
-			if (annot_tick) {
+			if (annot_tick[ANNOT]) {
 				angle = heading (rec, lon, lat, D.H.n_records);
 				if (angle < 0.0)
 					angle += 90.0;
 				else
 					angle -= 90.0;
-				if (annot_tick & 1) {	/* Time mark */
-					GMT_gcal_from_dt (annot_time, &calendar);			/* Convert t to a complete calendar structure */
-					GMT_format_calendar (date, clock, &GMT_plot_calclock.date, &GMT_plot_calclock.clock, FALSE, 1, annot_time);
+				if (annot_tick[ANNOT] & 1) {	/* Time mark */
+					GMT_gcal_from_dt (annot_time[ANNOT], &calendar);			/* Convert t to a complete calendar structure */
+					GMT_format_calendar (date, clock, &GMT_plot_calclock.date, &GMT_plot_calclock.clock, FALSE, 1, annot_time[ANNOT]);
 					this_julian = calendar.day_y;
 					if (this_julian != last_julian) {
 						mrk = MGD77TRACK_MARK_NEWDAY;
@@ -463,9 +526,9 @@ int main (int argc, char **argv)
 					ps_text (plot_x, plot_y, GMT_u2u[GMT_INCH][GMT_PT] * marker[mrk].font_size, label, angle, 5, 0);
 					last_julian = calendar.day_y;
 				}
-				if (annot_tick & 2) {	/* Distance mark */
+				if (annot_tick[ANNOT] & 2) {	/* Distance mark */
 					mrk = MGD77TRACK_MARK_DIST;
-					sprintf (label, "%d km  ", (int)((annot_dist - info.annot_int_dist) * factor));
+					sprintf (label, "%d km  ", (int)((annot_dist[ANNOT] - info[ANNOT].annot_int_dist) * factor));
 					ps_square (x, y, marker[mrk].marker_size, marker[mrk].s.rgb, TRUE);
 					ps_setpaint (marker[mrk].f.rgb);
 					plot_x = x;	plot_y = y;
@@ -473,20 +536,29 @@ int main (int argc, char **argv)
 					ps_text (plot_x, plot_y, GMT_u2u[GMT_INCH][GMT_PT] * marker[mrk].font_size, label, angle, 7, 0);
 				}
 			}
-			if (both && !(annot_tick & 1) && (draw_tick & 1)) {
+			if (both && !(annot_tick[ANNOT] & 1) && (draw_tick[ANNOT] & 1)) {
 				mrk = (this_julian != last_julian) ? MGD77TRACK_MARK_NEWDAY : MGD77TRACK_MARK_SAMEDAY;
 				ps_circle (x, y, marker[mrk].marker_size, marker[mrk].s.rgb, TRUE);
 			}
-			if (both && !(annot_tick & 2) && (draw_tick & 2)) {
+			if (both && !(annot_tick[ANNOT] & 2) && (draw_tick[ANNOT] & 2)) {
 				mrk = (this_julian != last_julian) ? MGD77TRACK_MARK_NEWDAY : MGD77TRACK_MARK_SAMEDAY;
 				ps_square (x, y, marker[mrk].marker_size, marker[mrk].s.rgb, TRUE);
 			}
-			if (draw_tick) {
+			if (draw_tick[ANNOT]) {
 				mrk = MGD77TRACK_MARK_DIST;
 				ps_setpaint (marker[mrk].s.rgb);
 				ps_cross (x, y, marker[mrk].marker_size);
 			}
-			if (annot_tick || draw_tick) annot_tick = draw_tick = FALSE;
+			if (annot_tick[ANNOT] || draw_tick[ANNOT]) annot_tick[ANNOT] = draw_tick[ANNOT] = FALSE;
+			if (annot_tick[LABEL]) {
+				angle = heading (rec, lon, lat, D.H.n_records);
+				if (angle < 0.0)
+					angle += 90.0;
+				else
+					angle -= 90.0;
+				annot_legname (x, y, lon[rec], lat[rec], angle, name, GMT_u2u[GMT_INCH][GMT_PT] * 1.25 * annotsize);
+				annot_tick[LABEL] = FALSE;
+			}
 		}
 		GMT_free ((void *)track_dist);
 		n_cruises++;
@@ -496,7 +568,7 @@ int main (int argc, char **argv)
 
 	GMT_map_basemap ();
 	
-	if (annot_name && no_clip) {	/* Plot leg names after clipping is terminated ( see -N) */
+	if (annot_name > 0 && no_clip) {	/* Plot leg names after clipping is terminated ( see -N) */
 		int id;
 		double size;
 		size = GMT_u2u[GMT_INCH][GMT_PT] * 1.25 * annotsize;
@@ -538,7 +610,7 @@ double heading (GMT_LONG rec, double *lon, double *lat, GMT_LONG n_records)
 	else if (sum_x2 < GMT_CONV_LIMIT)	/* Line is vertical */
 		angle = 90.0;
 	else
-		angle = (GMT_IS_ZERO (sum_xy)) ? 90.0 : d_atan2 (sum_xy, sum_x2) * R2D;
+		angle = (GMT_IS_ZERO (sum_xy)) ? 90.0 : d_atan2d (sum_xy, sum_x2);
 	if (angle > 90.0)
 		angle -= 180;
 	else if (angle < -90.0)
@@ -638,4 +710,4 @@ void annot_legname (double x, double y, double lon, double lat, double angle, ch
 
 BOOLEAN bad_coordinates (double lon, double lat) {
 	return (GMT_is_dnan (lon) || GMT_is_dnan (lat));
-}
\ No newline at end of file
+}
