@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtlegs.c,v 1.12 2008/03/24 08:58:33 guru Exp $
+ *	$Id: gmtlegs.c,v 1.15 2010/01/05 01:15:48 guru Exp $
  *
- *    Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -31,7 +31,7 @@ struct INFO {
 
 int main (int argc, char **argv)
 {
-	int i, ninfo, n_found = 0, bin, leg, no, flagin, nlegs, gmt, gmtflag = 0;
+	int i, ninfo, n_found = 0, bin, leg, no, flagin, nlegs, gmt, gmtflag = 0, not_used = 0;
 	char lname[16], line[BUFSIZ], file[BUFSIZ];
 	double west, east, south, north;
 	FILE *fleg, *fbin;
@@ -116,10 +116,10 @@ int main (int argc, char **argv)
 	/* Start reading the index-file */
 	
 	while (fread ((void *)&bin, (size_t)4, (size_t)1, fbin) != 0) {
-		fread ((void *)&nlegs, (size_t)4, (size_t)1, fbin);
+		not_used = fread ((void *)&nlegs, (size_t)4, (size_t)1, fbin);
 		if (inside (west, east, south, north, bin)) {
 			for (i = 0; i < nlegs; i++) {
-				fread ((void *)&leg, (size_t)4, (size_t)1, fbin);
+				not_used = fread ((void *)&leg, (size_t)4, (size_t)1, fbin);
 				gmt = leg & 15;
 				leg >>= 4;
 				if ((gmt & gmtflag) == gmtflag) ptr[leg]->mark = TRUE;
