@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: minmax.c,v 1.62 2009/09/09 23:27:03 guru Exp $
+ *    $Id: minmax.c,v 1.64 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -72,11 +72,11 @@ int main (int argc, char **argv)
 	struct MINMAX_CTRL *Ctrl;
 
 	GMT_LONG strip_blanks_and_output (double x, GMT_LONG col);
-	void *New_Minmax_Ctrl (), Free_Minmax_Ctrl (struct MINMAX_CTRL *C);
+	void *New_minmax_Ctrl (), Free_minmax_Ctrl (struct MINMAX_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct MINMAX_CTRL *) New_Minmax_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct MINMAX_CTRL *) New_minmax_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 	
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -492,7 +492,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)xyzmin);
 	GMT_free ((void *)xyzmax);
 
-	Free_Minmax_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_minmax_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -511,10 +511,10 @@ GMT_LONG strip_blanks_and_output (double x, GMT_LONG col)
 	return (fprintf (GMT_stdout, "%s", &text[k]));
 }
 
-void *New_Minmax_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_minmax_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct MINMAX_CTRL *C;
 	
-	C = (struct MINMAX_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct MINMAX_CTRL), "New_Minmax_Ctrl");
+	C = (struct MINMAX_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct MINMAX_CTRL), "New_minmax_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -523,6 +523,6 @@ void *New_Minmax_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Minmax_Ctrl (struct MINMAX_CTRL *C) {	/* Deallocate control structure */
+void Free_minmax_Ctrl (struct MINMAX_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
