@@ -1,6 +1,6 @@
 /*
- *	$Id: gmtstitch.c,v 1.54 2009/07/11 08:33:28 guru Exp $
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	$Id: gmtstitch.c,v 1.57 2010/01/05 01:15:48 guru Exp $
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  */
 /* gmtstitch will combine pieces of coastlines or similar segments into a
  * continuous line, polygon, or group of lines/polygons so that the jump
@@ -62,6 +62,7 @@ int main (int argc, char **argv)
 	memset ((void *)format, 0, BUFSIZ);
 	memset ((void *)linkfile, 0, BUFSIZ);
 	memset ((void *)lists, 0, BUFSIZ);
+	memset ((void *)closedfile, 0, BUFSIZ);
 	
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -222,8 +223,8 @@ int main (int argc, char **argv)
 	n_args = (argc > 1) ? argc : 2;
 
 	switch (distance_flag) {	/* Take different action depending on how we want distances calculated */
-		case 0:		/* Cartesian distance */
-			GMT_distance_func = GMT_cartesian_dist;
+		case 0:		/* Cartesian distance (or spherical degrees if -fg was used) */
+			GMT_distance_func = (GMT_io.in_col_type[0] == GMT_IS_LON) ? GMT_great_circle_dist_km : GMT_cartesian_dist;
 			break;
 		case 1:		/* Flat Earth Approximation */
 			GMT_distance_func = GMT_flatearth_dist_km;
@@ -283,7 +284,7 @@ int main (int argc, char **argv)
 		}
 	}
 	
-	ns = -1;
+	ns = id = -1;
 	n_open = n_closed = 0;
 	closed_dist = (separate) ? cutoff : 0.0;
 	for (k = 0; k < D->n_tables; k++) {
@@ -304,7 +305,7 @@ int main (int argc, char **argv)
 					fp = fp_closed;
 				else
 					fp = GMT_stdout;
-				strcpy (GMT_io.segment_header, D->table[k]->segment[j]->header);
+				if (D->table[k]->segment[j]->header) strcpy (GMT_io.segment_header, D->table[k]->segment[j]->header);
 				GMT_write_segmentheader (fp, D->table[k]->segment[j]->n_columns);
 				Write_This_Segment (fp, D->table[k]->segment[j], (GMT_LONG)0, np-1);
 				if (separate && distance > 0.0) Write_This_Segment (fp, D->table[k]->segment[j], (GMT_LONG)0, 0);	/* Close polygon */
@@ -314,13 +315,13 @@ int main (int argc, char **argv)
 				n_closed++;
 			}
 			else if (separate) {	/* Write open segment to stdout */
-				strcpy (GMT_io.segment_header, D->table[k]->segment[j]->header);
+				if (D->table[k]->segment[j]->header) strcpy (GMT_io.segment_header, D->table[k]->segment[j]->header);
 				GMT_write_segmentheader (GMT_stdout, D->table[k]->segment[j]->n_columns);
 				Write_This_Segment (GMT_stdout, D->table[k]->segment[j], (GMT_LONG)0, np-1);
 				n_open++;
 			}
 			else { /* Here we have a segment that is not closed.  Store refs to D->table and copy end points */
-			
+				if (id == -1) id = 0;
 				seg[id].id = id;
 				seg[id].orig_id = ns;
 				seg[id].group = k;
@@ -448,17 +449,17 @@ int main (int argc, char **argv)
 		fprintf (fp3, "# segid\tbegin_id\tb_pt\tb_dist\tb_nndist\tend_id\te_pt\te_dist\te_nndist\n");
 		for (i = 0; i < ns; i++) {
 			G = seg[i].group;	L = seg[i].pos;
-			if ((pp = strstr (D->table[G]->segment[L]->header, "-L"))) {
+			if (D->table[G]->segment[L]->header && (pp = strstr (D->table[G]->segment[L]->header, "-L"))) {
 				strcpy (name, &pp[2]);
 				for (j = 0; name[j]; j++) if (name[j] == ' ') name[j] = '\0';		/* Just truncate after 1st word */
 			} else sprintf (name, "%ld", seg[i].orig_id);
 			G = seg[seg[i].buddy[0].id].group;	L = seg[seg[i].buddy[0].id].pos;
-			if ((pp = strstr (D->table[G]->segment[L]->header, "-L"))) {
+			if (D->table[G]->segment[L]->header && (pp = strstr (D->table[G]->segment[L]->header, "-L"))) {
 				strcpy (name0, &pp[2]);
 				for (j = 0; name0[j]; j++) if (name0[j] == ' ') name0[j] = '\0';	/* Just truncate after 1st word */
 			} else sprintf (name0, "%ld", seg[i].buddy[0].orig_id);
 			G = seg[seg[i].buddy[1].id].group;	L = seg[seg[i].buddy[1].id].pos;
-			if ((pp = strstr (D->table[G]->segment[L]->header, "-L"))) {
+			if (D->table[G]->segment[L]->header && (pp = strstr (D->table[G]->segment[L]->header, "-L"))) {
 				strcpy (name1, &pp[2]);
 				for (j = 0; name1[j]; j++) if (name1[j] == ' ') name1[j] = '\0';	/* Just truncate after 1st word */
 			} else sprintf (name1, "%ld", seg[i].buddy[1].orig_id);
@@ -540,7 +541,10 @@ int main (int argc, char **argv)
 					j = 0;
 					n = np;
 				}
-				sprintf (GMT_io.segment_header, "# %s", D->table[G]->segment[L]->header);
+				if (D->table[G]->segment[L]->header)
+					sprintf (GMT_io.segment_header, "# %s", D->table[G]->segment[L]->header);
+				else
+					sprintf (GMT_io.segment_header, "#\n");
 				GMT_write_segmentheader (fp, D->table[G]->segment[L]->n_columns);
 				Write_This_Segment (fp, D->table[G]->segment[L], j, np-1);
 				p_last_x = D->table[G]->segment[L]->coord[GMT_X][np-1];
@@ -556,7 +560,10 @@ int main (int argc, char **argv)
 					j = 0;
 					n = np;
 				}
-				sprintf (GMT_io.segment_header, "# Reversed %s", D->table[G]->segment[L]->header);
+				if (D->table[G]->segment[L]->header)
+					sprintf (GMT_io.segment_header, "# Reversed %s", D->table[G]->segment[L]->header);
+				else
+					sprintf (GMT_io.segment_header, "#\n");
 				GMT_write_segmentheader (fp, D->table[G]->segment[L]->n_columns);
 				Write_This_Segment (fp, D->table[G]->segment[L], np-1-j, (GMT_LONG)0);
 				p_last_x = D->table[G]->segment[L]->coord[GMT_X][0];
