@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: nearneighbor.c,v 1.64 2009/09/09 23:27:03 guru Exp $
+ *	$Id: nearneighbor.c,v 1.66 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -105,11 +105,11 @@ int main (int argc, char **argv)
 
 	void assign_node (struct NEARNEIGHBOR_NODE **node, GMT_LONG n_sector, GMT_LONG sector, double distance, GMT_LONG id);
 	void free_node (struct NEARNEIGHBOR_NODE *node);
-	void *New_Nearneighbor_Ctrl (), Free_Nearneighbor_Ctrl (struct NEARNEIGHBOR_CTRL *C);
+	void *New_nearneighbor_Ctrl (), Free_nearneighbor_Ctrl (struct NEARNEIGHBOR_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct NEARNEIGHBOR_CTRL *) New_Nearneighbor_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct NEARNEIGHBOR_CTRL *) New_nearneighbor_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_boundcond_init (&edgeinfo);
 
@@ -516,7 +516,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)x0);
 	GMT_free ((void *)y0);
 
-	Free_Nearneighbor_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_nearneighbor_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -558,10 +558,10 @@ void free_node (struct NEARNEIGHBOR_NODE *node)
 	GMT_free ((void *)node);
 }
 
-void *New_Nearneighbor_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_nearneighbor_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct NEARNEIGHBOR_CTRL *C;
 
-	C = (struct NEARNEIGHBOR_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct NEARNEIGHBOR_CTRL), "New_Nearneighbor_Ctrl");
+	C = (struct NEARNEIGHBOR_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct NEARNEIGHBOR_CTRL), "New_nearneighbor_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->N.sectors = 4;
@@ -569,7 +569,7 @@ void *New_Nearneighbor_Ctrl () {	/* Allocate and initialize a new control struct
 	return ((void *)C);
 }
 
-void Free_Nearneighbor_Ctrl (struct NEARNEIGHBOR_CTRL *C) {	/* Deallocate control structure */
+void Free_nearneighbor_Ctrl (struct NEARNEIGHBOR_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);
 	GMT_free ((void *)C);
 }
