@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: project.c,v 1.69 2009/09/09 23:27:03 guru Exp $
+ *	$Id: project.c,v 1.71 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -127,11 +127,11 @@ int main (int argc, char **argv)
 	void	sphere_project_setup (double alat, double alon, double *a, double blat, double blon, double *b, double azim, double *p, double *c, GMT_LONG two_pts);
 	void	flat_project_setup (double alat, double alon, double blat, double blon, double plat, double plon, double *azim, double *e, GMT_LONG two_pts, BOOLEAN pole_set);
 	void	copy_text_from_col3 (char *line, char *z_cols);
-	void	*New_Project_Ctrl (), Free_Project_Ctrl (struct PROJECT_CTRL *C);
+	void	*New_project_Ctrl (), Free_project_Ctrl (struct PROJECT_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PROJECT_CTRL *) New_Project_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct PROJECT_CTRL *) New_project_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	memset ((void *)output_choice, 0, PROJECT_N_FARGS * sizeof (GMT_LONG));
 
@@ -759,7 +759,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)p_data);
 	GMT_free ((void *)out);
 
-	Free_Project_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_project_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -977,16 +977,16 @@ void copy_text_from_col3 (char *line, char *z_cols)
 	sscanf (line, "%*s %*s %[^\n]", z_cols);
 }
 
-void *New_Project_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_project_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PROJECT_CTRL *C;
 	
-	C = (struct PROJECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PROJECT_CTRL), "New_Project_Ctrl");
+	C = (struct PROJECT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PROJECT_CTRL), "New_project_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
 	return ((void *)C);
 }
 
-void Free_Project_Ctrl (struct PROJECT_CTRL *C) {	/* Deallocate control structure */
+void Free_project_Ctrl (struct PROJECT_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
