@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: ps2raster.c,v 1.66 2009/07/27 18:49:15 jluis Exp $
+ *	$Id: ps2raster.c,v 1.69 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 2006-2009 by J. Luis
+ *	Copyright (c) 2006-2010 by J. Luis
  *	See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -139,6 +139,7 @@ int main (int argc, char **argv) {
 	GMT_LONG got_BB, got_HRBB, got_BBatend, file_has_HRBB, got_orient, landscape, setup, i_unused = 0;
 	double xt, yt, w, h, x0 = 0.0, x1 = 612.0, y0 = 0.0, y1 = 828.0;
 	double	west = 0.0, east = 0.0, south = 0.0, north = 0.0;
+	double	west_prj, south_prj, east_prj, north_prj;
 
 	size_t n_alloc = GMT_SMALL_CHUNK;
 
@@ -155,14 +156,19 @@ int main (int argc, char **argv) {
 	char at_sign[2] = "";
 #endif
 
+#ifdef USE_GDAL
+	struct GDALREAD_CTRL *to_gdalread;
+	struct GD_CTRL *from_gdalread;
+#endif
+
 	FILE *fp = NULL, *fpo = NULL, *fpb = NULL, *fpl = NULL, *fp2 = NULL, *fpw = NULL;
 
 	struct PS2RASTER_CTRL *Ctrl;
 
-	void *New_Ps2raster_Ctrl (), Free_Ps2raster_Ctrl (struct PS2RASTER_CTRL *C);
+	void *New_ps2raster_Ctrl (), Free_ps2raster_Ctrl (struct PS2RASTER_CTRL *C);
 	BOOLEAN parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C);
 	
-	Ctrl = (struct PS2RASTER_CTRL *)New_Ps2raster_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PS2RASTER_CTRL *)New_ps2raster_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Parameters for all the formats available */
 
@@ -661,8 +667,8 @@ int main (int argc, char **argv) {
 				if (!strncmp(&line[2], "PROJ", 4)) { /* Search for the PROJ tag in the ps file */
 					char *ptmp = NULL, xx1[20], xx2[20], yy1[20], yy2[20];
 					sscanf (&line[8], "%s %s %s %s %s %s %s %s %s",proj4_name,xx1,xx2,yy1,yy2,c1,c2,c3,c4);
-					west = atof (c1);		east = atof (c2);
-					south = atof (c3);		north = atof (c4);
+					west_prj = atof (c1);		east_prj = atof (c2);
+					south_prj = atof (c3);		north_prj = atof (c4);
 					project_info.w = west = atof (xx1);		project_info.e = east = atof (xx2);
 					if (project_info.w > 180.0 && project_info.e > 180.0) {
 						project_info.w -= 360.0;
@@ -729,6 +735,69 @@ int main (int argc, char **argv) {
 				r = 0;
 				continue;
 			}
+#ifdef USE_GDAL
+			else if (!strncmp(c, "%%PageTrailer", (size_t)13) && found_proj) {
+				fgets (line, BUFSIZ, fp);
+				fprintf (fpo, "%%%%PageTrailer\n");
+				fprintf (fpo, "%s", line);
+
+				/* Write a GeoPDF registration info */ 
+
+				/* Allocate new control structures */
+				to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_Gdalread_Ctrl");
+				from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_Gd_Ctrl");
+				to_gdalread->W.active = 1;
+				from_gdalread->ProjectionRefPROJ4 = proj4_cmd;
+				GMT_gdalread ( NULL, to_gdalread, from_gdalread);
+				if (from_gdalread->ProjectionRefWKT != CNULL) {
+					double x0, y0, x1;	/* Projected coordinates */
+					double h0, v0, h1;	/* Correspnding point coordinates */
+					double a, H, V;		/* a -> coeff of affine matrix; H,V -> origin shift in projected coords */
+					double pX[4], pY[4], lptsX[4], lptsY[4];
+
+					x0 = west_prj;		y0 = south_prj;		x1 = east_prj;		y1 = north_prj;
+					h0 = v0 = 0;	/* because we used -A option so origin in points is at (0,0) */
+					h1 = h0 + w;
+					/* takes the projected coordinate system into the page coordinate system */
+					a = (h1 - h0)/(x1 - x0);
+					H = h0 - a*x0;
+					V = v0 - a*y0;
+
+					/* Use the above matrix to discover where the corners of the map will fall */
+					pX[0] = a*x0 + H;	pX[1] = a*x0 + H;	pX[2] = a*x1 + H;	pX[3] = a*x1 + H;
+					pY[0] = a*y0 + V;	pY[1] = a*y1 + V;	pY[2] = a*y1 + V;	pY[3] = a*y0 + V;
+
+					/* Now compute the LPTS array */
+					lptsX[0] = pX[0] / w;	lptsX[1] = pX[1] / w;	lptsX[2] = pX[2] / w;	lptsX[3] = pX[3] / w;
+					lptsY[0] = pY[0] / h;	lptsY[1] = pY[1] / h;	lptsY[2] = pY[2] / h;	lptsY[3] = pY[3] / h;
+
+					fprintf (fpo, "\n%% embed georegistation info\n");
+					fprintf (fpo, "[ {ThisPage} <<\n");
+					fprintf (fpo, "\t/VP [ <<\n");
+					fprintf (fpo, "\t\t/Type /Viewport\n");
+					fprintf (fpo, "\t\t/BBox[0 0 %.1f %.1f]\n", w, h);
+					fprintf (fpo, "\t\t/Measure <<\n");
+					fprintf (fpo, "\t\t\t/Type /Measure\n");
+					fprintf (fpo, "\t\t\t/Subtype /GEO\n");
+					fprintf (fpo, "\t\t\t/Bounds[0 0 0 1 1 1 1 0]\n");
+					fprintf (fpo, "\t\t\t/GPTS[%f %f %f %f %f %f %f %f]\n", 
+						south, west, north, west, north, east, south, east);
+					fprintf (fpo, "\t\t\t/LPTS[%f %f %f %f %f %f %f %f]\n", 
+						lptsX[0],lptsY[0], lptsX[1],lptsY[1], lptsX[2],lptsY[2], lptsX[3],lptsY[3]);
+					fprintf (fpo, "\t\t\t/GCS <<\n");
+					fprintf (fpo, "\t\t\t\t/Type /PROJCS\n");
+					fprintf (fpo, "\t\t\t\t/WKT\n");
+					fprintf (fpo, "\t\t\t\t(%s)\n", from_gdalread->ProjectionRefWKT);
+					fprintf (fpo, "\t\t\t>>\n");
+					fprintf (fpo, "\t\t>>\n");
+					fprintf (fpo, "\t>>]\n");
+					fprintf (fpo, ">> /PUT pdfmark\n\n");
+				}
+				GMT_free((void *)to_gdalread);
+				GMT_free((void *)from_gdalread);
+				continue;
+			}
+#endif
 			fprintf (fpo, "%s", line);
 		}
 
@@ -927,7 +996,7 @@ int main (int argc, char **argv) {
 		}
 	}
 
-	Free_Ps2raster_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_ps2raster_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_free ((void *)ps_names);
 
@@ -1005,10 +1074,10 @@ BOOLEAN parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C)
 	return (error);
 }
 
-void *New_Ps2raster_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_ps2raster_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PS2RASTER_CTRL *C;
 
-	C = (struct PS2RASTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PS2RASTER_CTRL), "New_Ps2raster_Ctrl");
+	C = (struct PS2RASTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PS2RASTER_CTRL), "New_ps2raster_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 #ifdef WIN32
@@ -1024,7 +1093,7 @@ void *New_Ps2raster_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Ps2raster_Ctrl (struct PS2RASTER_CTRL *C) {	/* Deallocate control structure */
+void Free_ps2raster_Ctrl (struct PS2RASTER_CTRL *C) {	/* Deallocate control structure */
 	if (C->D.dir) free ((void *)C->D.dir);
 	if (C->F.file) free ((void *)C->F.file);
 	if (C->G.file) free ((void *)C->G.file);
