@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psbasemap.c,v 1.49 2009/09/09 23:27:03 guru Exp $
+ *	$Id: psbasemap.c,v 1.51 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -61,11 +61,11 @@ int main (int argc, char **argv)
 
 	struct PSBASEMAP_CTRL *Ctrl;
 
-	void *New_Psbasemap_Ctrl (), Free_Psbasemap_Ctrl (struct PSBASEMAP_CTRL *C);
+	void *New_psbasemap_Ctrl (), Free_psbasemap_Ctrl (struct PSBASEMAP_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSBASEMAP_CTRL *)New_Psbasemap_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSBASEMAP_CTRL *)New_psbasemap_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] != '-') {
@@ -221,17 +221,17 @@ int main (int argc, char **argv)
 	
 	GMT_plotend ();
 
-	Free_Psbasemap_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psbasemap_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Psbasemap_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psbasemap_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSBASEMAP_CTRL *C;
 	
-	C = (struct PSBASEMAP_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSBASEMAP_CTRL), "New_Psbasemap_Ctrl");
+	C = (struct PSBASEMAP_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSBASEMAP_CTRL), "New_psbasemap_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
@@ -243,6 +243,6 @@ void *New_Psbasemap_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Psbasemap_Ctrl (struct PSBASEMAP_CTRL *C) {	/* Deallocate control structure */
+void Free_psbasemap_Ctrl (struct PSBASEMAP_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
