@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psclip.c,v 1.57 2009/09/10 15:13:00 remko Exp $
+ *	$Id: psclip.c,v 1.59 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -65,11 +65,11 @@ int main (int argc, char **argv)
 
 	struct PSCLIP_CTRL *Ctrl;
 
-	void *New_Psclip_Ctrl (), Free_Psclip_Ctrl (struct PSCLIP_CTRL *C);
+	void *New_psclip_Ctrl (), Free_psclip_Ctrl (struct PSCLIP_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSCLIP_CTRL *)New_Psclip_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSCLIP_CTRL *)New_psclip_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	west = east = north = south = 0.0;
 
@@ -229,7 +229,7 @@ int main (int argc, char **argv)
 
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-		Free_Psclip_Ctrl (Ctrl);	/* Deallocate control structure */
+		Free_psclip_Ctrl (Ctrl);	/* Deallocate control structure */
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
@@ -345,17 +345,17 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Psclip_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psclip_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Psclip_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psclip_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSCLIP_CTRL *C;
 	
-	C = (struct PSCLIP_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCLIP_CTRL), "New_Psclip_Ctrl");
+	C = (struct PSCLIP_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCLIP_CTRL), "New_psclip_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
@@ -364,6 +364,6 @@ void *New_Psclip_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Psclip_Ctrl (struct PSCLIP_CTRL *C) {	/* Deallocate control structure */
+void Free_psclip_Ctrl (struct PSCLIP_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
