@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscoast.c,v 1.99 2009/09/10 15:13:00 remko Exp $
+ *	$Id: pscoast.c,v 1.101 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -152,11 +152,11 @@ int main (int argc, char **argv)
 
 	void recursive_painting (int k0, int np, struct GMT_GSHHS_POL *p, int level, int start_level, struct GMT_FILL fill[]);
 	void recursive_clipping (int k0, int np, struct GMT_GSHHS_POL *p, int level, int start_level, int *n_pieces);
-	void *New_Pscoast_Ctrl (), Free_Pscoast_Ctrl (struct PSCOAST_CTRL *C);
+	void *New_pscoast_Ctrl (), Free_pscoast_Ctrl (struct PSCOAST_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSCOAST_CTRL *) New_Pscoast_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct PSCOAST_CTRL *) New_pscoast_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -633,7 +633,7 @@ int main (int argc, char **argv)
 
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 			
-			Free_Pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
+			Free_pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
 
 			GMT_end (argc, argv);
 			exit (EXIT_SUCCESS);
@@ -1007,7 +1007,7 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "Done\n");
 	
-	Free_Pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -1080,11 +1080,11 @@ BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, in
 	return (FALSE);	/* No, we do not want to use this polygon */
 }
 
-void *New_Pscoast_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pscoast_Ctrl () {	/* Allocate and initialize a new control structure */
 	int k;
 	struct PSCOAST_CTRL *C;
 
-	C = (struct PSCOAST_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCOAST_CTRL), "New_Pscoast_Ctrl");
+	C = (struct PSCOAST_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCOAST_CTRL), "New_pscoast_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 
@@ -1105,6 +1105,6 @@ void *New_Pscoast_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Pscoast_Ctrl (struct PSCOAST_CTRL *C) {	/* Deallocate control structure */
+void Free_pscoast_Ctrl (struct PSCOAST_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);
 }
