@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscontour.c,v 1.113 2009/09/09 23:27:03 guru Exp $
+ *	$Id: pscontour.c,v 1.115 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -130,11 +130,11 @@ int main(int argc, char **argv)
 
 	GMT_LONG get_triangle_crossings (double *x, double *y, double *z, int *ind, double **xc, double **yc, double **zc, GMT_LONG **v, GMT_LONG **cindex);
 	void paint_it (double x[], double y[], GMT_LONG n, double z);
-	void *New_Pscontour_Ctrl (), Free_Pscontour_Ctrl (struct PSCONTOUR_CTRL *C);
+	void *New_pscontour_Ctrl (), Free_pscontour_Ctrl (struct PSCONTOUR_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSCONTOUR_CTRL *)New_Pscontour_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSCONTOUR_CTRL *)New_pscontour_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -839,7 +839,7 @@ int main(int argc, char **argv)
 #endif
 	}
 
-	Free_Pscontour_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pscontour_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -951,10 +951,10 @@ void paint_it (double x[], double y[], GMT_LONG n, double z) {
 		ps_patch (x, y, (GMT_LONG)n, rgb, FALSE);	/* Contours drawn separately later if desired */
 }
 
-void *New_Pscontour_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pscontour_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSCONTOUR_CTRL *C;
 	
-	C = (struct PSCONTOUR_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_CTRL), "New_Pscontour_Ctrl");
+	C = (struct PSCONTOUR_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_CTRL), "New_pscontour_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	GMT_contlabel_init (&C->contour, 1);
@@ -967,7 +967,7 @@ void *New_Pscontour_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Pscontour_Ctrl (struct PSCONTOUR_CTRL *C) {	/* Deallocate control structure */
+void Free_pscontour_Ctrl (struct PSCONTOUR_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	if (C->D.file) free ((void *)C->D.file);	
 	if (C->T.file) free ((void *)C->T.file);	
