@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c,v 1.65 2009/01/09 04:02:34 guru Exp $
+ *	$Id: pshistogram.c,v 1.71 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ struct PSHISTOGRAM_CTRL {
 	} G;
 	struct I {	/* -I[o] */
 		BOOLEAN active;
-		int mode;
+		GMT_LONG mode;
 	} I;
 	struct L {	/* -L<pen> */
 		BOOLEAN active;
@@ -70,7 +70,7 @@ struct PSHISTOGRAM_CTRL {
 	} S;
 	struct T {	/* -T<col> */
 		BOOLEAN active;
-		int col;
+		GMT_LONG col;
 	} T;
 	struct W {	/* -W<width> */
 		BOOLEAN active;
@@ -78,7 +78,7 @@ struct PSHISTOGRAM_CTRL {
 	} W;
 	struct Z {	/* -Z<type> */
 		BOOLEAN active;
-		int mode;
+		GMT_LONG mode;
 	} Z;
 };
 
@@ -91,24 +91,23 @@ struct PSHISTOGRAM_CTRL {
 
 struct PSHISTOGRAM_INFO {	/* Control structure for pshistogram */
 	double	yy0, yy1;
-	int	*boxh;
-	int	n_boxes;
+	GMT_LONG	*boxh;
+	GMT_LONG	n_boxes;
 	GMT_LONG	n_counted;
 	double	box_width;
 	double	west, east, south, north;
-	int	center_box, cumulative;
-	int	hist_type;
+	GMT_LONG	center_box, cumulative;
+	GMT_LONG	hist_type;
 };
 
 int main (int argc, char **argv)
 {
 	BOOLEAN error = FALSE, automatic = FALSE;
 
-	char buffer[BUFSIZ], format[BUFSIZ];
+	char buffer[BUFSIZ], format[BUFSIZ], *not_used = NULL;
 	
 	GMT_LONG i, n_alloc = GMT_CHUNK, n;
-	
-	int n_expected_fields, n_fields;
+	GMT_LONG n_expected_fields, n_fields;
 	
 	double	*data, stats[6];
 
@@ -119,14 +118,14 @@ int main (int argc, char **argv)
 	struct PSHISTOGRAM_INFO F;
 	struct PSHISTOGRAM_CTRL *Ctrl;
 	
-	int fill_boxes (struct PSHISTOGRAM_INFO *F, double *x, GMT_LONG n);
-	int plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to_y, BOOLEAN draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, BOOLEAN cpt);
-	int get_loc_scl (double *x, GMT_LONG n, double *stats);
-	void *New_Pshistogram_Ctrl (), Free_Pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C);
+	GMT_LONG fill_boxes (struct PSHISTOGRAM_INFO *F, double *x, GMT_LONG n);
+	GMT_LONG plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to_y, BOOLEAN draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, BOOLEAN cpt);
+	GMT_LONG get_loc_scl (double *x, GMT_LONG n, double *stats);
+	void *New_pshistogram_Ctrl (), Free_pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSHISTOGRAM_CTRL *)New_Pshistogram_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSHISTOGRAM_CTRL *)New_pshistogram_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&F, 0, sizeof (struct PSHISTOGRAM_INFO));
 	F.hist_type = PSHISTOGRAM_COUNTS;
@@ -319,12 +318,12 @@ int main (int argc, char **argv)
 		error++;
 	}
         if (GMT_io.binary[GMT_IN] && Ctrl->T.col >= GMT_io.ncol[GMT_IN]) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Chosen column (%d) exceeds the columns (%d) in binary input data (-bi)\n", \
+                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Chosen column (%ld) exceeds the columns (%ld) in binary input data (-bi)\n", \
 		GMT_program, Ctrl->T.col+1, GMT_io.ncol[GMT_IN]);
 		error++;
 	}
         if (Ctrl->T.col < 0) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Chosen column (%d) must be >= 0\n", GMT_program, Ctrl->T.col);
+                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Chosen column (%ld) must be >= 0\n", GMT_program, Ctrl->T.col);
 		error++;
 	}
 
@@ -332,7 +331,7 @@ int main (int argc, char **argv)
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 	F.hist_type = Ctrl->Z.mode;
@@ -359,16 +358,16 @@ int main (int argc, char **argv)
 	x_min = DBL_MAX;	x_max = -DBL_MAX;
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
 
-	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp_in);
+	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (buffer, BUFSIZ, fp_in);
 
 	while ((n_fields = GMT_input (fp_in, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields, 2, n);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%d) fields near line %ld\n", GMT_program, n_fields, 2, n);
 			exit (EXIT_FAILURE);
 		}
 		if (Ctrl->T.col >= n_fields) {
-			fprintf (stderr, "%s: Expected at least %d fields but only found %d near line %ld\n", GMT_program, Ctrl->T.col+1, n_fields, n);
+			fprintf (stderr, "%s: Expected at least %ld fields but only found %ld near line %ld\n", GMT_program, Ctrl->T.col+1, n_fields, n);
 			exit (EXIT_FAILURE);
 		}
 		data[n] = in[Ctrl->T.col];
@@ -430,7 +429,7 @@ int main (int argc, char **argv)
 
 	if (Ctrl->I.active) {	/* Only info requested, quit before plotting */
 		if (Ctrl->I.mode) {
-			int ibox;
+			GMT_LONG ibox;
 			double xx, yy;
 			sprintf (format, "%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 			for (ibox = 0; ibox < F.n_boxes; ibox++) {
@@ -521,19 +520,19 @@ int main (int argc, char **argv)
 	GMT_free ((void *) data);
 	GMT_free ((void *) F.boxh);
 
-	Free_Pshistogram_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pshistogram_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-int fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
+GMT_LONG fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 
 	double	add_half = 0.0;
 	GMT_LONG	b0, b1, i, ibox, count_sum;
 
-	F->n_boxes = (int)ceil( (F->east - F->west) / F->box_width);
+	F->n_boxes = (GMT_LONG)ceil( (F->east - F->west) / F->box_width);
 
 	if (F->center_box) {
 		F->n_boxes++;
@@ -542,14 +541,14 @@ int fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 
 	if (F->n_boxes <= 0) return (-1);
 
-	F->boxh = (int *) GMT_memory (VNULL, (size_t)F->n_boxes , sizeof (int), GMT_program);
+	F->boxh = (GMT_LONG *) GMT_memory (VNULL, (size_t)F->n_boxes , sizeof (GMT_LONG), GMT_program);
 
 	F->n_counted = 0;
 
 	/* First fill boxes with counts  */
 
 	for (i = 0; i < n; i++) {
-		ibox = (int)floor( ( (data[i] - F->west) / F->box_width) + add_half);
+		ibox = (GMT_LONG)floor( ( (data[i] - F->west) / F->box_width) + add_half);
 		if (ibox < 0 || ibox >= F->n_boxes) continue;
 		F->boxh[ibox] ++;
 		F->n_counted++;
@@ -559,7 +558,7 @@ int fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 		count_sum = 0;
 		for (ibox = 0; ibox < F->n_boxes; ibox++) {
 			count_sum += F->boxh[ibox];
-			F->boxh[ibox] = count_sum;
+			F->boxh[ibox] = (GMT_LONG)count_sum;
 		}
 		b0 = 0;
 		b1 = count_sum;
@@ -587,10 +586,10 @@ int fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 		else if (F->hist_type == PSHISTOGRAM_LOG10_FREQ_PCT)
 			F->yy0 = d_log101p( 100.0 * b0 / F->n_counted );
 		else
-			F->yy0 = b0;
+			F->yy0 = (double)b0;
 	}
 	else {
-		F->yy0 = 0;
+		F->yy0 = 0.0;
 	}
 	if (b1) {
 		if (F->hist_type == PSHISTOGRAM_LOG_COUNTS)
@@ -604,17 +603,18 @@ int fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 		else if (F->hist_type == PSHISTOGRAM_LOG10_FREQ_PCT)
 			F->yy1 = d_log101p( 100.0 * b1 / F->n_counted );
 		else
-			F->yy1 = b1;
+			F->yy1 = (double)b1;
 	}
 	else {
-		F->yy1 = 0;
+		F->yy1 = 0.0;
 	}
 	return (0);
 }
 
-int plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to_y, BOOLEAN draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, BOOLEAN cpt)
+GMT_LONG plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to_y, BOOLEAN draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, BOOLEAN cpt)
 {
-	int	i, ibox, first = TRUE, index, rgb[3];
+	GMT_LONG	i, ibox, first = TRUE, index;
+	int rgb[3];
 	double	x[4], y[4], xx, yy, xval, *px, *py;
 	struct GMT_FILL *f;
 
@@ -685,12 +685,12 @@ int plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to_y, B
 	return (0);
 }
 
-int get_loc_scl (double *data, GMT_LONG n, double *stats)
+GMT_LONG get_loc_scl (double *data, GMT_LONG n, double *stats)
 {
 	/* Returns stats[] = L2, L1, LMS location, L2, L1, LMS scale  */
 
 	GMT_LONG	i, j;
-	int n_multiples;
+	GMT_LONG n_multiples;
 	double	dx;
 
 	if (n < 3) return (-1);
@@ -704,7 +704,7 @@ int get_loc_scl (double *data, GMT_LONG n, double *stats)
 	/* Get mode */
 
 	GMT_mode (data, n, j, 0, 0, &n_multiples, &stats[2]);
-	if (n_multiples > 0 && gmtdefs.verbose) fprintf (stderr, "%s: WARNING: %d multiple modes found\n", GMT_program, n_multiples);
+	if (n_multiples > 0 && gmtdefs.verbose) fprintf (stderr, "%s: WARNING: %ld multiple modes found\n", GMT_program, n_multiples);
 
 	/* Get MAD for L1 */
 
@@ -728,10 +728,10 @@ int get_loc_scl (double *data, GMT_LONG n, double *stats)
 	return (0);
 }
 	
-void *New_Pshistogram_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pshistogram_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSHISTOGRAM_CTRL *C;
 	
-	C = (struct PSHISTOGRAM_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSHISTOGRAM_CTRL), "New_Pshistogram_Ctrl");
+	C = (struct PSHISTOGRAM_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSHISTOGRAM_CTRL), "New_pshistogram_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
@@ -742,7 +742,7 @@ void *New_Pshistogram_Ctrl () {	/* Allocate and initialize a new control structu
 	return ((void *)C);
 }
 
-void Free_Pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C) {	/* Deallocate control structure */
+void Free_pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	GMT_free ((void *)C);	
 }
