@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pslegend.c,v 1.115 2009/09/09 23:27:03 guru Exp $
+ *	$Id: pslegend.c,v 1.118 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -89,7 +89,7 @@ int main (int argc, char **argv)
 	
 	FILE *fp = NULL, *fpo;
 	
-	void *New_Pslegend_Ctrl (), Free_Pslegend_Ctrl (struct PSLEGEND_CTRL *C);
+	void *New_pslegend_Ctrl (), Free_pslegend_Ctrl (struct PSLEGEND_CTRL *C);
 
 	/* Define the fraction of the height of the font to the font size */
 #define FONT_HEIGHT1 (GMT_font[gmtdefs.annot_font[0]].height)
@@ -112,7 +112,7 @@ int main (int argc, char **argv)
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSLEGEND_CTRL *)New_Pslegend_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSLEGEND_CTRL *)New_pslegend_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -490,7 +490,7 @@ int main (int argc, char **argv)
 					else
 						sprintf (sub, "%s%s", symbol, size);
 					if (symbol[0] == 'E' || symbol[0] == 'e') {	/* Ellipse needs more arguments */
-						x = 0.5 * GMT_convert_units (size, gmtdefs.measure_unit);
+						x = GMT_convert_units (size, gmtdefs.measure_unit);
 						sprintf (sarg, "%g %g 0 %g %g", x_off + off_ss, y0, x, 0.65*x);
 					}
 					else if (symbol[0] == 'V' || symbol[0] == 'v') {	/* Vector also need more args */
@@ -633,17 +633,17 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done\n", GMT_program);
 
-	Free_Pslegend_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pslegend_Ctrl (Ctrl);	/* Deallocate control structure */
 
  	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Pslegend_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pslegend_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSLEGEND_CTRL *C;
 	
-	C = (struct PSLEGEND_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSLEGEND_CTRL), "New_Pslegend_Ctrl");
+	C = (struct PSLEGEND_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSLEGEND_CTRL), "New_pslegend_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -653,7 +653,7 @@ void *New_Pslegend_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Pslegend_Ctrl (struct PSLEGEND_CTRL *C) {	/* Deallocate control structure */
+void Free_pslegend_Ctrl (struct PSLEGEND_CTRL *C) {	/* Deallocate control structure */
 	if (C->S.file) free ((void *)C->S.file);	
 	GMT_free ((void *)C);	
 }
