@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psmask.c,v 1.82 2009/09/09 23:27:03 guru Exp $
+ *	$Id: psmask.c,v 1.84 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -110,11 +110,11 @@ int main (int argc, char **argv)
 	void dump_clip_contours (struct PSMASK_INFO *info, double *xx, double *yy, GMT_LONG nn, GMT_LONG id, char *file);
 	void shrink_clip_contours (double *x, double *y, GMT_LONG n, double w, double e);
 	GMT_LONG clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *h, double xinc2, double yinc2, GMT_LONG *edge, GMT_LONG first, double **x, double **y, GMT_LONG *max);
-	void *New_Psmask_Ctrl (), Free_Psmask_Ctrl (struct PSMASK_CTRL *C);
+	void *New_psmask_Ctrl (), Free_psmask_Ctrl (struct PSMASK_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSMASK_CTRL *)New_Psmask_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSMASK_CTRL *)New_psmask_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&info, 0, sizeof (struct PSMASK_INFO));
 	info.first_dump = TRUE;
@@ -556,7 +556,7 @@ int main (int argc, char **argv)
 
 	GMT_plotend ();
 
-	Free_Psmask_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psmask_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -849,10 +849,10 @@ void shrink_clip_contours (double *x, double *y, GMT_LONG n, double w, double e)
 	}
 }
 
-void *New_Psmask_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psmask_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSMASK_CTRL *C;
 	
-	C = (struct PSMASK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSMASK_CTRL), "New_Psmask_Ctrl");
+	C = (struct PSMASK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSMASK_CTRL), "New_psmask_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 		
@@ -862,7 +862,7 @@ void *New_Psmask_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Psmask_Ctrl (struct PSMASK_CTRL *C) {	/* Deallocate control structure */
+void Free_psmask_Ctrl (struct PSMASK_CTRL *C) {	/* Deallocate control structure */
 	if (C->D.file) free ((void *)C->D.file);	
 	GMT_free ((void *)C);	
 }
