@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psrose.c,v 1.76 2009/09/09 23:27:03 guru Exp $
+ *	$Id: psrose.c,v 1.79 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -120,11 +120,11 @@ int main (int argc, char **argv)
 
 	void plot3d (double x, double y, GMT_LONG pen);
 	void arc3d (double x, double y, double r, double a1, double a2, GMT_LONG status);
-	void *New_Psrose_Ctrl (), Free_Psrose_Ctrl (struct PSROSE_CTRL *C);
+	void *New_psrose_Ctrl (), Free_psrose_Ctrl (struct PSROSE_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSROSE_CTRL *) New_Psrose_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSROSE_CTRL *) New_psrose_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	asize = gmtdefs.annot_font_size[0] * GMT_u2u[GMT_PT][GMT_INCH];
 	lsize = gmtdefs.annot_font_size[0] * GMT_u2u[GMT_PT][GMT_INCH];
@@ -503,11 +503,11 @@ int main (int argc, char **argv)
 
 	if (frame_info.plot && GMT_IS_ZERO (frame_info.axis[1].item[GMT_ANNOT_UPPER].interval)) frame_info.axis[1].item[GMT_ANNOT_UPPER].interval = frame_info.axis[1].item[GMT_GRID_UPPER].interval = 30.0;
 
-	/* Ready to plot */
+	/* Ready to plot.  So set up GMT projections (not used by psrose), we set region to actual plot width and scale to 1 */
 
 	project_info.projection = GMT_LINEAR;
 	project_info.region = TRUE;
-	project_info.pars[0] = project_info.pars[1] = (Ctrl->S.normalize) ? 1.0 : Ctrl->S.scale / max_radius;
+	project_info.pars[0] = project_info.pars[1] = 1.0;
 	GMT_err_fail (GMT_map_setup (-Ctrl->S.scale, Ctrl->S.scale, -Ctrl->S.scale, Ctrl->S.scale), "");
 
 	GMT_plotinit (argc, argv);
@@ -715,7 +715,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)mode_length);
 	GMT_free ((void *)mode_direction);
 
-	Free_Psrose_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psrose_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -744,10 +744,10 @@ void plot3d (double x, double y, GMT_LONG pen)
 	ps_plot (x, y, pen);
 }
 
-void *New_Psrose_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psrose_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSROSE_CTRL *C;
 	
-	C = (struct PSROSE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSROSE_CTRL), "New_Psrose_Ctrl");
+	C = (struct PSROSE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSROSE_CTRL), "New_psrose_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
@@ -769,7 +769,7 @@ void *New_Psrose_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Psrose_Ctrl (struct PSROSE_CTRL *C) {	/* Deallocate control structure */
+void Free_psrose_Ctrl (struct PSROSE_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	GMT_free ((void *)C);	
 }
