@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pstext.c,v 1.97 2009/09/09 23:27:03 guru Exp $
+ *	$Id: pstext.c,v 1.99 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -125,12 +125,12 @@ int main(int argc, char **argv)
 	struct PSTEXT_CTRL *Ctrl;
 
 	void GMT_putwords (double x, double y, char **text, GMT_LONG n_words, struct PSTEXT_INFO *info);
-	void *New_Pstext_Ctrl (), Free_Pstext_Ctrl (struct PSTEXT_CTRL *C);
+	void *New_pstext_Ctrl (), Free_pstext_Ctrl (struct PSTEXT_CTRL *C);
 	void load_parameters (struct PSTEXT_INFO *T, struct PSTEXT_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSTEXT_CTRL *)New_Pstext_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSTEXT_CTRL *)New_pstext_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&T, 0, sizeof (struct PSTEXT_INFO));
 
@@ -688,7 +688,7 @@ int main(int argc, char **argv)
 
 	GMT_free ((void *)use_font);
 
-	Free_Pstext_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pstext_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -756,10 +756,10 @@ void load_parameters (struct PSTEXT_INFO *T, struct PSTEXT_CTRL *C) {
 
 }
 
-void *New_Pstext_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pstext_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSTEXT_CTRL *C;
 	
-	C = (struct PSTEXT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSTEXT_CTRL), "New_Pstext_Ctrl");
+	C = (struct PSTEXT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSTEXT_CTRL), "New_pstext_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 		
@@ -777,6 +777,6 @@ void *New_Pstext_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Pstext_Ctrl (struct PSTEXT_CTRL *C) {	/* Deallocate control structure */
+void Free_pstext_Ctrl (struct PSTEXT_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
