@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pswiggle.c,v 1.67 2009/09/16 01:30:12 guru Exp $
+ *	$Id: pswiggle.c,v 1.69 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -103,11 +103,11 @@ int main (int argc, char **argv)
 
 	void GMT_draw_z_scale (double x0, double y0, double length, double zscale, BOOLEAN gave_xy, char *units);
 	void plot_wiggle (double *x, double *y, double *z, GMT_LONG np, double zscale, double start_az, double stop_az, BOOLEAN fixed, double fix_az, struct GMT_FILL *fill, struct GMT_PEN *pen_o, struct GMT_PEN *pen_t, BOOLEAN paint_wiggle, BOOLEAN negative, BOOLEAN outline, BOOLEAN track);
-	void *New_Pswiggle_Ctrl (), Free_Pswiggle_Ctrl (struct PSWIGGLE_CTRL *C);
+	void *New_pswiggle_Ctrl (), Free_pswiggle_Ctrl (struct PSWIGGLE_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSWIGGLE_CTRL *)New_Pswiggle_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSWIGGLE_CTRL *)New_pswiggle_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -491,7 +491,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)yy);
 	GMT_free ((void *)zz);
 
-	Free_Pswiggle_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pswiggle_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -599,10 +599,10 @@ void GMT_draw_z_scale (double x0, double y0, double length, double zscale, BOOLE
 	GMT_text3D (x0 + off, y0, project_info.z_level, gmtdefs.annot_font_size[0], gmtdefs.annot_font[0], txt, 0.0, 5, 0);
 }
 
-void *New_Pswiggle_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pswiggle_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSWIGGLE_CTRL *C;
 	
-	C = (struct PSWIGGLE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSWIGGLE_CTRL), "New_Pswiggle_Ctrl");
+	C = (struct PSWIGGLE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSWIGGLE_CTRL), "New_pswiggle_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->D.value = DBL_MAX;
@@ -615,7 +615,7 @@ void *New_Pswiggle_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Pswiggle_Ctrl (struct PSWIGGLE_CTRL *C) {	/* Deallocate control structure */
+void Free_pswiggle_Ctrl (struct PSWIGGLE_CTRL *C) {	/* Deallocate control structure */
 	if (C->S.label) free ((void *)C->S.label);	
 	GMT_free ((void *)C);	
 }
