@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psxy.c,v 1.178 2009/09/20 01:28:27 guru Exp $
+ *	$Id: psxy.c,v 1.186 2010/01/13 02:26:09 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -111,11 +111,11 @@ int main (int argc, char **argv)
 	void plot_y_errorbar (double x, double y, double delta_y, double error_width2, GMT_LONG line);
 	void plot_x_whiskerbar (double x, double y, double hinge[], double error_width2, int rgb[], GMT_LONG line, GMT_LONG notched);
 	void plot_y_whiskerbar (double x, double y, double hinge[], double error_width2, int rgb[], GMT_LONG line, GMT_LONG notched);
-	void *New_Psxy_Ctrl (), Free_Psxy_Ctrl (struct PSXY_CTRL *C);
+	void *New_psxy_Ctrl (), Free_psxy_Ctrl (struct PSXY_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSXY_CTRL *)New_Psxy_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSXY_CTRL *)New_psxy_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	xy_errors[GMT_X] = xy_errors[1] = 0;	/* These will be col # of where to find this info in data */
 
@@ -313,7 +313,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('P');
 		fprintf (stderr, "\t-S to select symbol type and symbol size (in %s).  Choose between\n", GMT_unit_names[gmtdefs.measure_unit]);
 		fprintf (stderr, "\t   -(xdash), +(plus), st(a)r, (b|B)ar, (c)ircle, (d)iamond, (e)llipse, (f)ront, octa(g)on, (h)exagon, (i)nvtriangle,\n");
-		fprintf (stderr, "\t   (j)rotated rectangle, (k)ustom, (l)etter, pe(n)tagon, (p)oint, (q)uoted line, (r)ect, (s)quare,\n");
+		fprintf (stderr, "\t   (j)rotated rectangle, (k)ustom, (l)etter, (m)athangle, pe(n)tagon, (p)oint, (q)uoted line, (r)ect, (s)quare,\n");
 		fprintf (stderr, "\t   (t)riangle, (v)ector, (w)edge, (x)cross, (y)dash\n");
 		fprintf (stderr, "\t   If no size is specified, psxy expects the 3rd column to have sizes.\n");
 		fprintf (stderr, "\t   If no symbol is specified, psxy expects the last column to have symbol code.\n");
@@ -322,8 +322,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Bars: Append b<base> to give the y-value of the base [Default = 0]\n");
 		fprintf (stderr, "\t      Append u if width is in x-input units [Default is %s]\n", GMT_unit_names[gmtdefs.measure_unit]);
 		fprintf (stderr, "\t      Use upper case -SB for horizontal bars (base then refers to x and width may be in y-units [Default is vertical]\n");
-		fprintf (stderr, "\t   Ellipses: the direction, semi-major, and semi-minor axis must be in input columns 3, 4 and 5.\n");
-		fprintf (stderr, "\t     If -SE rather than -Se is selected, psxy will expect azimuth, and semi-axes in km\n");
+		fprintf (stderr, "\t   Ellipses: the direction, major, and minor axis must be in input columns 3, 4 and 5.\n");
+		fprintf (stderr, "\t     If -SE rather than -Se is selected, psxy will expect azimuth, and axes in km\n");
 		fprintf (stderr, "\t     and convert azimuths based on the chosen map projection.  If projection is linear then\n");
 		fprintf (stderr, "\t     we scale the minor/major axes by the map scale.\n");
 		fprintf (stderr, "\t   Rotatable Rectangle: Direction, x-dimension, and y-dimension are expected in columns 3, 4, and 5.\n");
@@ -343,6 +343,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t     the current directory, in $GMT_USERDIR, or in $GMT_SHAREDIR (in that order).\n");
 		GMT_list_custom_symbols ();
 		fprintf (stderr, "\t   Letter: append /<string> after symbol size, and optionally %%<font>\n");
+		fprintf (stderr, "\t   Mathangle: the start and stop directions of the math angle must be in input columns 3, 4.\n");
+		fprintf (stderr, "\t     Use -Smf for arrow at first angle, -Sml for last angle, -Smb for both [none].\n");
 		fprintf (stderr, "\t   Quoted line: Give [d|f|n|l|x]<info>[:<labelinfo>]\n");
 		fprintf (stderr, "\t     <code><info> controls placement of labels along lines.  Choose among five algorithms:\n");
 		GMT_cont_syntax (7, 1);
@@ -669,7 +671,7 @@ int main (int argc, char **argv)
 					dir1 = 90.0 - in[two+S.read_size];
 					dir2 = 90.0 - in[three+S.read_size];
 				}
-				else if (S.symbol == GMT_SYMBOL_PIE) {
+				else if (S.symbol == GMT_SYMBOL_PIE || S.symbol == GMT_SYMBOL_MANGLE) {
 					dir1 = in[two+S.read_size];
 					dir2 = in[three+S.read_size];
 				}
@@ -797,6 +799,10 @@ int main (int argc, char **argv)
 						size = (S.equal_area) ? 1.09963611079 * S.size_x : S.size_x;
 						GMT_hexagon (plot_x, plot_y, 0.0, &size, &current_fill, outline_active);
 						break;
+					case GMT_SYMBOL_MANGLE:
+						dim[0] = S.size_x2; dim[1] = dir1; dim[2] = dir2;
+						GMT_matharc (plot_x, plot_y, 0.0, dim, gmtdefs.vector_shape, &current_pen, S.v_double_heads);
+						break;
 					case GMT_SYMBOL_PENTAGON:
 						size = (S.equal_area) ? 1.14948092619 * S.size_x : S.size_x;
 						GMT_pentagon (plot_x, plot_y, 0.0, &size, &current_fill, outline_active);
@@ -1042,7 +1048,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *)yy);
 	}
 
-	Free_Psxy_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psxy_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -1051,42 +1057,46 @@ int main (int argc, char **argv)
 
 void plot_x_errorbar (double x, double y, double delta_x, double error_width2, GMT_LONG line) {
 	double x_1, x_2, y_1, y_2;
+	BOOLEAN tip1, tip2;
 
+	tip1 = tip2 = (error_width2 > 0.0);
 	GMT_geo_to_xy (x - delta_x, y, &x_1, &y_1);
 	GMT_geo_to_xy (x + delta_x, y, &x_2, &y_2);
 	if (GMT_is_dnan (x_1)) {
 		fprintf (stderr, "%s: Warning: X error bar exceeded domain near line %ld. Set to x_min\n", GMT_program, line);
 		x_1 = project_info.xmin;
+		tip1 = FALSE;
 	}
 	if (GMT_is_dnan (x_2)) {
 		fprintf (stderr, "%s: Warning: X error bar exceeded domain near line %ld. Set to x_max\n", GMT_program, line);
 		x_2 = project_info.xmax;
+		tip2 = FALSE;
 	}
 	ps_segment (x_1, y_1, x_2, y_2);
-	if (error_width2 > 0.0) {
-		ps_segment (x_1, y_1 - error_width2, x_1, y_1 + error_width2);
-		ps_segment (x_2, y_2 - error_width2, x_2, y_2 + error_width2);
-	}
+	if (tip1) ps_segment (x_1, y_1 - error_width2, x_1, y_1 + error_width2);
+	if (tip2) ps_segment (x_2, y_2 - error_width2, x_2, y_2 + error_width2);
 }
 
 void plot_y_errorbar (double x, double y, double delta_y, double error_width2, GMT_LONG line) {
 	double x_1, x_2, y_1, y_2;
+	BOOLEAN tip1, tip2;
 
+	tip1 = tip2 = (error_width2 > 0.0);
 	GMT_geo_to_xy (x, y - delta_y, &x_1, &y_1);
 	GMT_geo_to_xy (x, y + delta_y, &x_2, &y_2);
 	if (GMT_is_dnan (y_1)) {
 		fprintf (stderr, "%s: Warning: Y error bar exceeded domain near line %ld. Set to y_min\n", GMT_program, line);
 		y_1 = project_info.ymin;
+		tip1 = FALSE;
 	}
 	if (GMT_is_dnan (y_2)) {
 		fprintf (stderr, "%s: Warning: Y error bar exceeded domain near line %ld. Set to y_max\n", GMT_program, line);
 		y_2 = project_info.ymax;
+		tip2 = FALSE;
 	}
 	ps_segment (x_1, y_1, x_2, y_2);
-	if (error_width2 > 0.0) {
-		ps_segment (x_1 - error_width2, y_1, x_1 + error_width2, y_1);
-		ps_segment (x_2 - error_width2, y_2, x_2 + error_width2, y_2);
-	}
+	if (tip1) ps_segment (x_1 - error_width2, y_1, x_1 + error_width2, y_1);
+	if (tip2) ps_segment (x_2 - error_width2, y_2, x_2 + error_width2, y_2);
 }
 
 void plot_x_whiskerbar (double x, double y, double hinge[], double error_width2, int rgb[], GMT_LONG line, GMT_LONG kind) {
@@ -1173,10 +1183,10 @@ void plot_y_whiskerbar (double x, double y, double hinge[], double error_width2,
 	}
 }
 
-void *New_Psxy_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psxy_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSXY_CTRL *C;
 	
-	C = (struct PSXY_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSXY_CTRL), "New_Psxy_Ctrl");
+	C = (struct PSXY_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSXY_CTRL), "New_psxy_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 		
@@ -1188,7 +1198,7 @@ void *New_Psxy_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Psxy_Ctrl (struct PSXY_CTRL *C) {	/* Deallocate control structure */
+void Free_psxy_Ctrl (struct PSXY_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	GMT_free ((void *)C);	
 }
