@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: psxyz.c,v 1.137 2009/01/11 18:09:20 remko Exp $
+ *	$Id: psxyz.c,v 1.169 2010/01/13 02:26:09 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ struct PSXYZ_CTRL {
 	} S;
 	struct W {	/* -W<pen> */
 		BOOLEAN active;
-		int mode;	/* 0 = normal, 1 = -C applies to pen color only, 2 = -C applies to symbol fill & pen color */
+		GMT_LONG mode;	/* 0 = normal, 1 = -C applies to pen color only, 2 = -C applies to symbol fill & pen color */
 		struct GMT_PEN pen;
 	} W;
 	struct Z {	/* -Z<z_level> */
@@ -85,7 +85,7 @@ struct PSXYZ_CTRL {
 
 struct PSXYZ_DATA1 {
 	char *string;
-	int symbol, flag;
+	GMT_LONG symbol, flag;
 	float x_size, y_size, z_size;
 	double lon, lat;
 	double x, y, z, value, dist;
@@ -104,37 +104,37 @@ int main (int argc, char **argv)
 	BOOLEAN	get_rgb = FALSE, read_symbol, clip_set = FALSE, fill_active, bar_clip;
 	BOOLEAN default_outline = FALSE, outline_active;
 
-	char line[BUFSIZ], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], txt_c[GMT_LONG_TEXT];
+	char line[BUFSIZ], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], txt_c[GMT_LONG_TEXT], *not_used = NULL;
 
-	GMT_LONG	i, n, n_alloc = GMT_CHUNK, n_total_read = 0;
+	GMT_LONG i, n, n_alloc = 0, n_total_read = 0, j, n_files = 0;
+	GMT_LONG fno, n_cols_start = 3, n_args, n_fields, this_outline;
+	GMT_LONG three, four, five, n_required = 3, n_expected = 0, change;
 	
-	int 	j, n_files = 0, fno, rgb[9], n_cols_start = 3, n_fields;
-	int	n_args, three, four, five, n_required = 3;
-	int	n_expected = 0, this_outline, change;
+	int rgb[9];
 
 	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, dim[3], DX, DY;
 	double lux[3], tmp, *in, x_1, x_2, y_1, y_2, xxx, yyy, font_size;
-	double x2, y2, v_w, h_l, h_w, dx, dy, xx[2], yy[2], s, c, size, *xp, *yp;
+	double x2, y2, v_w, h_l, h_w, dx, dy, xx[2], yy[2], s, c, size;
 
 	FILE *fp = NULL;
 
 	struct GMT_PEN default_pen, current_pen;
 	struct GMT_FILL default_fill, current_fill;
 	struct GMT_SYMBOL S;
-	struct PSXYZ_DATA1 *data1;
-	struct PSXYZ_DATA2 *data2;
+	struct PSXYZ_DATA1 *data1 = NULL;
+	struct PSXYZ_DATA2 *data2 = NULL;
 	struct PSXYZ_CTRL *Ctrl;
 
-	void column3D (double x, double y, double z, double base, double x_size, double y_size, int *rgb, int outline);
-	void cube3D (double x, double y, double z, double x_size, double y_size, int *rgb, int outline);
-	void barx3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, int outline);
-	void bary3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, int outline);
+	void column3D (double x, double y, double z, double base, double x_size, double y_size, int *rgb, GMT_LONG outline);
+	void cube3D (double x, double y, double z, double x_size, double y_size, int *rgb, GMT_LONG outline);
+	void barx3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, GMT_LONG outline);
+	void bary3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, GMT_LONG outline);
 	void sort_on_distance (struct PSXYZ_DATA1 *data, GMT_LONG n);
-	void *New_Psxyz_Ctrl (), Free_Psxyz_Ctrl (struct PSXYZ_CTRL *C);
+	void *New_psxyz_Ctrl (), Free_psxyz_Ctrl (struct PSXYZ_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSXYZ_CTRL *)New_Psxyz_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSXYZ_CTRL *)New_psxyz_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_3D_mode = 1;	/* Only do background axis first; do foreground at end */
 
@@ -167,6 +167,7 @@ int main (int argc, char **argv)
 				case 'H':
 				case 'J':
 				case 'K':
+				case 'M':
 				case 'O':
 				case 'P':
 				case 'R':
@@ -179,6 +180,8 @@ int main (int argc, char **argv)
 				case 'b':
 				case 'c':
 				case 'f':
+				case 'g':
+				case 'm':
 				case ':':
 				case '\0':
 					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
@@ -220,9 +223,6 @@ int main (int argc, char **argv)
 				case 'L':		/* Force closed polygons */
 					Ctrl->L.active = TRUE;
 					break;
-				case 'M':		/* Multiple line segments */
-					GMT_multisegment (&argv[i][2]);
-					break;
                                 case 'N':               /* Do not clip to map */
                                         Ctrl->N.active = TRUE;
                                         break;
@@ -262,10 +262,10 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {	/* Display usage */
 		fprintf (stderr,"psxyz %s - Plot lines, polygons, and symbols in 3-D\n\n", GMT_VERSION);
-		fprintf(stderr,"usage: psxyz <xyzfiles> %s %s [%s]\n", GMT_J_OPT, GMT_Rgeoz_OPT, GMT_B_OPT);
-		fprintf(stderr, "\t[%s] [-C<cpt>] [-D<dx>/<dy>[/<dz>]] [%s] [-G<fill>] [%s] [-I<intens>] [-K] [-L] [%s] [-N] [-O]\n", GMT_Jz_OPT, GMT_E_OPT, GMT_Ho_OPT, GMT_Mo_OPT);
-		fprintf(stderr, "\t[-P] [-Q] [-S<symbol><size>[/size_y]] [%s] [-V] [-W[+|-][<pen>]] [%s]\n", GMT_U_OPT, GMT_X_OPT);
-		fprintf(stderr, "\t[%s] [%s] [%s] [%s] [%s]\n", GMT_Y_OPT, GMT_c_OPT, GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
+		fprintf(stderr,"usage: psxyz <xyzfiles> %s %s [%s] [%s] [-C<cpt>]\n", GMT_J_OPT, GMT_Rgeoz_OPT, GMT_B_OPT, GMT_Jz_OPT);
+		fprintf(stderr, "\t[-D<dx>/<dy>[/<dz>]] [%s] [-G<fill>] [%s] [-I<intens>] [-K] [-L]\n", GMT_E_OPT, GMT_Ho_OPT);
+		fprintf(stderr, "\t[-N] [-O] [-P] [-Q] [-S<symbol><size>[/size_y]] [%s] [-V] [-W[+|-][<pen>]] [%s]\n", GMT_U_OPT, GMT_X_OPT);
+		fprintf(stderr, "\t[%s] [%s] [%s] [%s] [%s] [%s] [%s]\n", GMT_Y_OPT, GMT_c_OPT, GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT, GMT_g_OPT, GMT_mo_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -276,7 +276,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		GMT_explain_option ('b');
 		fprintf (stderr, "\t-C Use cpt-file to assign symbol colors based on t-value in 4th column (requires -S)\n");
-		fprintf (stderr, "\t   Without -S, psxyz expects -M lines/polygons and looks for -Z<tval> strings in each multiheader\n");
+		fprintf (stderr, "\t   Without -S, psxyz expects -m lines/polygons and looks for -Z<tval> strings in each multiheader\n");
 		fprintf (stderr, "\t-D Offset symbol or line positions by <dx>/<dy>[/<dy>] [no offset].\n");
 		GMT_explain_option ('E');
 		GMT_fill_syntax ('G', "Specify color or pattern [Default is no fill].");
@@ -285,15 +285,14 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-I sets a constant intensity used to modulate the fill color (requires -C or -G)\n");
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-L Force closed polygons\n");
-		GMT_explain_option ('M');
 		fprintf (stderr, "\t-N Do Not skip symbols that fall outside map border [Default will ignore those outside]\n");
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
 		fprintf (stderr, "\t-Q Do NOT sort symbols based on distance to viewer before plotting\n");
 		fprintf (stderr, "\t-S to select symbol type and symbol size (in %s).  Choose between\n", GMT_unit_names[gmtdefs.measure_unit]);
 		fprintf (stderr, "\t   -(xdash), +(plus), st(a)r, (b|B)ar, (c)ircle, (d)iamond, (e)llipse, (f)ront, octa(g)on, (h)exagon\n");
-		fprintf (stderr, "\t   (i)nvtriangle, (j)rotated rectangle, (k)ustom, (%c)etter, pe(n)tagon, c(o)lumn, (p)oint, (q)uoted line,\n", 'l');
-		fprintf (stderr, "\t   (r)ect, (s)quare, (t)riangle, c(u)be, (v)ector, (w)edge, (x)cross, (y)dash, (z)dash\n");
+		fprintf (stderr, "\t   (i)nvtriangle, (j)rotated rectangle, (k)ustom, (%c)etter, pe(n)tagon, (m)athangle, c(o)lumn, (p)oint,\n", 'l');
+		fprintf (stderr, "\t   (q)uoted line, (r)ect, (s)quare, (t)riangle, c(u)be, (v)ector, (w)edge, (x)cross, (y)dash, (z)dash\n");
 		fprintf (stderr, "\t   If no size is specified, psxyz expects the 4th column to have sizes.\n");
 		fprintf (stderr, "\t   If no symbol is specified, psxyz expects the last column to have symbol code.\n");
 		fprintf (stderr, "\t   [Note: if -C is selected then 4th means 5th column, etc.]\n");
@@ -320,9 +319,11 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t       triangle : diagonal square when centered, directed triangle otherwise.\n"); 
 		fprintf (stderr, "\t     offset = start plotting symbols when along-track distance equals offset [0].\n"); 
 		fprintf (stderr, "\t   Kustom: append <symbolname> immediately after 'k'; this will look for <symbolname>.def in\n");
-		fprintf (stderr, "\t     the current directory or in %s or in %s/custom.\n", GMT_USERDIR, GMT_SHAREDIR);
+		fprintf (stderr, "\t     the current directory, in $GMT_USERDIR, or in $GMT_SHAREDIR (in that order).\n");
 		GMT_list_custom_symbols ();
 		fprintf (stderr, "\t   Letter: append /<string> after symbol size, and optionally %%<font>\n");
+		fprintf (stderr, "\t   Mathangle: the start and stop directions of the math angle must be in input columns 4, 5.\n");
+		fprintf (stderr, "\t     Use -Smf for arrow at first angle, -Sml for last angle, -Smb for both [none].\n");
 		fprintf (stderr, "\t   Quoted line: Give [d|f|n|l|x]<info>[:<labelinfo>]. z must be constant for each segment\n");
 		fprintf (stderr, "\t     <code><info> controls the placement of labels along the lines.  Choose among five algorithms:\n");
 		GMT_cont_syntax (7, 1);
@@ -350,6 +351,8 @@ int main (int argc, char **argv)
 		GMT_explain_option ('n');
 		fprintf (stderr, "\t   Default is the required number of columns\n");
 		GMT_explain_option ('f');
+		GMT_explain_option ('g');
+		GMT_explain_option ('m');
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
@@ -370,7 +373,7 @@ int main (int argc, char **argv)
 	}
 	if (Ctrl->C.active && S.symbol == 0 && !GMT_io.multi_segments[GMT_IN]) {
 		error++;
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option: Must also specify a symbol (see -S) or give polygon file with -M\n", GMT_program);
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option: Must also specify a symbol (see -S) or give polygon file with -m\n", GMT_program);
 	}
 	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
@@ -413,13 +416,13 @@ int main (int argc, char **argv)
 	n_expected = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : n_required;
 	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN]=  n_required;
 	if (n_expected < n_required) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data must have at least %d columns\n", GMT_program, n_required);
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data must have at least %ld columns\n", GMT_program, n_required);
 		error++;
 	}
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 	if (Ctrl->C.active) GMT_read_cpt (Ctrl->C.file);
@@ -487,6 +490,7 @@ int main (int argc, char **argv)
 		GMT_xyz_to_xy (Ctrl->D.dx, Ctrl->D.dy, Ctrl->D.dz, &DX, &DY);
 		ps_transrotate (DX, DY, 0.0);	/* Shift plot a bit */
 	}
+	GMT_io.skip_if_NaN[GMT_Z] = TRUE;	/* Extend GMT NaN-handling to the z-coordinate */
 
 	done = FALSE;
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over all input files */
@@ -512,7 +516,7 @@ int main (int argc, char **argv)
 		}
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
-				GMT_fgets (line, BUFSIZ, fp);
+				not_used = GMT_fgets (line, BUFSIZ, fp);
 				if (i == 0 && S.G.label_type == 2) GMT_extract_label (&line[1], S.G.label);	/* Set initial header as potential label */
 			}
 		}
@@ -522,11 +526,10 @@ int main (int argc, char **argv)
 			GMT_world_map = (S.symbol == GMT_SYMBOL_ELLIPSE && S.convert_angles) ? FALSE : TRUE;
 			if (read_symbol) n_expected = BUFSIZ;
 
-			data1 = (struct PSXYZ_DATA1 *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (struct PSXYZ_DATA1), GMT_program);
 			n = 0;
-			while ((n_fields = GMT_input (fp, &n_expected, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
+			while ((n_fields = GMT_input (fp, &n_expected, &in)) >= 0 && !GMT_REC_IS_EOF) {
 
-				while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {	/* Skip segment headers */
+				while (GMT_REC_IS_SEG_HEADER && !GMT_REC_IS_EOF) {	/* Skip segment headers */
 					if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
 					
 					change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
@@ -539,10 +542,10 @@ int main (int argc, char **argv)
 					if (read_symbol) n_expected = BUFSIZ;
 					n_fields = GMT_input (fp, &n_expected, &in);
 				}
-				if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
+				if (GMT_REC_IS_EOF) continue;		/* At EOF */
 	
-				if (GMT_io.status & GMT_IO_MISMATCH && !read_symbol) {
-					fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields, n_expected, n_total_read);
+				if (GMT_REC_IS_ERROR && !read_symbol) {
+					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected, n_total_read);
 					exit (EXIT_FAILURE);
 				}
 				n_total_read++;
@@ -563,9 +566,10 @@ int main (int argc, char **argv)
 					S.size_y = (S.symbol == GMT_SYMBOL_COLUMN) ? in[four] * GMT_u2u[S.u][GMT_INCH] : S.size_x;
 				}
 
+				if (n == n_alloc) n_alloc = GMT_alloc_memory ((void **)&data1, n, n_alloc, sizeof (struct PSXYZ_DATA1), GMT_program);
 				data1[n].flag = 0;
-				data1[n].lon = in[0];
-				data1[n].lat = in[1];
+				data1[n].lon = in[GMT_X];
+				data1[n].lat = in[GMT_Y];
 				data1[n].string = NULL;
 				if (S.read_vector) {
 					data1[n].x_size = (float)in[three];	/* direction */
@@ -604,7 +608,7 @@ int main (int argc, char **argv)
 						data1[n].z_size *= (float)GMT_u2u[S.u][GMT_INCH];
 					}
 				}
-				else if (S.symbol == GMT_SYMBOL_PIE) {
+				else if (S.symbol == GMT_SYMBOL_PIE || S.symbol == GMT_SYMBOL_MANGLE) {
 					data1[n].x_size = (float)S.size_x;
 					if (S.convert_angles == 1) {	/* Got azimuths instead */
 						data1[n].y_size = (float)(90.0 - in[three+S.read_size]);	/* Start direction in degrees */
@@ -653,15 +657,15 @@ int main (int argc, char **argv)
 						else if (in[GMT_Y] > north)
 							in[GMT_Y] = north;
 					}
-					if (in[2] < project_info.z_bottom || in[2] > project_info.z_top) continue;
+					if (in[GMT_Z] < project_info.z_bottom || in[GMT_Z] > project_info.z_top) continue;
 				}
 				else if (!Ctrl->N.active) {
-					if (in[2] < project_info.z_bottom || in[2] > project_info.z_top) continue;
-					GMT_map_outside (in[0], in[1]);
+					if (in[GMT_Z] < project_info.z_bottom || in[GMT_Z] > project_info.z_top) continue;
+					GMT_map_outside (in[GMT_X], in[GMT_Y]);
 					if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
 				}
 
-				GMT_project3D (in[0], in[1], in[2], &data1[n].x, &data1[n].y, &data1[n].z);
+				GMT_project3D (in[GMT_X], in[GMT_Y], in[GMT_Z], &data1[n].x, &data1[n].y, &data1[n].z);
 				if (get_rgb) {	/* Lookup z to get rgb */
 					data1[n].value = in[3];
 					GMT_get_rgb_from_z (data1[n].value, current_fill.rgb);
@@ -698,15 +702,10 @@ int main (int argc, char **argv)
 				data1[n].f = current_fill;
 				data1[n].p = current_pen;
 				data1[n].outline = outline_active;
-
 				n++;
-				if (n == n_alloc) {
-					n_alloc <<= 1;
-					data1 = (struct PSXYZ_DATA1 *) GMT_memory ((void *)data1, (size_t)n_alloc, sizeof (struct PSXYZ_DATA1), GMT_program);
-				}
 				if (read_symbol) n_expected = BUFSIZ;
 			}
-			data1 = (struct PSXYZ_DATA1 *) GMT_memory ((void *)data1, (size_t)n, sizeof (struct PSXYZ_DATA1), GMT_program);
+			n_alloc = GMT_alloc_memory ((void **)&data1, 0, n, sizeof (struct PSXYZ_DATA1), GMT_program);
 	
 			/* Sort according to distance  from viewer */
 	
@@ -793,6 +792,10 @@ int main (int argc, char **argv)
 						size = (S.equal_area) ? 1.09963611079 * data1[i].x_size : data1[i].x_size;
 						GMT_hexagon (data1[i].x, data1[i].y, data1[i].z, &size, &data1[i].f, data1[i].outline);
 						break;
+					case GMT_SYMBOL_MANGLE:
+						dim[0] = 0.5 * data1[i].x_size; dim[1] = data1[i].y_size; dim[2] = data1[i].z_size;
+						GMT_matharc (data1[i].x, data1[i].y, data1[i].z, dim, gmtdefs.vector_shape,  &data1[i].p, S.v_double_heads);
+						break;
 					case GMT_SYMBOL_PENTAGON:
 						size = (S.equal_area) ? 1.14948092619 * data1[i].x_size : data1[i].x_size;
 						GMT_pentagon (data1[i].x, data1[i].y, data1[i].z, &size, &data1[i].f, data1[i].outline);
@@ -945,64 +948,63 @@ int main (int argc, char **argv)
 						break;
 				}
 			}
-			GMT_free ((void *)data1);
 		}
 		else {	/* Line/polygon part */
-			data2 = (struct PSXYZ_DATA2 *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (struct PSXYZ_DATA2), GMT_program);
 			n_required = 3;
 			n_fields = GMT_input (fp, &n_expected, &in);
-			while (! (GMT_io.status & GMT_IO_EOF)) {
-
-				while (GMT_io.status & GMT_IO_SEGMENT_HEADER) {
-					if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
+			while (!GMT_REC_IS_EOF) {
+				while (GMT_REC_IS_NEW_SEGMENT) {	/* Process multisegment header flags (or NaN gaps) */
+					if (GMT_REC_IS_SEG_HEADER) {
+						if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
 					
-					change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
-					if (Ctrl->I.active) {
-						GMT_illuminate (Ctrl->I.value, current_fill.rgb);
-						GMT_illuminate (Ctrl->I.value, default_fill.rgb);
+						change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
+						if (Ctrl->I.active) {
+							GMT_illuminate (Ctrl->I.value, current_fill.rgb);
+							GMT_illuminate (Ctrl->I.value, default_fill.rgb);
+						}
+						if ((change & 4) && penset_OK) GMT_setpen (&current_pen);
+						if ((change & 1)) polygon = TRUE;
+						if ((change & 2) && !Ctrl->L.active) {
+							polygon = FALSE;
+							ps_setpaint (current_fill.rgb);
+						}
+						if (S.G.label_type == 2) {	/* Update segment header */
+							GMT_extract_label (&GMT_io.segment_header[1], S.G.label);
+						}
 					}
-					if ((change & 4) && penset_OK) GMT_setpen (&current_pen);
-					if ((change & 1)) polygon = TRUE;
-					if ((change & 2) && !Ctrl->L.active) {
-						polygon = FALSE;
-						ps_setpaint (current_fill.rgb);
-					}
-					if (S.G.label_type == 2) {	/* Update segment header */
-						GMT_extract_label (&GMT_io.segment_header[1], S.G.label);
-					}
-
 					n_fields = GMT_input (fp, &n_expected, &in);
 					n_total_read++;
 				}
-				if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
+				if (GMT_REC_IS_EOF) continue;		/* At EOF */
+				if (GMT_REC_IS_GAP) GMT_io.status = 0;	/* Done with gap */
 
 				n = 0;
-				while (! (GMT_io.status & (GMT_IO_SEGMENT_HEADER | GMT_IO_EOF))) {	/* Keep going until FALSE or = 2 segment header */
-					if (GMT_io.status & GMT_IO_MISMATCH) {
-						fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields, n_expected, n_total_read);
+				while (!GMT_REC_IS_LINE_BREAK) {	/* Keep going until FALSE or = 2 segment header or gap */
+					if (GMT_REC_IS_ERROR) {
+						fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected, n_total_read);
 						exit (EXIT_FAILURE);
 					}
 
-					data2[n].x = in[0];	data2[n].y = in[1];
-					data2[n].z = in[2];
+					if (n == n_alloc) n_alloc = GMT_alloc_memory ((void **)&data2, n, n_alloc, sizeof (struct PSXYZ_DATA2), GMT_program);
+					data2[n].x = in[GMT_X];	data2[n].y = in[GMT_Y];
+					data2[n].z = in[GMT_Z];
 					n++;
-					if (n == n_alloc) {
-						n_alloc <<= 1;
-						data2 = (struct PSXYZ_DATA2 *) GMT_memory ((void *)data2, (size_t)n_alloc, sizeof (struct PSXYZ_DATA2), GMT_program);
-					}
 					n_fields = GMT_input (fp, &n_expected, &in);
 				}
-
+				
+				/* Done reading a segment */
+				
 				if (polygon) {  /* Explicitly close polygon */
+					if (n == n_alloc) n_alloc = GMT_alloc_memory ((void **)&data2, n, n_alloc, sizeof (struct PSXYZ_DATA2), GMT_program);
 					data2[n].x = data2[0].x;
 					data2[n].y = data2[0].y;
 					data2[n].z = data2[0].z;
 					n++;
 				}
-				data2 = (struct PSXYZ_DATA2 *) GMT_memory ((void *)data2, (size_t)n, sizeof (struct PSXYZ_DATA2), GMT_program);
-				n_alloc = n;
+				n_alloc = GMT_alloc_memory ((void **)&data2, n, n_alloc, sizeof (struct PSXYZ_DATA2), GMT_program);
 		
 				if (!GMT_cpt_skip) {
+					double *xp, *yp;
 					xp = (double *) GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
 					yp = (double *) GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
 		
@@ -1020,7 +1022,7 @@ int main (int argc, char **argv)
 					}
 					else {
 						for (i = 0; i < n; i++) GMT_geoz_to_xy (data2[i].x, data2[i].y, data2[i].z, &xp[i], &yp[i]);
-						ps_line (xp, yp, n, 3, FALSE, TRUE);
+						ps_line (xp, yp, n, 3, FALSE);
 					}
 					if (S.symbol == GMT_SYMBOL_FRONT) {
 						for (i = 0; i < n; i++) GMT_geo_to_xy (data2[i].x, data2[i].y, &xp[i], &yp[i]);
@@ -1030,13 +1032,12 @@ int main (int argc, char **argv)
 					GMT_free ((void *)xp);
 					GMT_free ((void *)yp);
 				}
-				n = 0;
 			}
-			GMT_free ((void *)data2);
 		}
 		if (fp != GMT_stdin) GMT_fclose (fp);
-
 	}
+	if (data1) GMT_free ((void *)data1);
+	if (data2) GMT_free ((void *)data2);
 
 	if (S.symbol == GMT_SYMBOL_QUOTED_LINE) {
 		GMT_contlabel_plot (&S.G);
@@ -1053,16 +1054,16 @@ int main (int argc, char **argv)
 	ps_rotatetrans (z_project.xmin, z_project.ymin, 0.0);
 	GMT_plotend ();
 
-	Free_Psxyz_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psxyz_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void column3D (double x, double y, double z, double base, double x_size, double y_size, int *rgb, int outline)
+void column3D (double x, double y, double z, double base, double x_size, double y_size, int *rgb, GMT_LONG outline)
 {
-	int i, j, k;
+	GMT_LONG i, j, k;
 	double zz, xp[4], yp[4], zp[4], plot_x[4], plot_y[4], top, sign;
 
 	x_size *= 0.5;
@@ -1102,9 +1103,9 @@ void column3D (double x, double y, double z, double base, double x_size, double
 	}
 }
 
-void cube3D (double x, double y, double z, double x_size, double y_size, int *rgb, int outline)
+void cube3D (double x, double y, double z, double x_size, double y_size, int *rgb, GMT_LONG outline)
 {
-	int i, j, k;
+	GMT_LONG i, j, k;
 	double xp[4], yp[4], zp[4], plot_x[4], plot_y[4], sign;
 
 	x_size *= 0.5;
@@ -1140,9 +1141,9 @@ void cube3D (double x, double y, double z, double x_size, double y_size, int *rg
 	}
 }
 
-void bary3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, int outline)
+void bary3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, GMT_LONG outline)
 {
-	int i;
+	GMT_LONG i;
 	double xp[4], yp[4], plot_x[4], plot_y[4];
 
 	size *= 0.5;
@@ -1152,9 +1153,9 @@ void bary3D (double x, double y, double z, double base, double size, struct GMT_
 	GMT_fill (plot_x, plot_y, (GMT_LONG)4, f, outline);
 }
 
-void barx3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, int outline)
+void barx3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, GMT_LONG outline)
 {
-	int i;
+	GMT_LONG i;
 	double xp[4], yp[4], plot_x[4], plot_y[4];
 
 	size *= 0.5;
@@ -1169,58 +1170,38 @@ void sort_on_distance (struct PSXYZ_DATA1 *data, GMT_LONG n)
 	/* This function sorts the data array such that points farthest away are plotted first */
 	GMT_LONG i;
 
-	int dist_compare(const void *point_1, const void *point_2);
-	double dx, dy, x0, y0, x, y, dr, a, b, c;
+	int dist_compare(const void *a, const void *b);
 
-	x0 = 0.5 * (project_info.xmin + project_info.xmax);
-	y0 = 0.5 * (project_info.ymin + project_info.ymax);
-
-	dx = 0.5 * (project_info.xmax - project_info.xmin);
-	dy = 0.5 * (project_info.ymax - project_info.ymin);
-	dr = hypot (dx, dy);
-
-	x = x0 - dr * z_project.sin_az;
-	y = y0 - dr * z_project.cos_az;
-
-	if (z_project.cos_az == 0.0) {
-		a = 1.0;
-		b = 0.0;
-		c = x;
-	}
-	else {
-		a = -tan (z_project.view_azimuth);
-		b = -1.0;
-		c = y - x * a;
-	}
-
-	for (i = 0; i < n; i++) data[i].dist = fabs (a * data[i].x + b * data[i].y + c);
+	for (i = 0; i < n; i++) data[i].dist = - z_project.sin_az * data[i].x - z_project.cos_az * data[i].y;
 
 	qsort ((void *)data, (size_t)n, sizeof (struct PSXYZ_DATA1), dist_compare);
 }
 
-int dist_compare (const void *point_1, const void *point_2)
+int dist_compare (const void *a, const void *b)
 {
-	int first;
+	double z;
 
-	if ( ((struct PSXYZ_DATA1 *)point_1)->dist > ((struct PSXYZ_DATA1 *)point_2)->dist)
+	if ( ((struct PSXYZ_DATA1 *)a)->dist < ((struct PSXYZ_DATA1 *)b)->dist) {
 		return (-1);
-	else if ( ((struct PSXYZ_DATA1 *)point_1)->dist < ((struct PSXYZ_DATA1 *)point_2)->dist)
+	}
+	else if ( ((struct PSXYZ_DATA1 *)a)->dist > ((struct PSXYZ_DATA1 *)b)->dist) {
 		return (1);
+	}
 	else {
-		first = ( ((struct PSXYZ_DATA1 *)point_1)->z < ((struct PSXYZ_DATA1 *)point_2)->z);
-		if (first && z_project.view_elevation >= 0.0)
+		z = ( ((struct PSXYZ_DATA1 *)a)->z - ((struct PSXYZ_DATA1 *)b)->z) * z_project.sin_el;
+		if (z < 0.0)
 			return (-1);
-		else if (first && z_project.view_elevation < 0.0)
+		else if (z > 0.0)
 			return (1);
 		else
 			return (0);
 	}
 }
 
-void *New_Psxyz_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psxyz_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSXYZ_CTRL *C;
 	
-	C = (struct PSXYZ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSXYZ_CTRL), "New_Psxyz_Ctrl");
+	C = (struct PSXYZ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSXYZ_CTRL), "New_psxyz_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 		
@@ -1232,7 +1213,7 @@ void *New_Psxyz_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Psxyz_Ctrl (struct PSXYZ_CTRL *C) {	/* Deallocate control structure */
+void Free_psxyz_Ctrl (struct PSXYZ_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	GMT_free ((void *)C);	
 }
