@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sample1d.c,v 1.52 2009/09/09 23:27:04 guru Exp $
+ *	$Id: sample1d.c,v 1.57 2010/01/14 17:32:12 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,14 +31,24 @@
  
 #include "gmt.h"
 
+#define INT_1D	0	/* Regular 1-D interpolation */
+#define INT_2D	1	/* Spatial 2-D path interpolation */
+
 struct SAMPLE1D_CTRL {
+#ifdef DEBUG
+	struct A {	/* -A[m|p] */
+		int mode;
+	} A;
+#endif
 	struct F {	/* -Fl|a|c */
 		BOOLEAN active;
 		GMT_LONG mode;
 	} F;
-	struct I {	/* -I<inc> */
+	struct I {	/* -I<inc>[e|E|k|K|m|M|n|N|c|C|d|D] */
 		BOOLEAN active;
+		GMT_LONG mode;
 		double inc;
+		char unit;
 	} I;
 	struct T {	/* -T<time_col> */
 		BOOLEAN active;
@@ -63,18 +73,23 @@ int main (int argc, char **argv)
 
 	double *t_supplied_out = VNULL, *t_out, *ttime, *data, **col = VNULL, **out = VNULL;
 	double tt, low_t, high_t, *in, *dout = VNULL;
-
+#ifdef DEBUG
+	GMT_LONG proj_type = 0;
+	double d_scale;
+	PFD distance_func;
+#endif
 	char line[BUFSIZ], type[3], *not_used = NULL;
 
 	FILE *fp = NULL, *fpt = NULL;
 
+
 	struct SAMPLE1D_CTRL *Ctrl;
 
-	void *New_Sample1d_Ctrl (), Free_Sample1d_Ctrl (struct SAMPLE1D_CTRL *C);
+	void *New_sample1d_Ctrl (), Free_sample1d_Ctrl (struct SAMPLE1D_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct SAMPLE1D_CTRL *)New_Sample1d_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct SAMPLE1D_CTRL *)New_sample1d_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	type[0] = 'l';	type[1] = 'a';	type[2] = 'c';
 
@@ -118,6 +133,13 @@ int main (int argc, char **argv)
 				case 'I':
 					Ctrl->I.active = TRUE;
 					Ctrl->I.inc = atof (&argv[i][2]);
+#ifdef DEBUG
+					n = strlen (argv[i]) - 1;
+					if (strchr ("ekmnd", argv[i][n])) {
+						Ctrl->I.unit = argv[i][n];
+						Ctrl->I.mode = INT_2D;
+					}
+#endif
 					break;
 				case 'T':
 					Ctrl->T.active = TRUE;
@@ -139,8 +161,18 @@ int main (int argc, char **argv)
 					Ctrl->F.mode = 0;
 					break;
 				case 'A':
-					Ctrl->F.active = TRUE;
-					Ctrl->F.mode = 1;
+#ifdef DEBUG
+					if (argv[i][2] == 'm')
+						Ctrl->A.mode = 1;
+					else if (argv[i][2] == 'p')
+						Ctrl->A.mode = 2;
+					else {	/* Old backwards compatible -A option */
+#endif
+						Ctrl->F.active = TRUE;
+						Ctrl->F.mode = 1;
+#ifdef DEBUG
+					}
+#endif
 					break;
 				case 'C':
 					Ctrl->F.active = TRUE;
@@ -176,6 +208,12 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   [Default is -F%c]\n", type[Ctrl->F.mode]);
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I <x_inc> sets equidistant grid interval [x1 - x0]\n");
+#ifdef DEBUG
+		fprintf (stderr, "\t   Append e|k|m|n|d to indicate that the first two columns contain\n");
+		fprintf (stderr, "\t   longitude, latitude and you wish to resample this path using great\n");
+		fprintf (stderr, "\t   circle segment with a nominal spacing of <t_inc> in those units.\n");
+		fprintf (stderr, "\t   See -Am|p to only sample along meridians and parallels.\n");
+#endif
 		fprintf (stderr, "\t-N <knotfile> is an ASCII table with the desired time positions in column 0\n");
 		fprintf (stderr, "\t   Overrides the -I and -S settings.  If none of -I, -S, and -N is set\n");
 		fprintf (stderr, "\t   then <tstart> = first input point, <t_inc> = (t[1] - t[0])\n");
@@ -220,6 +258,10 @@ int main (int argc, char **argv)
 		error++;
 	}
 
+#ifdef DEBUG
+	if (Ctrl->I.mode) error += GMT_get_dist_scale (Ctrl->I.unit, &d_scale, &proj_type, &distance_func);
+	if (Ctrl->I.mode) Ctrl->I.inc /= d_scale;			/* Convert increment to spherical degrees */
+#endif
 	if (error) exit (EXIT_FAILURE);
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
@@ -348,6 +390,25 @@ int main (int argc, char **argv)
 
 			/* If we didn't get input abscissa, now's the time to generate them */
 
+#ifdef DEBUG
+			if (Ctrl->I.active && Ctrl->I.mode == INT_2D) {	/* Special spatial interpolation */
+				GMT_LONG np;
+				double *lon, *lat, xyout[2];
+				lon = (double *) GMT_memory (VNULL, n, sizeof (double), GMT_program);
+				lat = (double *) GMT_memory (VNULL, n, sizeof (double), GMT_program);
+				memcpy ((void *)lon, (void *)col[GMT_X], n*sizeof(double));
+				memcpy ((void *)lat, (void *)col[GMT_Y], n*sizeof(double));
+				np = GMT_fix_up_path (&lon, &lat, n, Ctrl->I.inc, Ctrl->A.mode);
+				for (i = 0; i < np; i++) {
+					xyout[GMT_X] = lon[i];	xyout[GMT_Y] = lat[i];
+					GMT_output (GMT_stdout, 2, xyout);
+				}
+				rows += n + 1;
+				GMT_free ((void *)lon);
+				GMT_free ((void *)lat);
+				continue;
+			}
+#endif
 			if (Ctrl->N.active) {	/* Get relevant t_out segment */
 				low_t  = MIN (col[Ctrl->T.col][0], col[Ctrl->T.col][n-1]);
 				high_t = MAX (col[Ctrl->T.col][0], col[Ctrl->T.col][n-1]);
@@ -449,17 +510,17 @@ int main (int argc, char **argv)
 	if (nan_flag) GMT_free ((void *)nan_flag);
 	if (Ctrl->N.active) GMT_free ((void *)t_supplied_out);
 	
-	Free_Sample1d_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_sample1d_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Sample1d_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_sample1d_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SAMPLE1D_CTRL *C;
 	
-	C = (struct SAMPLE1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SAMPLE1D_CTRL), "New_Sample1d_Ctrl");
+	C = (struct SAMPLE1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SAMPLE1D_CTRL), "New_sample1d_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->F.mode = gmtdefs.interpolant;
@@ -467,7 +528,7 @@ void *New_Sample1d_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Sample1d_Ctrl (struct SAMPLE1D_CTRL *C) {	/* Deallocate control structure */
+void Free_sample1d_Ctrl (struct SAMPLE1D_CTRL *C) {	/* Deallocate control structure */
 	if (C->N.file) free ((void *)C->N.file);	
 	GMT_free ((void *)C);	
 }
