@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegyz.c,v 1.32 2008/05/12 22:35:47 guru Exp $
+ *	$Id: pssegyz.c,v 1.36 2009/08/28 12:08:32 remko Exp $
  *
- *    Copyright (c) 1999-2008 by T. Henstock
+ *    Copyright (c) 1999-2009 by T. Henstock
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* pssegyz program to plot segy files in 3d in postscript with variable trace spacing option
@@ -78,7 +78,7 @@ int main (int argc, char **argv)
 	char input[512];
 	char *text;
 	char *head;
-	long *head2;
+	int head2;
 
 
 	char reelhead[3200];
@@ -109,7 +109,7 @@ int main (int argc, char **argv)
 					error += GMT_parse_common_options (argv[i], &w, &e, &s, &n);
 					break;
                                 case 'E':
-					sscanf (&argv[i][2], "%lf/%lf", &z_project.view_azimuth, &z_project.view_elevation);
+					error += GMT_get_proj3D (&argv[i][2], &z_project.view_azimuth, &z_project.view_elevation);
 					break;
 				/* parameters for wiggle mode */
 				case 'F':
@@ -243,7 +243,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "pssegyz %s - Plot a segy file in PostScript\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: pssegyz [<segyfile>] %s %s -D<dev>\n", GMT_Jx_OPT, GMT_Rx_OPT);
-		fprintf (stderr, "	[-E<az/el>] [-C<clip>] [-B<bias>] [-N] [-Z]\n");
+		fprintf (stderr, "	[%s] [-C<clip>] [-B<bias>] [-N] [-Z]\n", GMT_E_OPT);
 		fprintf (stderr, "	[-F<gray>|<r/g/b>] [-I] [-W] [-S<x>/<y>]\n");
 		fprintf (stderr, "	[-X<dx>] [-Y<dz>] [-L<nsamp>] [-M<ntraces>] \n");
 		fprintf (stderr, "	[-U<redvel>] [-A] [-O] [-K] [-P]\n");
@@ -402,19 +402,18 @@ use a few of these*/
 	while ((ix<n_traces) && (header = get_segy_header(fpi))){   /* read traces one by one */
 	/* check true location header for x */
 		if (xplot_offset){ /* plot traces by offset, cdp, or input order */
-			long offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
+			int32_t offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
 			x0 = (double) offset;
 		}
 		else if (xplot_cdp){
-			long cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
+			int32_t cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
 			x0 = (double) cdpval;
 		}
 		else if (byte_x){ /* ugly code - want to get value starting at byte_x of header into a double... */
-			long plot_loc;
 		   	head = (char *) header;
-			head2 = (long *) &(head[byte_x]);
-			plot_loc = ((swap_bytes)? GMT_swab4(*head2): *head2);
-		  	x0 = (double) plot_loc;
+			memcpy(&head2, &head[byte_x], 4); /* edited to fix bug where 8bytes were copied from head.
+                                                Caused by casting to a long directly from char array*/ 
+			x0 = (double) ((swap_bytes)? GMT_swab4(head2): head2);
 		}
 		else if (fix_x)
 			x0 /= dx;
@@ -423,19 +422,18 @@ use a few of these*/
 
 	/* now do same for y */
 		if (yplot_offset){ /* plot traces by offset, cdp, or input order */
-			long offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
+			int32_t offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
 			y0 = (double) offset;
 		}
 		else if (yplot_cdp){
-			long cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
+			int32_t cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
 			y0 = (double) cdpval;
 		}
 		else if (byte_y){
-		  	long plot_loc;
 			head =  (char *) header;
-			head2 = (long *) &(head[byte_y]);
-			plot_loc = ((swap_bytes)? GMT_swab4(*head2): *head2);
-			y0 = (double) plot_loc;
+			memcpy(&head2, &head[byte_y], 4); /* edited to fix bug where 8bytes were copied from head.
+                                                Caused by casting to a long directly from char array*/ 
+			y0 = (double) ((swap_bytes)? GMT_swab4(head2): head2);
 		}
 		else if (fix_y)
 			y0 /= dx;
