@@ -1,8 +1,9 @@
 /************************ segy_io.h *******************************/
-/*  $Id: segy_io.h,v 1.6 2002/03/17 19:58:58 pwessel Exp $  */
+/*  $Id: segy_io.h,v 1.9 2007/01/31 21:51:04 remko Exp $  */
 /* segy_io.h:	Include file for segy_io.c, a suite of functions to */
 /* help reading and writing those annoying, redundant SEGY header */
 /* variables and for reading/writing to/from SEGY files.          */
+/* From PASSCAL code base which is in the public domain		  */
 /******************************************************************/
 
 #ifndef SEGY_IO_H
@@ -16,12 +17,12 @@
 #define FALSE 0
 #endif
 
-#if defined(_WIN32) || defined(__OPENNT)
+#if defined(WIN32)
 typedef short int16_t;
 typedef int int32_t;
 typedef unsigned short uint16_t;
 typedef unsigned int uint32_t;
-#elif  !defined(_INTTYPES_H)
+#elif  !defined(_INTTYPES_H) && !defined(__OPENNT)
 #include <inttypes.h>
 #endif
 
