@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: spectrum1d.c,v 1.39 2008/03/24 08:58:32 guru Exp $
+ *	$Id: spectrum1d.c,v 1.46 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ struct SPECTRUM1D_CTRL {
 	} N;
 	struct S {	/* -S<segment_size> */
 		BOOLEAN active;
-		int size;
+		GMT_LONG size;
 	} S;
 	struct W {	/* -W */
 		BOOLEAN active;
@@ -113,9 +113,9 @@ int main (int argc, char **argv)
 {
 	BOOLEAN	error = FALSE;
 	
-	char	buffer[BUFSIZ];
+	char	buffer[BUFSIZ], *not_used = NULL;
 
-	int	i, k, j, n_expected_fields, n_fields, n_outputs, window_test = 2;
+	GMT_LONG	i, k, j, n_expected_fields, n_fields, n_outputs, window_test = 2;
 	GMT_LONG	n_alloc, n_data;
 
 	float	*x, *y = NULL;
@@ -129,13 +129,13 @@ int main (int argc, char **argv)
 
 	void alloc_arrays (struct SPECTRUM1D_INFO *C);
 	void compute_spectra (struct SPECTRUM1D_INFO *C, float *x, float *y, GMT_LONG n_data);
-	void write_output (struct SPECTRUM1D_INFO *C, char *cols, int n_outputs, BOOLEAN write_wavelength, char *namestem);
+	void write_output (struct SPECTRUM1D_INFO *C, char *cols, GMT_LONG n_outputs, BOOLEAN write_wavelength, char *namestem);
 	void free_space (struct SPECTRUM1D_INFO *C);
-	void *New_Spectrum1d_Ctrl (), Free_Spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C);
+	void *New_spectrum1d_Ctrl (), Free_spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct SPECTRUM1D_CTRL *)New_Spectrum1d_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct SPECTRUM1D_CTRL *)New_spectrum1d_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&C, 0, sizeof (struct SPECTRUM1D_INFO));
 	
@@ -241,7 +241,7 @@ int main (int argc, char **argv)
 		error++;
 	}
 	if (window_test != Ctrl->S.size) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option: Segment size not radix 2.  Try %d or %d\n", GMT_program,
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option: Segment size not radix 2.  Try %ld or %ld\n", GMT_program,
 			(window_test/2), window_test);
 		error++;
 	}
@@ -263,7 +263,7 @@ int main (int argc, char **argv)
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
+		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 	C.dt = Ctrl->D.inc;
@@ -301,17 +301,17 @@ int main (int argc, char **argv)
 	if (C.y_given) y = (float *)GMT_memory (VNULL, (size_t)n_alloc, sizeof(float), GMT_program);
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : C.y_given + 1;
 
-	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp);
+	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (buffer, BUFSIZ, fp);
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_data);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_data);
 			exit (EXIT_FAILURE);
 		}
 
-                x[n_data] = (float)in[0];
-		if (C.y_given) y[n_data] = (float)in[1];
+                x[n_data] = (float)in[GMT_X];
+		if (C.y_given) y[n_data] = (float)in[GMT_Y];
                 n_data++;
 
                 if (n_data == n_alloc) {
@@ -334,7 +334,7 @@ int main (int argc, char **argv)
 
 	free_space (&C);
 
-	Free_Spectrum1d_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_spectrum1d_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -466,7 +466,7 @@ void compute_spectra (struct SPECTRUM1D_INFO *C, float *x, float *y, GMT_LONG n_
 	}
 }
 
-void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN write_wavelength, char *namestem)
+void write_output (struct SPECTRUM1D_INFO *C, char *col, GMT_LONG n_outputs, BOOLEAN write_wavelength, char *namestem)
 {
 	GMT_LONG	i, j;
 	double	delta_f, eps_pow, out[3], *f_or_w;
@@ -490,8 +490,8 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].xpow;
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].xpow;
 				out[2] = eps_pow * C->spec[i].xpow;
 				GMT_output (fpout, 3, out);
 			}
@@ -506,8 +506,8 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].ypow;
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].ypow;
 				out[2] = eps_pow * C->spec[i].ypow;
 				GMT_output (fpout, 3, out);
 			}
@@ -521,9 +521,9 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].ypow * C->spec[i].coh;
-				out[2] = out[1] * eps_pow * sqrt( (2.0 - C->spec[i].coh) / C->spec[i].coh);
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].ypow * C->spec[i].coh;
+				out[2] = out[GMT_Y] * eps_pow * sqrt( (2.0 - C->spec[i].coh) / C->spec[i].coh);
 				GMT_output (fpout, 3, out);
 			}
 			GMT_fclose(fpout);
@@ -536,9 +536,9 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].ypow * (1.0 - C->spec[i].coh);
-				out[2] = out[1] * eps_pow;
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].ypow * (1.0 - C->spec[i].coh);
+				out[2] = out[GMT_Y] * eps_pow;
 				GMT_output (fpout, 3, out);
 			}
 			GMT_fclose(fpout);
@@ -551,9 +551,9 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].gain;
-				out[2] = out[1] * eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].gain;
+				out[2] = out[GMT_Y] * eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
 				GMT_output (fpout, 3, out);
 			}
 			GMT_fclose(fpout);
@@ -574,9 +574,9 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].radmit;
-				out[2] = fabs (eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) ) * out[1]);
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].radmit;
+				out[2] = fabs (eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) ) * out[GMT_Y]);
 				GMT_output (fpout, 3, out);
 			}
 			GMT_fclose(fpout);
@@ -589,8 +589,8 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].phase;
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].phase;
 				out[2] = eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
 				GMT_output (fpout, 3, out);
 			}
@@ -603,9 +603,9 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 			}
 			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
 			for (i = 0; i < C->n_spec; i++) {
-				out[0] = f_or_w[i];
-				out[1] = C->spec[i].coh;
-				out[2] = out[1] * eps_pow * (1.0 - C->spec[i].coh) * sqrt(2.0 / C->spec[i].coh);
+				out[GMT_X] = f_or_w[i];
+				out[GMT_Y] = C->spec[i].coh;
+				out[2] = out[GMT_Y] * eps_pow * (1.0 - C->spec[i].coh) * sqrt(2.0 / C->spec[i].coh);
 				GMT_output (fpout, 3, out);
 			}
 			GMT_fclose(fpout);
@@ -687,10 +687,10 @@ void detrend_and_hanning (struct SPECTRUM1D_INFO *C)
 		C->x_variance /= C->window;
 	}
 }
-void *New_Spectrum1d_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_spectrum1d_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SPECTRUM1D_CTRL *C;
 	
-	C = (struct SPECTRUM1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SPECTRUM1D_CTRL), "New_Spectrum1d_Ctrl");
+	C = (struct SPECTRUM1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SPECTRUM1D_CTRL), "New_spectrum1d_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->D.inc = 1.0;
@@ -706,7 +706,7 @@ void *New_Spectrum1d_Ctrl () {	/* Allocate and initialize a new control structur
 	return ((void *)C);
 }
 
-void Free_Spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C) {	/* Deallocate control structure */
+void Free_spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C) {	/* Deallocate control structure */
 	if (C->N.name) free ((void *)C->N.name);	
 	GMT_free ((void *)C);	
 }
