@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sphdistance.c,v 1.17 2009/09/09 23:27:05 guru Exp $
+ *	$Id: sphdistance.c,v 1.20 2010/01/05 01:15:48 guru Exp $
  *
- *	Copyright (c) 2008-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 2008-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -99,12 +99,12 @@ int main (int argc, char **argv)
 	struct GMT_LINE_SEGMENT *P = NULL;
 	struct GMT_TABLE *Table;
 	struct STRIPACK_VORONOI *V = NULL;
-	void *New_Sphdistance_Ctrl (), Free_Sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C);
+	void *New_sphdistance_Ctrl (), Free_sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct SPHDISTANCE_CTRL *)New_Sphdistance_Ctrl ();	/* Allocate and initialize a new control structure */
-	GMT_grd_init (&h, argc, argv, TRUE);
+	Ctrl = (struct SPHDISTANCE_CTRL *)New_sphdistance_Ctrl ();	/* Allocate and initialize a new control structure */
+	GMT_grd_init (&h, argc, argv, FALSE);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -510,7 +510,7 @@ int main (int argc, char **argv)
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Sphdistance_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_sphdistance_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -588,15 +588,15 @@ void prepare_polygon (struct GMT_LINE_SEGMENT *P)
 	}
 }
 
-void *New_Sphdistance_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_sphdistance_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SPHDISTANCE_CTRL *C;
 	
-	C = (struct SPHDISTANCE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct SPHDISTANCE_CTRL), "New_Sphdistance_Ctrl");
+	C = (struct SPHDISTANCE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct SPHDISTANCE_CTRL), "New_sphdistance_Ctrl");
 	C->L.unit = 'E';	/* Default is meter distances */
 	return ((void *)C);
 }
 
-void Free_Sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C) {	/* Deallocate control structure */
+void Free_sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	if (C->Q.file) free ((void *)C->Q.file);	
 	GMT_free ((void *)C);	
