@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: splitxyz.c,v 1.50 2009/09/09 23:27:04 guru Exp $
+ *	$Id: splitxyz.c,v 1.52 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -94,11 +94,11 @@ int main(int argc, char **argv)
 	FILE    *fp = NULL, *fpout;
 
 	void	filterz(struct DATA *data, GMT_LONG ndata, double z_filter, double *fwork, GMT_LONG hilow), filterxy_setup(double *fwork), filterxy(struct DATA *data, GMT_LONG begin, GMT_LONG end, double xy_filter, double *fwork, GMT_LONG hilow);
-	void *New_Splitxyz_Ctrl (), Free_Splitxyz_Ctrl (struct SPLITXYZ_CTRL *C);
+	void *New_splitxyz_Ctrl (), Free_splitxyz_Ctrl (struct SPLITXYZ_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 	
-	Ctrl = (struct SPLITXYZ_CTRL *)New_Splitxyz_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct SPLITXYZ_CTRL *)New_splitxyz_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	fpout = GMT_stdout;
 	memset ((void *)output_choice, 0, SPLITXYZ_N_OUTPUT_CHOICES * sizeof (GMT_LONG));
@@ -517,7 +517,7 @@ int main(int argc, char **argv)
 	if (gmtdefs.verbose) fprintf(stderr,"%s:  Split %ld data into %ld files.\n", GMT_program, ndata, nprofiles);
 	GMT_free ((void *)data);
 
-	Free_Splitxyz_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_splitxyz_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -641,10 +641,10 @@ void filterxy (struct DATA *data, GMT_LONG begin, GMT_LONG end, double xy_filter
 	return;
 }
 
-void *New_Splitxyz_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_splitxyz_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SPLITXYZ_CTRL *C;
 	
-	C = (struct SPLITXYZ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SPLITXYZ_CTRL), "New_Splitxyz_Ctrl");
+	C = (struct SPLITXYZ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SPLITXYZ_CTRL), "New_splitxyz_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
         C->A.azimuth = 90.0;
@@ -653,7 +653,7 @@ void *New_Splitxyz_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Splitxyz_Ctrl (struct SPLITXYZ_CTRL *C) {	/* Deallocate control structure */
+void Free_splitxyz_Ctrl (struct SPLITXYZ_CTRL *C) {	/* Deallocate control structure */
 	if (C->N.name) free ((void *)C->N.name);	
 	GMT_free ((void *)C);	
 }
