@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: surface.c,v 1.67 2009/09/09 23:27:04 guru Exp $
+ *	$Id: surface.c,v 1.70 2010/01/09 03:29:28 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -246,11 +246,11 @@ int main (int argc, char **argv)
 	void replace_planar_trend (struct SURFACE_INFO *C);
 	void write_output (struct SURFACE_INFO *C, char *grdfile);
 	void load_parameters (struct SURFACE_INFO *C, struct SURFACE_CTRL *Ctrl);
-	void *New_Surface_Ctrl (), Free_Surface_Ctrl (struct SURFACE_CTRL *C);
+	void *New_surface_Ctrl (), Free_surface_Ctrl (struct SURFACE_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct SURFACE_CTRL *)New_Surface_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct SURFACE_CTRL *)New_surface_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	memset ((void *)&C, 0, sizeof (struct SURFACE_INFO));
 	memset ((void *)&GMT_Surface_Global, 0, sizeof (struct SURFACE_GLOBAL));
@@ -548,7 +548,7 @@ int main (int argc, char **argv)
 		replace_planar_trend (&C);
 		write_output (&C, Ctrl->G.file);
 		GMT_free ((void *) C.u);
-		Free_Surface_Ctrl (Ctrl);	/* Deallocate control structure */
+		Free_surface_Ctrl (Ctrl);	/* Deallocate control structure */
 
 		GMT_end (argc, argv);
 
@@ -612,7 +612,7 @@ int main (int argc, char **argv)
 
 	GMT_free ((void *) C.u);
 
-	Free_Surface_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_surface_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -1629,14 +1629,15 @@ void throw_away_unusables (struct SURFACE_INFO *C)
 			last_index = C->data[k].index;
 		}
 	}
-	/* Sort again; this time the SURFACE_OUTSIDE points will be thrown away  */
-
-	qsort ((void *)C->data, (size_t)C->npoints, sizeof (struct SURFACE_DATA), compare_points);
-	C->npoints -= n_outside;
-	C->data = (struct SURFACE_DATA *) GMT_memory ((void *)C->data, (size_t)C->npoints, sizeof(struct SURFACE_DATA), GMT_program);
-	if (gmtdefs.verbose && (n_outside)) {
-		fprintf (stderr, "%s: %ld unusable points were supplied; these will be ignored.\n", GMT_program, n_outside);
-		fprintf (stderr, "%s: You should have pre-processed the data with block-mean, -median, or -mode.\n", GMT_program);
+	
+	if (n_outside) {	/* Sort again; this time the SURFACE_OUTSIDE points will be thrown away  */
+		qsort ((void *)C->data, (size_t)C->npoints, sizeof (struct SURFACE_DATA), compare_points);
+		C->npoints -= n_outside;
+		C->data = (struct SURFACE_DATA *) GMT_memory ((void *)C->data, (size_t)C->npoints, sizeof(struct SURFACE_DATA), GMT_program);
+		if (gmtdefs.verbose) {
+			fprintf (stderr, "%s: %ld unusable points were supplied; these will be ignored.\n", GMT_program, n_outside);
+			fprintf (stderr, "%s: You should have pre-processed the data with block-mean, -median, or -mode.\n", GMT_program);
+		}
 	}
 }
 
@@ -2043,10 +2044,10 @@ void load_parameters (struct SURFACE_INFO *C, struct SURFACE_CTRL *Ctrl)
 	C->converge_limit = Ctrl->C.value;
 }
 
-void *New_Surface_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_surface_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SURFACE_CTRL *C;
 	
-	C = (struct SURFACE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SURFACE_CTRL), "New_Surface_Ctrl");
+	C = (struct SURFACE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SURFACE_CTRL), "New_surface_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->N.value = 250;
@@ -2056,7 +2057,7 @@ void *New_Surface_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Surface_Ctrl (struct SURFACE_CTRL *C) {	/* Deallocate control structure */
+void Free_surface_Ctrl (struct SURFACE_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	if (C->L.low) free ((void *)C->L.low);	
 	if (C->L.high) free ((void *)C->L.high);	
