@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: trend1d.c,v 1.44 2009/09/09 23:27:04 guru Exp $
+ *	$Id: trend1d.c,v 1.46 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -172,11 +172,11 @@ int main (int argc, char **argv)
 	void load_gtg_and_gtd(struct TREND1D_DATA *data, GMT_LONG n_data, double *gtg, double *gtd, double *grow, GMT_LONG n_model, GMT_LONG mp, GMT_LONG m_type);
 	void solve_system(double *gtg, double *gtd, double *model, GMT_LONG n_model, GMT_LONG mp, double *lambda, double *v, double *b, double *z, double c_no, GMT_LONG *ir);
 	void GMT_cheb_to_pol (double c[], GMT_LONG n, double a, double b);
-	void *New_Trend1d_Ctrl (), Free_Trend1d_Ctrl (struct TREND1D_CTRL *C);
+	void *New_trend1d_Ctrl (), Free_trend1d_Ctrl (struct TREND1D_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct TREND1D_CTRL *)New_Trend1d_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct TREND1D_CTRL *)New_trend1d_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -471,7 +471,7 @@ int main (int argc, char **argv)
 
 	free_the_memory(gtg, v, gtd, lambda, workb, workz, c_model, o_model, w_model, data, work);
 
-	Free_Trend1d_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_trend1d_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -880,10 +880,10 @@ void GMT_cheb_to_pol (double c[], GMT_LONG n, double a, double b)
 	GMT_free ((void *) dd);
 }
 
-void *New_Trend1d_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_trend1d_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct TREND1D_CTRL *C;
 	
-	C = (struct TREND1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct TREND1D_CTRL), "New_Trend1d_Ctrl");
+	C = (struct TREND1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct TREND1D_CTRL), "New_trend1d_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->C.value = 1.0e06;		/* Condition number for matrix solution  */	
@@ -892,6 +892,6 @@ void *New_Trend1d_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Trend1d_Ctrl (struct TREND1D_CTRL *C) {	/* Deallocate control structure */
+void Free_trend1d_Ctrl (struct TREND1D_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
