@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: trend2d.c,v 1.45 2009/09/09 23:27:04 guru Exp $
+ *	$Id: trend2d.c,v 1.47 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -130,11 +130,11 @@ int main(int argc, char **argv)
 	void move_model_a_to_b(double *model_a, double *model_b, GMT_LONG n_model, double *chisq_a, double *chisq_b);
 	void load_gtg_and_gtd(struct TREND2D_DATA *data, GMT_LONG n_data, double *gtg, double *gtd, double *grow, GMT_LONG n_model, GMT_LONG mp);
 	void solve_system(double *gtg, double *gtd, double *model, GMT_LONG n_model, GMT_LONG mp, double *lambda, double *v, double *b, double *z, double c_no, GMT_LONG *ir);
-	void *New_Trend2d_Ctrl (), Free_Trend2d_Ctrl (struct TREND2D_CTRL *C);
+	void *New_trend2d_Ctrl (), Free_trend2d_Ctrl (struct TREND2D_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct TREND2D_CTRL *)New_Trend2d_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct TREND2D_CTRL *)New_trend2d_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	n_outputs = 0;
 	sprintf (format, "%s\t", gmtdefs.d_format);
@@ -426,7 +426,7 @@ int main(int argc, char **argv)
 
 	free_the_memory(gtg, v, gtd, lambda, workb, workz, c_model, o_model, w_model, data, work);
 
-	Free_Trend2d_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_trend2d_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -793,10 +793,10 @@ void solve_system (double *gtg, double *gtd, double *model, GMT_LONG n_model, GM
 	}
 }
 
-void *New_Trend2d_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_trend2d_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct TREND2D_CTRL *C;
 	
-	C = (struct TREND2D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct TREND2D_CTRL), "New_Trend2d_Ctrl");
+	C = (struct TREND2D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct TREND2D_CTRL), "New_trend2d_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->C.value = 1.0e06;		/* Condition number for matrix solution  */	
@@ -804,6 +804,6 @@ void *New_Trend2d_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Trend2d_Ctrl (struct TREND2D_CTRL *C) {	/* Deallocate control structure */
+void Free_trend2d_Ctrl (struct TREND2D_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
