@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: triangulate.c,v 1.67 2009/09/09 23:27:04 guru Exp $
+ *	$Id: triangulate.c,v 1.69 2010/01/05 01:15:47 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -97,11 +97,11 @@ int main (int argc, char **argv)
 	struct TRIANGULATE_EDGE *edge;
 	struct TRIANGULATE_CTRL *Ctrl;
 
-	void *New_Triangulate_Ctrl (), Free_Triangulate_Ctrl (struct TRIANGULATE_CTRL *C);
+	void *New_triangulate_Ctrl (), Free_triangulate_Ctrl (struct TRIANGULATE_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct TRIANGULATE_CTRL *)New_Triangulate_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct TRIANGULATE_CTRL *)New_triangulate_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&header, argc, argv, FALSE);
 
@@ -517,7 +517,7 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Triangulate_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_triangulate_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -544,17 +544,17 @@ int compare_edge (const void *p1, const void *p2)
 	}
 }
 
-void *New_Triangulate_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_triangulate_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct TRIANGULATE_CTRL *C;
 	
-	C = (struct TRIANGULATE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct TRIANGULATE_CTRL), "New_Triangulate_Ctrl");
+	C = (struct TRIANGULATE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct TRIANGULATE_CTRL), "New_triangulate_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->D.dir = -1;	/* No derivatives */
 	return ((void *)C);
 }
 
-void Free_Triangulate_Ctrl (struct TRIANGULATE_CTRL *C) {	/* Deallocate control structure */
+void Free_triangulate_Ctrl (struct TRIANGULATE_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
