@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_binlist.c,v 1.62 2009/09/09 23:27:05 guru Exp $
+ *	$Id: x2sys_binlist.c,v 1.64 2010/01/05 01:15:49 guru Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
+ *      Copyright (c) 1999-2010 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -157,7 +157,7 @@ int main (int argc, char **argv)
 	}
 	
 	x2sys_bix_init (&B, TRUE);
-	nav_flag = (1 << s->x_col) + (1 << s->y_col);	/* For bins just cut by track but no points inside the bin */
+	nav_flag = (1 << s->x_col[GMT_IN]) + (1 << s->y_col[GMT_IN]);	/* For bins just cut by track but no points inside the bin */
 	jump_180 = irint (180.0 / B.bin_x);
 	jump_360 = irint (360.0 / B.bin_x);
 
@@ -178,7 +178,7 @@ int main (int argc, char **argv)
 		if (gmtdefs.verbose) fprintf (stderr, "[%s]\n", s->path);
 		
 		if (ea_mode) {	/* Project coordinates */
-			for (j = 0; j < p.n_rows; j++) GMT_geo_to_xy (data[s->x_col][j], data[s->y_col][j], &data[s->x_col][j], &data[s->y_col][j]);
+			for (j = 0; j < p.n_rows; j++) GMT_geo_to_xy (data[s->x_col[GMT_IN]][j], data[s->y_col[GMT_IN]][j], &data[s->x_col[GMT_IN]][j], &data[s->y_col[GMT_IN]][j]);
 		}
 		
 		/* Reset bin flags */
@@ -186,13 +186,13 @@ int main (int argc, char **argv)
 		memset ((void *)B.binflag, 0, (size_t)(B.nm_bin * sizeof (unsigned int)));
 		if (trackline) {
 			memset ((void *)dist_bin, 0, (size_t)(B.nm_bin * sizeof (double)));
-			GMT_err_fail (GMT_distances (data[s->x_col], data[s->y_col], p.n_rows, dist_scale, -s->dist_flag, &dist_km), "");	/* -ve gives increments */
+			GMT_err_fail (GMT_distances (data[s->x_col[GMT_IN]], data[s->y_col[GMT_IN]], p.n_rows, dist_scale, -s->dist_flag, &dist_km), "");	/* -ve gives increments */
 		}
 
 		last_bin_ij = last_bin_i = last_bin_j = -1;
 		for (j = 0; j < p.n_rows; j++) {
-			if (outside (data[s->x_col][j], data[s->y_col][j], &B, s->geographic)) continue;
-			 x2sys_err_fail (x2sys_bix_get_ij (data[s->x_col][j], data[s->y_col][j], &this_bin_i, &this_bin_j, &B, &this_bin_ij), "");
+			if (outside (data[s->x_col[GMT_IN]][j], data[s->y_col[GMT_IN]][j], &B, s->geographic)) continue;
+			 x2sys_err_fail (x2sys_bix_get_ij (data[s->x_col[GMT_IN]][j], data[s->y_col[GMT_IN]][j], &this_bin_i, &this_bin_j, &B, &this_bin_ij), "");
 
 			/* While this may be the same bin as the last bin, the data available may have changed so we keep
 			 * turning the data flags on again and again. */
@@ -205,10 +205,10 @@ int main (int argc, char **argv)
 			
 			if (j > 0) { /* Can check for gaps starting with 1st to 2nd point */
 				gap = FALSE;
-				if (s->t_col >= 0) {	/* There is a time column in the data*/
-					if (GMT_is_dnan (data[s->t_col][j])&& (dist_km[j] - dist_km[j-1]) > B.dist_gap) /* but time = NaN, so test for gaps based on distance */
+				if (s->t_col[GMT_IN] >= 0) {	/* There is a time column in the data*/
+					if (GMT_is_dnan (data[s->t_col[GMT_IN]][j])&& (dist_km[j] - dist_km[j-1]) > B.dist_gap) /* but time = NaN, so test for gaps based on distance */
 						gap = TRUE;
-			   		else if ((data[s->t_col][j] - data[s->t_col][j-1]) > B.time_gap)	/* We have a time data gap so we skip this interval */
+			   		else if ((data[s->t_col[GMT_IN]][j] - data[s->t_col[GMT_IN]][j-1]) > B.time_gap)	/* We have a time data gap so we skip this interval */
 						gap = TRUE;
 				}
 				else if ((dist_km[j] - dist_km[j-1]) > B.dist_gap) /* There is no time column, must test for gaps based on distance */
@@ -229,31 +229,31 @@ int main (int argc, char **argv)
 				if (s->geographic && (this_bin_i - last_bin_i) > jump_180) {		/* Jumped from east to west across Greenwich */
 					start_i = this_bin_i + 1;
 					end_i = last_bin_i + jump_360;
-					dx = (data[s->x_col][j] - 360.0) - data[s->x_col][j-1];
+					dx = (data[s->x_col[GMT_IN]][j] - 360.0) - data[s->x_col[GMT_IN]][j-1];
 				}
 				else if (s->geographic && (this_bin_i - last_bin_i) < -jump_180) {	/* Jumped from west to east across Greenwich */
 					start_i = last_bin_i + 1;
 					end_i = this_bin_i + jump_360;
-					dx = data[s->x_col][j] - (data[s->x_col][j-1] - 360.0);
+					dx = data[s->x_col[GMT_IN]][j] - (data[s->x_col[GMT_IN]][j-1] - 360.0);
 				}
 				else {								/* Did no such thing */
 					start_i = MIN (last_bin_i, this_bin_i) + 1;
 					end_i = MAX (last_bin_i, this_bin_i);
-					dx = data[s->x_col][j] - data[s->x_col][j-1];
+					dx = data[s->x_col[GMT_IN]][j] - data[s->x_col[GMT_IN]][j-1];
 				}
 				
 				/* Find all the bin-line intersections */
 				
 				/* Add the start and stop coordinates to the xc/yc arrays so we can get mid-points of the intervals */
 				
-				X[0].x = data[s->x_col][j-1];	X[0].y = data[s->y_col][j-1];	X[0].d = 0.0;
-				X[1].x = data[s->x_col][j];	X[1].y = data[s->y_col][j];	X[1].d = hypot (dx, data[s->y_col][j] - data[s->y_col][j-1]);
+				X[0].x = data[s->x_col[GMT_IN]][j-1];	X[0].y = data[s->y_col[GMT_IN]][j-1];	X[0].d = 0.0;
+				X[1].x = data[s->x_col[GMT_IN]][j];	X[1].y = data[s->y_col[GMT_IN]][j];	X[1].d = hypot (dx, data[s->y_col[GMT_IN]][j] - data[s->y_col[GMT_IN]][j-1]);
 				nx = 2;
 				for (bj = MIN (last_bin_j, this_bin_j) + 1; bj <= MAX (last_bin_j, this_bin_j); bj++) {	/* If we go in here we know dy is non-zero */
 					y = B.y_min + bj * B.bin_y;
-					del_y = y - data[s->y_col][j-1];
-					del_x = del_y * dx / (data[s->y_col][j] - data[s->y_col][j-1]);
-					x = data[s->x_col][j-1] + del_x;
+					del_y = y - data[s->y_col[GMT_IN]][j-1];
+					del_x = del_y * dx / (data[s->y_col[GMT_IN]][j] - data[s->y_col[GMT_IN]][j-1]);
+					x = data[s->x_col[GMT_IN]][j-1] + del_x;
 					X[nx].x = x;	X[nx].y = y;	X[nx].d = hypot (del_x , del_y);
 					nx++;
 					if (nx == (int)nx_alloc) {
@@ -264,13 +264,13 @@ int main (int argc, char **argv)
 				for (bi = start_i; bi <= end_i; bi++) {	/* If we go in here we think dx is non-zero (we do a last-ditch dx check just in case) */
 					x = B.x_min + bi * B.bin_x;
 					if (s->geographic && x >= 360.0) x -= 360.0;
-					del_x = x - data[s->x_col][j-1];
+					del_x = x - data[s->x_col[GMT_IN]][j-1];
 					if (fabs (del_x) > 180.0) del_x = copysign (360.0 - fabs (del_x), -del_x);
-					del_y = (dx == 0.0) ? 0.5 * (data[s->y_col][j] - data[s->y_col][j-1]) : del_x * (data[s->y_col][j] - data[s->y_col][j-1]) / dx;
-					y = data[s->y_col][j-1] + del_y;
+					del_y = (dx == 0.0) ? 0.5 * (data[s->y_col[GMT_IN]][j] - data[s->y_col[GMT_IN]][j-1]) : del_x * (data[s->y_col[GMT_IN]][j] - data[s->y_col[GMT_IN]][j-1]) / dx;
+					y = data[s->y_col[GMT_IN]][j-1] + del_y;
 					if (s->geographic && fabs (y) > y_max) {
 						y = copysign (y_max, y);
-						del_y = y - data[s->y_col][j-1];
+						del_y = y - data[s->y_col[GMT_IN]][j-1];
 					}
 					X[nx].x = x;	X[nx].y = y;	X[nx].d = hypot (del_x, del_y);
 					nx++;
