@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_get.c,v 1.47 2009/09/18 02:54:20 guru Exp $
+ *	$Id: x2sys_get.c,v 1.51 2010/01/05 01:15:49 guru Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
+ *      Copyright (c) 1999-2010 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -29,19 +29,28 @@
 
 #include "x2sys.h"
 
+int find_leg (char *name, struct X2SYS_BIX *B, int n)
+{	/* Return track id # for this leg */
+	int i;
+
+	for (i = 0; i < n; i++) if (!strcmp (name, B->head[i].trackname)) return (i);
+	return (-1);
+}
+
 int main (int argc, char **argv)
 {
-	char *TAG = CNULL, *fflags = CNULL, *nflags = CNULL, *fx = NULL;
+	char *TAG = NULL, *fflags = NULL, *nflags = NULL, *fx = NULL;
 	char *y_match = NULL, *n_match = NULL, line[BUFSIZ], *p = NULL;
 	
 	double x, y;
 
-	struct X2SYS_INFO *s;
+	struct X2SYS_INFO *s = NULL;
 	struct X2SYS_BIX B;
-	struct X2SYS_BIX_TRACK *track;
+	struct X2SYS_BIX_TRACK *track = NULL;
 
-	BOOLEAN error = FALSE, no_suffix = FALSE, center = FALSE, x_setup = FALSE;
-	BOOLEAN y_ok, n_ok, first, *include = NULL, swap = FALSE;
+	BOOLEAN error = FALSE, no_suffix, center = FALSE, x_setup = FALSE;
+	BOOLEAN y_ok, n_ok, first, *include = NULL, swap = FALSE, quick = FALSE;
+	BOOLEAN internal = TRUE, external = TRUE, extension = FALSE;
 
 	int combo = 0, ij, n_tracks_found, n_tracks, bit;
 	int id1, id2, item, n_flags = 0, n_pairs, missing = 0, *ids_in_bin = NULL;
@@ -53,8 +62,6 @@ int main (int argc, char **argv)
 	
 	FILE *fp;
 
-	int find_leg (char *name, struct X2SYS_BIX *B, int n);
-
 	argc = GMT_begin (argc, argv);
 	
 	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
@@ -71,14 +78,15 @@ int main (int argc, char **argv)
 				case 'C':
 					center = TRUE;
 					break;
+				case 'D':
+					quick = TRUE;	/* Just list track names and not the full report  */
+					break;
+				case 'E':
+					extension = TRUE;
+					break;
 				case 'F':
 					fflags = &argv[i][2];
 					break;
-#if 0
-				case 'S':
-					no_suffix = TRUE;
-					break;
-#endif
 				case 'L':
 					if (argv[i][2]) fx = &argv[i][2];
 					x_setup = TRUE;
@@ -89,6 +97,10 @@ int main (int argc, char **argv)
 				case 'T':
 					TAG = &argv[i][2];
 					break;
+				case 'Q':	/* Specify internal or external only */
+					if (argv[i][2] == 'e') internal = FALSE;
+					if (argv[i][2] == 'i') external = FALSE;
+					break;
 				case 's':
 					swap = TRUE;	/* Undocumented swap option for index.b reading */
 					break;
@@ -102,22 +114,23 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || error || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "x2sys_get %s - Get track listing from track index database\n\n", X2SYS_VERSION);
-		fprintf (stderr, "usage: x2sys_get -T<TAG> [-C] [-F<fflags>] [-L[list]] [-N<nflags>] [%s] [-V]\n\n", GMT_Rgeo_OPT);
+		fprintf (stderr, "usage: x2sys_get -T<TAG> [-C] [-D] [-E] [-F<fflags>] [-L[list]] [-N<nflags>] [-Qe|i] [%s] [-V]\n\n", GMT_Rgeo_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "	-C reports center of each tile with tracks instead [Default is track files]\n");
-		fprintf (stderr, "	-F is comma-separated list of column names that must be present [Default is any field]\n");
-		fprintf (stderr, "	-L Setup mode: Return all pairs of cruises that might intersect given\n");
+		fprintf (stderr, "	-C reports center of each tile with tracks instead [Default is track files].\n");
+		fprintf (stderr, "	-D only reports the track names and not the report on each field.\n");
+		fprintf (stderr, "	-E Append the filename extensions in the report [just track name].\n");
+		fprintf (stderr, "	-F is comma-separated list of column names that must be present [Default is any field].\n");
+		fprintf (stderr, "	-L Setup mode: Return all pairs of cruises that might intersect given.\n");
 		fprintf (stderr, "	   the bin distribution.  Optionally, give file with a list of cruises.\n");
 		fprintf (stderr, "	   Then, only pairs with at least one cruise from the list is output.\n");
-		fprintf (stderr, "	-N is comma-separated list of column names that must be missing\n");
+		fprintf (stderr, "	-N is comma-separated list of column names that must be missing.\n");
+		fprintf (stderr,"	-Q Append e for external or i for internal crossovers [Default is both].\n");
+		fprintf (stderr,"	   Requires -L and affects the pairs that are returned.\n");
 		GMT_explain_option ('R');
 		fprintf (stderr, "	[Default region is the entire data domain]\n");
-#if 0
-		fprintf (stderr, "	-S reports tracks files without suffix [Default is file name]\n");
-#endif
 		GMT_explain_option ('V');
 		exit (EXIT_FAILURE);
 	}
@@ -155,6 +168,8 @@ int main (int argc, char **argv)
 
 	x2sys_err_fail (x2sys_bix_read_index (s, &B, swap), "");
 
+	no_suffix = !extension;
+	
 	if (x_setup) {
 		n_flags = (int)ceil (n_tracks / 32.0);
 		include = (BOOLEAN *) GMT_memory (VNULL, (size_t)n_tracks, sizeof (BOOLEAN), GMT_program);
@@ -242,6 +257,8 @@ int main (int argc, char **argv)
 
 	if (x_setup) {
 		for (id1 = n_pairs = 0; id1 < n_tracks; id1++) {
+			if (internal && include[id1]) printf ("%s\t%s\n", B.head[id1].trackname, B.head[id1].trackname);
+			if (!external) continue;	/* Skip all external comparisons */
 			for (id2 = id1 + 1; id2 < n_tracks; id2++) {
 				item = id2 / 32;
 				bit = id2 % 32;
@@ -264,11 +281,13 @@ int main (int argc, char **argv)
 		if (n_tracks_found) {
 			if (gmtdefs.verbose ) fprintf (stderr, "%s: Found %d tracks\n", GMT_program, n_tracks_found);
 	
-			printf ("# Search command: %s", GMT_program);
-			for (i = 1; i < argc; i++) printf (" %s", argv[i]);
-			printf ("\n#track_ID\t");
-			for (i = 0; i < (s->n_fields-1); i++) printf ("%s\t", s->info[i].name);
-			printf ("%s\n", s->info[s->n_fields-1].name);
+			if (!quick) {
+				printf ("# Search command: %s", GMT_program);
+				for (i = 1; i < argc; i++) printf (" %s", argv[i]);
+				printf ("\n#track_ID\t");
+				for (i = 0; i < (s->n_fields-1); i++) printf ("%s\t", s->info[i].name);
+				printf ("%s\n", s->info[s->n_fields-1].name);
+			}
 			for (k = 0; k < n_tracks; k++) {
 				if (y_match[k] == 0 || n_match[k] == 1) continue;
 				if (no_suffix) {
@@ -276,8 +295,11 @@ int main (int argc, char **argv)
 					if (i) B.head[k].trackname[i] = '\0';
 				}
 				printf ("%s", B.head[k].trackname);
-				for (i = 0, bit = 1; i < s->n_fields; i++, bit <<= 1) {
-					(B.head[k].flag & bit) ? printf ("\tY") : printf ("\tN");
+				if (extension) printf (".%s", s->suffix);
+				if (!quick) {
+					for (i = 0, bit = 1; i < s->n_fields; i++, bit <<= 1) {
+						(B.head[k].flag & bit) ? printf ("\tY") : printf ("\tN");
+					}
 				}
 				printf ("\n");
 			}
@@ -296,12 +318,3 @@ int main (int argc, char **argv)
 
 	exit (EXIT_SUCCESS);
 }
-
-int find_leg (char *name, struct X2SYS_BIX *B, int n)
-{	/* Return track id # for this leg */
-	int i;
-	
-	for (i = 0; i < n; i++) if (!strcmp (name, B->head[i].trackname)) return (i);
-	return (-1);
-}
-
