@@ -1,8 +1,8 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_init.c,v 1.33 2009/01/09 04:02:36 guru Exp $
+ *	$Id: x2sys_init.c,v 1.38 2010/01/05 01:15:49 guru Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
- *      See COPYING file for copying and redistribution conditions.
+ *      Copyright (c) 1999-2010 by P. Wessel
+ *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -44,8 +44,8 @@ int main (int argc, char **argv)
 
 	FILE *fp = NULL, *fp_def = NULL;
 
-	GMT_LONG n_tags = 0, i, n_found = 0, geodetic = 0, r_entry, i_entry, d_entry;
-	GMT_LONG e_entry,  g_entry, m_entry, wd_entry, wt_entry, n_entry, c_entry;
+	int n_tags = 0, i, n_found = 0, geodetic = 0, r_entry, i_entry, d_entry, d_start;
+	int e_entry,  g_entry, m_entry, wd_entry, wt_entry, n_entry, c_entry;
 
 	double x_min = 0.0, x_max = 0.0, y_min = 0.0, y_max = 0.0, bin_x = 0.0, bin_y = 0.0;
 
@@ -100,6 +100,7 @@ int main (int argc, char **argv)
 					i_entry = i;
 					break;
 				case 'M':
+				case 'm':
 					m_entry = i;
 					break;
 				case 'N':	/* Distance and speed unit selection */
@@ -146,7 +147,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || error || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "x2sys_init %s - Initialize a new track system database\n\n", X2SYS_VERSION);
 		fprintf (stderr, "usage: x2sys_init <TAG> [-Cc|f|g|e] [-D<deffile>] [-E<suffix>] [-F] [-G[d/g]] [-I[<binsize>]]\n");
-		fprintf (stderr, "\t[%s] [-N[d|s][c|e|k|m|n]]] [%s] [-V] [-Wt|d|n<gap>]\n\n", GMT_M_OPT, GMT_Rgeo_OPT);
+		fprintf (stderr, "\t[-N[d|s][c|e|k|m|n]]] [%s] [-V] [-Wt|d|n<gap>] [%s]\n\n", GMT_Rgeo_OPT, GMT_m_OPT);
 		fprintf (stderr, "\t<TAG> is the unique system identifier.  Files created will be placed in\n");
 		fprintf (stderr, "\t   the directory X2SYS_HOME/<TAG>.\n");
 
@@ -165,7 +166,6 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-G for geographical coordinates.  Append g for discontinuity at Greenwich (output 0/360 [Default])\n");
 		fprintf (stderr, "\t   and append d for discontinuity at Dateline (output -180/+180)\n");
 		fprintf (stderr, "\t-I sets bin size for track bin index output [1/1]\n");
-		GMT_explain_option ('M');
 		fprintf (stderr, "\t-N Append (d)istances or (s)peed, and your choice for unit. Choose among:\n");
 		fprintf (stderr, "\t   c Cartesian distance (user-dist-units, user user-dist-units/user-time-units)\n");
 		fprintf (stderr, "\t   e Metric units I (meters, m/s)\n");
@@ -179,6 +179,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-W Set maximum gaps allowed at crossover.  Option may be repeated.\n");
 		fprintf (stderr, "\t   -Wt sets maximum time gap (in user units) [Default is infinite]\n");
 		fprintf (stderr, "\t   -Wd sets maximum distance gap (in user units) [Default is infinite]\n");
+		GMT_explain_option ('m');
 		exit (EXIT_FAILURE);
 	}
 
@@ -208,6 +209,8 @@ int main (int argc, char **argv)
 		fprintf (stderr,"%s: Unable to open local definition file : %s\n", GMT_program, def_file);
 		exit (EXIT_FAILURE);
 	}
+	for (d_start = strlen (sfile)-1; d_start >= 0 && sfile[d_start] != DIR_DELIM; d_start--);	/* Find pos of last slash */
+	d_start++;		/* Find start of file name */
 	
 	/* Determine the TAG directory */
 	
@@ -227,7 +230,7 @@ int main (int argc, char **argv)
 	/* Initialize the system TAG files in X2SYS_HOME/TAG */
 
 	sprintf (tag_file, "%s%c%s.tag", TAG, DIR_DELIM, TAG);
-	sprintf (def_file, "%s%c%s.def", TAG, DIR_DELIM, ((d_entry) ? sfile : TAG));
+	sprintf (def_file, "%s%c%s.def", TAG, DIR_DELIM, &sfile[d_start]);
 	sprintf (path_file, "%s%c%s_paths.txt", TAG, DIR_DELIM, TAG);
 	sprintf (track_file, "%s%c%s_tracks.d", TAG, DIR_DELIM, TAG);
 	sprintf (bin_file, "%s%c%s_index.b", TAG, DIR_DELIM, TAG);
@@ -313,11 +316,11 @@ int main (int argc, char **argv)
 	else
 #endif
 		fprintf (fp, "# Initialized by: unknown\n#\n");
-	(d_entry) ? fprintf (fp, "%s", argv[d_entry]) : fprintf (fp, "-D%s", TAG);
+	fprintf (fp, "-D%s", &sfile[d_start]);	/* Now a local *.def file in the TAG directory */
 	if (c_entry) fprintf (fp, " %s", argv[c_entry]);
 	if (e_entry) fprintf (fp, " %s", argv[e_entry]);
 	if (g_entry) fprintf (fp, " %s", argv[g_entry]);
-	if (m_entry) fprintf (fp, " %s", argv[m_entry]);
+	if (m_entry) fprintf (fp, " -m%s", &argv[m_entry][2]);
 	if (n_entry) fprintf (fp, " %s", argv[n_entry]);
 	if (wt_entry) fprintf (fp, " %s", argv[wt_entry]);
 	if (wd_entry) fprintf (fp, " %s", argv[wd_entry]);
