@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_solve.c,v 1.39 2009/09/16 01:30:12 guru Exp $
+ *	$Id: x2sys_solve.c,v 1.42 2010/01/14 07:15:20 guru Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
+ *      Copyright (c) 1999-2010 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -121,26 +121,16 @@ double basis_z (double **P, int which, int col) {	/* Basis function f for a depe
 	return (P[COL_Z1+which][col]);
 }
 
-#ifdef SAVEFORLATER
-int x2sys_read_namedatelist (char *file, char ***list, double **start, int *nf);
-#endif
-
 int main (int argc, char **argv)
 {
 	char *TAG = CNULL, *column = CNULL, **trk_list = NULL, *dbase = CNULL;
 	char  trk[2][GMT_TEXT_LEN], t_txt[2][GMT_TEXT_LEN], z_txt[GMT_TEXT_LEN], w_txt[GMT_TEXT_LEN], line[BUFSIZ];
-#ifdef SAVEFORLATER
-	char *tracklist = CNULL;
-#endif
-	BOOLEAN error = FALSE, grow_list = FALSE, normalize = FALSE, use_weights = FALSE, active_col[N_COE_PARS];
+	BOOLEAN error = FALSE, grow_list = FALSE, normalize = FALSE, use_weights = FALSE, active_col[N_COE_PARS], reset_zero = FALSE;
 	int *ID[2];
 	GMT_LONG n_par = 0, n, m, t, n_tracks = 0, mode = 0, n_active;
 	GMT_LONG i, p, j, k, r, s, off, row, n_COE = 0, n_alloc = GMT_CHUNK, n_alloc_t = GMT_CHUNK, ierror;
 	double *N, *a, *b, *data[N_COE_PARS], sgn, zero_test = 1.0e-08, old_mean, new_mean, sw2;
-	double old_stdev, new_stdev, e_k, min_extent, max_extent, range = 0.0, Sw, Sx, Sxx;
-#ifdef SAVEFORLATER
-	double *start = NULL;
-#endif
+	double old_stdev, new_stdev, e_k, Sw, Sx, Sxx, range = 0.0, *start = NULL;
 	struct X2SYS_INFO *S;
 	struct X2SYS_BIX B;
 	FILE *fp;
@@ -185,17 +175,15 @@ int main (int argc, char **argv)
 							break;
 					}
 					break;
-#ifdef SAVEFORLATER
-				case 'I':	/* List of track names and their start time dateTclock */
-					tracklist = &argv[i][2];
-					break;
-#endif
 				case 'T':
 					TAG = &argv[i][2];
 					break;
 				case 'W':
 					use_weights = TRUE;
 					break;
+				case 'Z':
+					reset_zero = TRUE;
+					break;
 				default:
 					error = TRUE;
 					fprintf (stderr, "%s: Unrecognized option -%c\n", GMT_program, argv[i][1]);
@@ -208,11 +196,7 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || error || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "x2sys_solve %s - Determine least-squares systematic correction from crossovers\n\n", X2SYS_VERSION);
-#ifdef SAVEFORLATER
-		fprintf (stderr, "usage: x2sys_solve -C<column> -E<flag> -T<TAG> [<coedata>] [-I<tracklist>] [-V] [-W] [%s]\n\n", GMT_bi_OPT);
-#else
-		fprintf (stderr, "usage: x2sys_solve -C<column> -E<flag> -T<TAG> [<coedata>] [-V] [-W] [%s]\n\n", GMT_bi_OPT);
-#endif
+		fprintf (stderr, "usage: x2sys_solve -C<column> -E<flag> -T<TAG> [<coedata>] [-V] [-W] [Z] [%s]\n\n", GMT_bi_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -222,11 +206,9 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-T <TAG> is the x2sys tag for the data set.\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t<coedata> is the ASCII data output file from x2sys_list [or we read stdin]\n");
-#ifdef SAVEFORLATER
-		fprintf (stderr, "\t-I List of tracks and their start date (required for -Et)\n");
-#endif
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W weights are present in last column for weighted fit [no weights]\n");
+		fprintf (stderr, "\t-Z Use the earliest time and shortest distance as local origin [use 0].\n");
 		GMT_explain_option ('i');
 		exit (EXIT_FAILURE);
 	}
@@ -235,17 +217,6 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: ERROR -E: Choose among c, d, g, h, s and t\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-#ifdef SAVEFORLATER
-	if (mode == F_IS_DRIFT_T && !tracklist) {
-		fprintf (stderr, "%s: ERROR -Ed: Solution requires -I<tracklist>\n", GMT_program);
-		exit (EXIT_FAILURE);
-	}
-	
-	if (tracklist && x2sys_read_namedatelist (tracklist, &trk_list, &start, &n_tracks) == X2SYS_NOERROR) {
-		fprintf (stderr, "%s: ERROR -I: Problems reading %s\n", GMT_program, tracklist);
-		exit (EXIT_FAILURE);	
-	}
-#endif
 	
 	/* Initialize system via the tag */
 	
@@ -412,6 +383,7 @@ int main (int argc, char **argv)
 			exit (EXIT_FAILURE);	
 		}
 		while (GMT_fgets (line, BUFSIZ, fp)) {    /* Not yet EOF */
+			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (line[0] == '#') continue;	/* Skip other comments */
 			switch (mode) {	/* Handle input differently depending on what is expected */
 				case F_IS_CONSTANT:
@@ -468,12 +440,6 @@ int main (int argc, char **argv)
 							trk_list = (char **) GMT_memory ((void *)trk_list, (size_t)n_alloc_t, sizeof (char *), GMT_program);
 						}
 					}
-#ifdef SAVEFORLATER
-					else {
-						fprintf (stderr, "%s: ERROR: Track %s not in specified list of tracks [%s]\n", GMT_program, trk[i], tracklist);
-						exit (EXIT_FAILURE);					
-					}
-#endif
 				}
 			}
 		
@@ -493,13 +459,23 @@ int main (int argc, char **argv)
 	
 	normalize = (mode == F_IS_DRIFT_T || mode == F_IS_DRIFT_D);
 	if (normalize) {	/* For numerical stability, normalize distances or times to fall in 0-1 range */
-		min_extent = DBL_MAX;	max_extent = -DBL_MAX;
+		double min_extent, max_extent;
+		start = (double *) GMT_memory (NULL, (size_t)n_tracks, sizeof (double), GMT_program);
 		j = (mode == F_IS_DRIFT_T) ? COL_T1 : COL_D1;	/* Which variable we are working on */
+		
+		if (reset_zero) {	/* Must determine smallest t or d for all tracks */
+			for (k = 0; k < n_tracks; k++) start[k] = DBL_MAX;
+			for (k = 0; k < n_COE; k++) {
+				for (i = 0; i < 2; i++) {
+					if (data[j+i][k] < start[ID[i][k]]) start[ID[i][k]] = data[j+i][k];
+				}
+			}
+		}
+		/* Now we know the start time/distance [or all 0].  Remove it to reduce mangitudes of values */
+		min_extent = DBL_MAX;	max_extent = -DBL_MAX;
 		for (k = 0; k < n_COE; k++) {
 			for (i = 0; i < 2; i++) {
-#ifdef SAVEFORLATER
-				if (mode == F_IS_DRIFT_T) data[COL_T1+i][k] -= start[ID[i][k]];	/* Remove origin time for track */
-#endif
+				if (reset_zero) data[j+i][k] -= start[ID[i][k]];
 				if (data[j+i][k] < min_extent) min_extent = data[j+i][k];
 				if (data[j+i][k] > max_extent) max_extent = data[j+i][k];
 			}
@@ -599,10 +575,16 @@ int main (int argc, char **argv)
 				printf ("\t%g\n", a[p]);
 				break;
 			case F_IS_DRIFT_T:
-				printf ("\t%g\t%g*((time-T))\n", a[p*n_par], a[p*n_par+1]);
+				if (reset_zero)
+					printf ("\t%g\t%g*((time-T))\n", a[p*n_par], a[p*n_par+1]);
+				else
+					printf ("\t%g\t%g*((time-%g))\n", a[p*n_par], a[p*n_par+1], start[p]);
 				break;
 			case F_IS_DRIFT_D:
-				printf ("\t%g\t%g*((dist))\n", a[p*n_par], a[p*n_par+1]);
+				if (reset_zero)
+					printf ("\t%g\t%g*((dist-%g))\n", a[p*n_par], a[p*n_par+1], start[p]);
+				else
+					printf ("\t%g\t%g*((dist))\n", a[p*n_par], a[p*n_par+1]);
 				break;
 			case F_IS_GRAV1930:
 				printf ("\t%g\t%g*sin((lat))^2\n", a[p*n_par], a[p*n_par+1]);
@@ -622,57 +604,11 @@ int main (int argc, char **argv)
 	GMT_free ((void *)data[COL_WW]);
 	for (i = 0; i < 2; i++) GMT_free ((void *)ID[i]);
 	GMT_free ((void *)b);
+	if (reset_zero) GMT_free ((void *)start);
 	x2sys_free_list (trk_list, n_tracks);
-#ifdef SAVEFORLATER
-	if (start) GMT_free ((void *)start);
-#endif
 
 	x2sys_end (S);
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
-
-#ifdef SAVEFORLATER
-int x2sys_read_namedatelist (char *file, char ***list, double **start, int *nf)
-{
-	/* Reads a list with track names and their origin times (needed for -Et) */
-	int n_alloc = GMT_CHUNK, n = 0;
-	char **p, line[BUFSIZ], name[GMT_TEXT_LEN], date[GMT_TEXT_LEN];
-	double *T;
-	FILE *fp;
-
-	if ((fp = x2sys_fopen (file, "r")) == NULL) {
-  		fprintf (stderr, "%s : Cannot find track list file %s in either current or X2SYS_HOME directories\n", GMT_program, line);
-		return (GMT_GRDIO_FILE_NOT_FOUND);
-	}
-	
-	p = (char **) GMT_memory (VNULL, (size_t)n_alloc, sizeof (char *), GMT_program);
-	T = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
-
-	while (fgets (line, BUFSIZ, fp)) {
-		GMT_chop (line);	/* Remove trailing CR or LF */
-		sscanf (line, "%s %s", name, date);
-		p[n] = (char *) strdup (name);
-		if (date[strlen(date)-1] != 'T') strcat (date, "T");
-		if (GMT_scanf (date, GMT_IS_ABSTIME, &T[n]) == GMT_IS_NAN) T[n] = GMT_d_NaN;
-		
-		n++;
-		if (n == n_alloc) {
-			n_alloc <<= 1;
-			p = (char **)  GMT_memory ((void *)p, (size_t)n_alloc, sizeof (char *), GMT_program);
-			T = (double *) GMT_memory ((void *)T, (size_t)n_alloc, sizeof (double), GMT_program);
-		}
-	}
-	fclose (fp);
-
-	p = (char **)  GMT_memory ((void *)p, (size_t)n, sizeof (char *), GMT_program);
-	T = (double *) GMT_memory ((void *)T, (size_t)n, sizeof (double), GMT_program);
-
-	*list = p;
-	*start = T;
-	*nf = n;
-
-	return (X2SYS_NOERROR);
-}
-#endif
