@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: xyz2grd.c,v 1.89 2009/09/09 23:27:04 guru Exp $
+ *	$Id: xyz2grd.c,v 1.92 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -96,11 +96,11 @@ int main (int argc, char **argv)
 	struct GMT_Z_IO io;
 	struct XYZ2GRD_CTRL *Ctrl;
 	
-	void *New_Xyz2grd_Ctrl (), Free_Xyz2grd_Ctrl (struct XYZ2GRD_CTRL *C);
+	void *New_xyz2grd_Ctrl (), Free_xyz2grd_Ctrl (struct XYZ2GRD_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct XYZ2GRD_CTRL *)New_Xyz2grd_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct XYZ2GRD_CTRL *)New_xyz2grd_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&grd, argc, argv, FALSE);
 
@@ -451,34 +451,40 @@ int main (int argc, char **argv)
 			
 			grd.node_offset = 0;
 			not_used = fgets (line, BUFSIZ, fp);
+			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %d", &grd.nx) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			not_used = fgets (line, BUFSIZ, fp);
+			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %d", &grd.ny) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			not_used = fgets (line, BUFSIZ, fp);
+			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.x_min) != 1) {
 				fprintf (stderr, "%s: Error decoding xll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!strncmp (line, "xllcorner", (size_t)9)) grd.node_offset = 1;	/* Pixel grid */
 			not_used = fgets (line, BUFSIZ, fp);
+			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.y_min) != 1) {
 				fprintf (stderr, "%s: Error decoding yll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!strncmp (line, "yllcorner", (size_t)9)) grd.node_offset = 1;	/* Pixel grid */
 			not_used = fgets (line, BUFSIZ, fp);
+			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.x_inc) != 1) {
 				fprintf (stderr, "%s: Error decoding cellsize record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!Ctrl->E.set) {	/* Only read if not specified in -E */
 				not_used = fgets (line, BUFSIZ, fp);
+				GMT_chop (line);					/* Rid the world of CR/LF */
 				if (sscanf (line, "%*s %lf", &Ctrl->E.nodata) != 1) {
 					fprintf (stderr, "%s: Error decoding nodata_value record\n", GMT_program);
 					exit (EXIT_FAILURE);
@@ -624,17 +630,17 @@ int main (int argc, char **argv)
 	GMT_free ((void *)a);
 	if (!Ctrl->E.active) GMT_free ((void *)flag);
 
-	Free_Xyz2grd_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_xyz2grd_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Xyz2grd_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_xyz2grd_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct XYZ2GRD_CTRL *C;
 	
-	C = (struct XYZ2GRD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct XYZ2GRD_CTRL), "New_Xyz2grd_Ctrl");
+	C = (struct XYZ2GRD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct XYZ2GRD_CTRL), "New_xyz2grd_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->N.value = GMT_d_NaN;
@@ -643,7 +649,7 @@ void *New_Xyz2grd_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Xyz2grd_Ctrl (struct XYZ2GRD_CTRL *C) {	/* Deallocate control structure */
+void Free_xyz2grd_Ctrl (struct XYZ2GRD_CTRL *C) {	/* Deallocate control structure */
 	if (C->D.information) free ((void *)C->D.information);	
 	if (C->G.file) free ((void *)C->G.file);	
 	if (C->S.file) free ((void *)C->S.file);	
